@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2017, 2019 IBM Corporation.
+ * Copyright (c) 2017, 2020 IBM Corporation.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -30,6 +30,7 @@ import javax.annotation.processing.Messager;
 import javax.annotation.processing.ProcessingEnvironment;
 import javax.annotation.processing.RoundEnvironment;
 import javax.annotation.processing.SupportedAnnotationTypes;
+import javax.annotation.processing.SupportedSourceVersion;
 import javax.lang.model.AnnotatedConstruct;
 import javax.lang.model.SourceVersion;
 import javax.lang.model.element.AnnotationMirror;
@@ -58,12 +59,13 @@ import org.eclipse.jdt.compiler.apt.tests.processors.util.TestDirectiveVisitor;
 import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 
 /**
- * A processor that explores the java 9 specific elements and validates the lambda and 
- * type annotated elements. To enable this processor, add 
+ * A processor that explores the java 9 specific elements and validates the lambda and
+ * type annotated elements. To enable this processor, add
  * -Aorg.eclipse.jdt.compiler.apt.tests.processors.elements.Java9ElementProcessor to the command line.
  * @since 3.14
  */
 @SupportedAnnotationTypes("*")
+@SupportedSourceVersion(SourceVersion.RELEASE_8)
 public class Java9ElementProcessor extends BaseProcessor {
 	boolean reportSuccessAlready = true;
 	RoundEnvironment roundEnv = null;
@@ -89,7 +91,7 @@ public class Java9ElementProcessor extends BaseProcessor {
 				int current = Integer.parseInt(property);
 				if (current >= ver12) this.isJre12 = true;
 			}
-		} 
+		}
 	}
 	// Always return false from this processor, because it supports "*".
 	// The return value does not signify success or failure!
@@ -98,7 +100,7 @@ public class Java9ElementProcessor extends BaseProcessor {
 		if (roundEnv.processingOver()) {
 			return false;
 		}
-		
+
 		this.roundEnv = roundEnv;
 		Map<String, String> options = processingEnv.getOptions();
 		if (!options.containsKey(this.getClass().getName())) {
@@ -209,8 +211,8 @@ public class Java9ElementProcessor extends BaseProcessor {
 		assertEquals("incorrect no of modules in root elements", 2, moduleCount);
 		assertEquals("incorrect modules among root elements", "[mod.a, mod.b]", modules.toString());
 		assertEquals("incorrect no of types in root elements", 5, typeCount);
-		assertEquals("incorrect types among root elements", 
-				"[abc.A, abc.internal.A, abc.internal.TypeInAModule, abc.internal.pqr.A, pqr.ext.B]", 
+		assertEquals("incorrect types among root elements",
+				"[abc.A, abc.internal.A, abc.internal.TypeInAModule, abc.internal.pqr.A, pqr.ext.B]",
 				types.toString());
 	}
 	// Test the types part of root elements get the modules right
@@ -233,7 +235,7 @@ public class Java9ElementProcessor extends BaseProcessor {
 		assertEquals("modules should be equals", module, modFromRoot);
 	}
 	/*
-	 * Test module element can be retrieved and 
+	 * Test module element can be retrieved and
 	 * annotations on module declarations can be retrieved
 	 */
 	public void testModuleAnnotation1() {
@@ -264,8 +266,8 @@ public class Java9ElementProcessor extends BaseProcessor {
 	public void testModuleElement1() {
 		CharSequence name = "mod.a";
 		ModuleElement mod = _elementUtils.getModuleElement(name);
-		assertEquals("incorrect name", "mod.a", mod.getQualifiedName().toString());
-		assertEquals("incorrect name", "mod.a", mod.getQualifiedName().toString());
+		assertEquals("incorrect qualified name", "mod.a", mod.getQualifiedName().toString());
+		assertEquals("incorrect simple name", "a", mod.getSimpleName().toString());
 		List<? extends Element> enclosedElements = mod.getEnclosedElements();
 		PackageElement pack = null;
 		for (Element element : enclosedElements) {
@@ -319,7 +321,7 @@ public class Java9ElementProcessor extends BaseProcessor {
 		assertEquals("Incorrect element kind", ElementKind.MODULE, base.getKind());
 		assertFalse("Should be named", base.isUnnamed());
 		assertFalse("Should not be open", base.isOpen());
-	
+
 	}
 	/*
 	 * Test packages can be retrieved with the Elements API with and without
@@ -391,7 +393,7 @@ public class Java9ElementProcessor extends BaseProcessor {
 		assertEquals("Modules should be same", mod, mElement);
 	}
 	/*
-	 * Test that a module not part of the root modules can NOT be retrieved. 
+	 * Test that a module not part of the root modules can NOT be retrieved.
 	 */
 	public void testModuleElement7() {
 		// test that a random module from system unrelated to the module we are compiling is not loaded by the compiler
@@ -422,7 +424,7 @@ public class Java9ElementProcessor extends BaseProcessor {
 		assertNotNull("java.base module null", base);
 		List<? extends Directive> directives = base.getDirectives();
 		List<Directive> filterDirective = filterDirective(directives, DirectiveKind.EXPORTS);
-		assertEquals("incorrect no of exports", this.isJre11 ? 107 : (this.isJre10 ? 102 : 108) , filterDirective.size());
+		assertTrue("missing exports", filterDirective.size() > 100);
 		ExportsDirective pack = null;
 		for (Directive directive : filterDirective) {
 			ModuleElement.ExportsDirective exports = (ExportsDirective) directive;
@@ -704,7 +706,7 @@ public class Java9ElementProcessor extends BaseProcessor {
 				}
 			}
 		}
-		
+
 	}
 	public void testDirectiveVisitor() {
 		ModuleElement mod = _elementUtils.getModuleElement("mod.b");
@@ -840,35 +842,35 @@ public class Java9ElementProcessor extends BaseProcessor {
 				Filer filer = processingEnv.getFiler();
 				JavaFileObject jfo = filer.createSourceFile("targets.bug535819.query.QEntity1", annotatedType);
 				Writer writer = jfo.openWriter();
-				writer.write("package targets.bug535819.query;\n" + 
-						"  \n" + 
-						"import targets.bug535819.Entity1;\n" + 
-						"public class QEntity1 {\n" + 
-						"  private static final QEntity1 _alias = new QEntity1(true);\n" + 
-						"  public QEntity1() {\n" + 
-						"    super(Entity1.class);\n" + 
-						"  }\n" + 
-						"  private QEntity1(boolean dummy) {\n" + 
-						"    super(dummy);\n" + 
-						"  }\n" + 
-						"  public static class Alias {\n" + 
-						"  }\n" + 
+				writer.write("package targets.bug535819.query;\n" +
+						"  \n" +
+						"import targets.bug535819.Entity1;\n" +
+						"public class QEntity1 {\n" +
+						"  private static final QEntity1 _alias = new QEntity1(true);\n" +
+						"  public QEntity1() {\n" +
+						"    super(Entity1.class);\n" +
+						"  }\n" +
+						"  private QEntity1(boolean dummy) {\n" +
+						"    super(dummy);\n" +
+						"  }\n" +
+						"  public static class Alias {\n" +
+						"  }\n" +
 						"}");
 				writer.close();
-				
+
 				jfo = filer.createSourceFile("targets.bug535819.assoc.QAssocEntity1", annotatedType);
 				writer = jfo.openWriter();
-				writer.write("package targets.bug535819.query.assoc;\n" + 
-						"  \n" + 
-						"import targets.bug535819.Entity1;\n" + 
-						"import targets.bug535819.query.QEntity1;\n" + 
-						"public class QAssocEntity1<R>  {\n" + 
-						"  public QAssocEntity1(String name, R root) {\n" + 
-						"    super(name, root);\n" + 
-						"  }\n" + 
-						"}\n" + 
+				writer.write("package targets.bug535819.query.assoc;\n" +
+						"  \n" +
+						"import targets.bug535819.Entity1;\n" +
+						"import targets.bug535819.query.QEntity1;\n" +
+						"public class QAssocEntity1<R>  {\n" +
+						"  public QAssocEntity1(String name, R root) {\n" +
+						"    super(name, root);\n" +
+						"  }\n" +
+						"}\n" +
 						"");
-				writer.close();	
+				writer.close();
 			} catch (IOException e) {
 				e.printStackTrace();
 			}
@@ -973,14 +975,14 @@ public class Java9ElementProcessor extends BaseProcessor {
         	reportError(message + ", expected " + expected.toString() + " but was " + actual.toString());
         }
     }
-    
+
     static boolean equalsRegardingNull(Object expected, Object actual) {
         if (expected == null) {
             return actual == null;
         }
         return expected.equals(actual);
     }
-    
+
 	public void assertEquals(String msg, int expected, int actual) {
 		if (expected != actual) {
 			StringBuffer buf = new StringBuffer();
@@ -991,7 +993,7 @@ public class Java9ElementProcessor extends BaseProcessor {
 	}
 	public void assertEquals(Object expected, Object actual) {
 		if (expected != actual) {
-			
+
 		}
 	}
 	private void verifyAnnotations(AnnotatedConstruct construct, String[] annots) {
