@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2020 IBM Corporation.
+ * Copyright (c) 2020, 2021 IBM Corporation.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -40,6 +40,7 @@ import javax.lang.model.element.Modifier;
 import javax.lang.model.element.RecordComponentElement;
 import javax.lang.model.element.TypeElement;
 import javax.lang.model.element.VariableElement;
+import javax.lang.model.type.DeclaredType;
 import javax.lang.model.type.ExecutableType;
 import javax.lang.model.type.TypeKind;
 import javax.lang.model.type.TypeMirror;
@@ -128,6 +129,10 @@ public class RecordElementProcessor extends BaseElementProcessor {
 		testRecords4();
 		testRecords5();
 		testRecords6();
+		testRecords7();
+		testRecords8();
+		testRecords9();
+		testRecords10();
 	}
 
 	public void testPreviewFlagTrue() throws IOException {
@@ -153,7 +158,7 @@ public class RecordElementProcessor extends BaseElementProcessor {
 		List<? extends RecordComponentElement> recordComponents = record.getRecordComponents();
 		// Test that in the first round, we don't get an NPE
 		assertNotNull("recordComponents Should not be null", recordComponents);
-		assertEquals("recordComponents Should not be null", 5, recordComponents.size());
+		assertEquals("recordComponents Should not be null", 6, recordComponents.size());
 	}
 	/*
 	 * Test for presence of record component in a record element
@@ -171,7 +176,7 @@ public class RecordElementProcessor extends BaseElementProcessor {
 		assertNotNull("enclosedElements for record should not be null", enclosedElements);
 		List<RecordComponentElement> recordComponentsIn = ElementFilter.recordComponentsIn(enclosedElements);
 		int size = recordComponentsIn.size();
-		assertEquals("incorrect no of record components", 5, size);
+		assertEquals("incorrect no of record components", 6, size);
 		Element element = recordComponentsIn.get(0);
 		assertEquals("Incorrect kind of element", ElementKind.RECORD_COMPONENT, element.getKind());
 		RecordComponentElement recordComponent = (RecordComponentElement) element;
@@ -277,7 +282,7 @@ public class RecordElementProcessor extends BaseElementProcessor {
 		assertNotNull("enclosedElements for record should not be null", enclosedElements);
 		List<RecordComponentElement> recordComponentsIn = ElementFilter.recordComponentsIn(enclosedElements);
 		int size = recordComponentsIn.size();
-		assertEquals("incorrect no of record components", 5, size);
+		assertEquals("incorrect no of record components", 6, size);
 		Element element = recordComponentsIn.get(0);
 		assertEquals("Incorrect kind of element", ElementKind.RECORD_COMPONENT, element.getKind());
 		RecordComponentElement recordComponent = (RecordComponentElement) element;
@@ -303,7 +308,7 @@ public class RecordElementProcessor extends BaseElementProcessor {
 		assertNotNull("enclosedElements for record should not be null", enclosedElements);
 		List<RecordComponentElement> recordComponentsIn = ElementFilter.recordComponentsIn(enclosedElements);
 		int size = recordComponentsIn.size();
-		assertEquals("incorrect no of record components", 5, size);
+		assertEquals("incorrect no of record components", 6, size);
 
 		Element element = recordComponentsIn.get(2);
 		assertEquals("Incorrect kind of element", ElementKind.RECORD_COMPONENT, element.getKind());
@@ -323,28 +328,56 @@ public class RecordElementProcessor extends BaseElementProcessor {
 		List<String> actualMethodNames = methodsIn.stream().filter((m) -> m.getSimpleName().toString().startsWith("comp"))
 																	.map((m) -> m.getSimpleName().toString())
 																	.collect(Collectors.toList());
-		assertEquals("incorrect method", 5, actualMethodNames.size());
+		assertEquals("incorrect method", 6, actualMethodNames.size());
 		for (ExecutableElement method : methodsIn) {
 			if (method.getSimpleName().toString().equals("comp_")) {
 				verifyAnnotations(method, new String[]{});
 				TypeMirror asType = method.asType();
 				verifyAnnotations(asType, new String[]{});
 			} else if (method.getSimpleName().toString().equals("comp2_")) {
-				verifyAnnotations(method, new String[]{"@MyAnnot2()"});
-				TypeMirror asType = method.asType();
-				verifyAnnotations(asType, new String[]{});
+				if (!isBinaryMode) {
+					verifyAnnotations(method, new String[]{"@MyAnnot2()"});
+					TypeMirror asType = method.asType();
+					verifyAnnotations(asType, new String[]{});
+				}
 			} else if (method.getSimpleName().toString().equals("comp3_")) {
-				verifyAnnotations(method, new String[]{"@MyAnnot3()"});
-				TypeMirror asType = method.asType();
-				verifyAnnotations(asType, new String[]{});
+				// Known issue
+				if (!isBinaryMode) {
+					verifyAnnotations(method, new String[]{"@MyAnnot3()"});
+					TypeMirror asType = method.asType();
+					verifyAnnotations(asType, new String[]{});
+				}
 			} else if (method.getSimpleName().toString().equals("comp4_")) {
 				verifyAnnotations(method, new String[]{});
 				TypeMirror asType = method.asType();
 				verifyAnnotations(asType, new String[]{});
 			} else if (method.getSimpleName().toString().equals("comp5_")) {
-				verifyAnnotations(method, new String[]{});
-				TypeMirror asType = method.asType();
-				verifyAnnotations(asType, new String[]{});
+				// Known issue
+				if (!isBinaryMode) {
+					verifyAnnotations(method, new String[]{});
+					TypeMirror asType = method.asType();
+					verifyAnnotations(asType, new String[]{});
+				}
+			} else if (method.getSimpleName().toString().equals("comp6_")) {
+				List<? extends AnnotationMirror> annots = method.getAnnotationMirrors();
+				assertEquals("incorrect no of annotations", 1, annots.size());
+				AnnotationMirror mirror = annots.get(0);
+				DeclaredType annotationType = mirror.getAnnotationType();
+				Element asElement = annotationType.asElement();
+				if (isBinaryMode) {
+					List<? extends AnnotationMirror> annotationMirrors = asElement.getAnnotationMirrors();
+					assertEquals("incorrect no of annotations", 2, annotationMirrors.size());
+					for (AnnotationMirror mirror1 : annotationMirrors) {
+						if (mirror1.getAnnotationType().asElement().getSimpleName().toString().contains("Retention")) {
+							assertEquals("Invalid annotation value", "@Retention(value=RUNTIME)", getAnnotationString(mirror1));
+						} else if (mirror1.getAnnotationType().asElement().getSimpleName().toString().contains("Target")) {
+							String annotationString = getAnnotationString(mirror1);
+							assertTrue("must contain target METHOD", annotationString.contains("METHOD"));
+							assertTrue("must contain target TYPE_USE", annotationString.contains("TYPE_USE"));
+							assertEquals("Invalid annotation value", "@Target(value=METHOD,TYPE_USE)", getAnnotationString(mirror1));
+						}
+					}
+				}
 			}
 		}
 		methodsIn = ElementFilter.constructorsIn(enclosedElements);
@@ -354,7 +387,7 @@ public class RecordElementProcessor extends BaseElementProcessor {
 		TypeMirror asType = m.asType();
 		verifyAnnotations(asType, new String[]{});
 		List<? extends VariableElement> parameters = m.getParameters();
-		assertEquals("incorrect parameters", 5, parameters.size());
+		assertEquals("incorrect parameters", 6, parameters.size());
 		for (VariableElement v : parameters) {
 			if (v.getSimpleName().toString().equals("comp_")) {
 				verifyAnnotations(v, new String[]{"@MyAnnot()"}); // ECJ fails
@@ -521,45 +554,68 @@ public class RecordElementProcessor extends BaseElementProcessor {
         assertTrue("Test returned negative", result);
 	}
 	public void testRecords9() {
-			String[] arr1 = new String[] { "x", "bigInt", "r1", "floatValue", "c", "recordInstance" };
-			TypeKind[] arr2 = new TypeKind[] { TypeKind.INT, TypeKind.DECLARED, TypeKind.DECLARED, TypeKind.FLOAT,
-					TypeKind.DECLARED, TypeKind.DECLARED };
-			List<String> names = Arrays.asList(arr1);
-			List<TypeKind> types = Arrays.asList(arr2);
+		String[] arr1 = new String[] { "x", "bigInt", "r1", "floatValue", "c", "recordInstance" };
+		TypeKind[] arr2 = new TypeKind[] { TypeKind.INT, TypeKind.DECLARED, TypeKind.DECLARED, TypeKind.FLOAT,
+				TypeKind.DECLARED, TypeKind.DECLARED };
+		List<String> names = Arrays.asList(arr1);
+		List<TypeKind> types = Arrays.asList(arr2);
 
-	        Element record = _elementUtils.getTypeElement("records.R3");
-	        List<? extends Element> allElements = record.getEnclosedElements();
-	        List<RecordComponentElement> components = ElementFilter.recordComponentsIn(allElements);
-	        List<ExecutableElement> accessors = components.stream().map
-	                (RecordComponentElement::getAccessor).collect(Collectors.toList());
-	        assertEquals("Size mismatch", names.size(), accessors.size());
-	        for (ExecutableElement accessor : accessors) {
-	            String name = accessor.getSimpleName().toString();
-	            int indexOf = names.indexOf(name);
-	            assertSame("Type kind not same for \"" + name + "\".", types.get(indexOf), accessor.getReturnType().getKind());
-	            assertTrue("should be executable type for \"" + name + "\".", (accessor.asType() instanceof ExecutableType));
-	            assertNull("should be null", accessor.getDefaultValue());
-	            List<? extends AnnotationMirror> mirrors = accessor.getAnnotationMirrors();
-				if (name.equals("c") || name.equals("bigInt") || name.equals("r1")) {
-	            	assertEquals("annotations count mismatch for \"" + name + "\".", 1, mirrors.size());
-	            	Set<? extends ExecutableElement> accessorAnnotations = mirrors.get(0)
-	                        .getElementValues().keySet();
-	            	assertEquals("annotations type element mismatch for \"" + name + "\".", 1, accessorAnnotations.size());
-	            	int val = (int) accessorAnnotations.toArray(new ExecutableElement[0])[0].getDefaultValue()
-	                        .getValue();
-	            	assertEquals("Incorrect default value for \"" + name + "\".", 1, val);
-	            }
-	            if (name.equals("floatValue") || name.equals("x")) {
-	            	assertEquals("annotations count mismatch for \"" + name + "\".", 0, mirrors.size());
-	            }
-	            if (name.equals("recordInstance")) {
-	            	assertEquals("annotations count mismatch for \"" + name + "\".", 2, mirrors.size());
-	            }
-	            assertTrue("Parameters should be empty for \"" + name + "\".", accessor.getParameters().isEmpty());
-	            assertTrue("Thrown types should be empty for \"" + name + "\".", accessor.getThrownTypes().isEmpty());
-	            assertTrue("Type parameters should be empty for \"" + name + "\".", accessor.getTypeParameters().isEmpty());
-	            assertFalse("Should not be default for \"" + name + "\".", accessor.isDefault());
-	            assertFalse("Should not be varargs for \"" + name + "\".", accessor.isVarArgs());
-	        }
+		Element record = _elementUtils.getTypeElement("records.R3");
+		List<? extends Element> allElements = record.getEnclosedElements();
+		List<RecordComponentElement> components = ElementFilter.recordComponentsIn(allElements);
+		List<ExecutableElement> accessors = components.stream().map
+				(RecordComponentElement::getAccessor).collect(Collectors.toList());
+		assertEquals("Size mismatch", names.size(), accessors.size());
+		for (ExecutableElement accessor : accessors) {
+			String name = accessor.getSimpleName().toString();
+			int indexOf = names.indexOf(name);
+			assertSame("Type kind not same for \"" + name + "\".", types.get(indexOf), accessor.getReturnType().getKind());
+			assertTrue("should be executable type for \"" + name + "\".", (accessor.asType() instanceof ExecutableType));
+			assertNull("should be null", accessor.getDefaultValue());
+			List<? extends AnnotationMirror> mirrors = accessor.getAnnotationMirrors();
+			if (name.equals("c") || name.equals("bigInt") || name.equals("r1")) {
+				assertEquals("annotations count mismatch for \"" + name + "\".", 1, mirrors.size());
+				Set<? extends ExecutableElement> accessorAnnotations = mirrors.get(0)
+						.getElementValues().keySet();
+				assertEquals("annotations type element mismatch for \"" + name + "\".", 1, accessorAnnotations.size());
+				int val = (int) accessorAnnotations.toArray(new ExecutableElement[0])[0].getDefaultValue()
+						.getValue();
+				assertEquals("Incorrect default value for \"" + name + "\".", 1, val);
+			}
+			if (name.equals("floatValue") || name.equals("x")) {
+				assertEquals("annotations count mismatch for \"" + name + "\".", 0, mirrors.size());
+			}
+			if (name.equals("recordInstance")) {
+				assertEquals("annotations count mismatch for \"" + name + "\".", 2, mirrors.size());
+			}
+			assertTrue("Parameters should be empty for \"" + name + "\".", accessor.getParameters().isEmpty());
+			assertTrue("Thrown types should be empty for \"" + name + "\".", accessor.getThrownTypes().isEmpty());
+			assertTrue("Type parameters should be empty for \"" + name + "\".", accessor.getTypeParameters().isEmpty());
+			assertFalse("Should not be default for \"" + name + "\".", accessor.isDefault());
+			assertFalse("Should not be varargs for \"" + name + "\".", accessor.isVarArgs());
+		}
+	}
+	public void testRecords10() {
+		Set<? extends Element> elements = roundEnv.getRootElements();
+		TypeElement record = null;
+		for (Element element : elements) {
+			if ("R4".equals(element.getSimpleName().toString())) {
+				record = (TypeElement) element;
+			}
+		}
+		assertNotNull("TypeElement for record should not be null", record);
+
+		List<? extends Element> enclosedElements = record.getEnclosedElements();
+		List<ExecutableElement> methodsIn = ElementFilter.constructorsIn(enclosedElements);
+		assertEquals("incorrect method", 1, methodsIn.size());
+		ExecutableElement m = methodsIn.get(0);
+		verifyAnnotations(m, new String[]{});
+		TypeMirror asType = m.asType();
+		verifyAnnotations(asType, new String[]{});
+		List<? extends VariableElement> parameters = m.getParameters();
+		assertEquals("incorrect parameters", 1, parameters.size());
+		VariableElement var = parameters.get(0);
+		assertEquals("component name incorrect", "i", var.getSimpleName().toString());
+		verifyAnnotations(var, new String[]{"@Marker4()"});
 	}
 }
