@@ -1,3 +1,3 @@
 module com.reinhardt.annotationdiscoveryvisitornpe {
-    requires java.xml.bind;
+    requires java.compiler;
 }
