@@ -462,7 +462,7 @@ public void test10() {
 		// completeBehind:
 		"argv",
 		// expectedCompletionNodeToString:
-		"<CompleteOnName:>",
+		"<CompleteOnArgumentName:String[] argv>",
 		// expectedUnitDisplayString:
 		"package pack;\n" +
 		"class A {\n" +
@@ -478,9 +478,9 @@ public void test10() {
 		"  }\n" +
 		"}\n",
 		// expectedCompletionIdentifier:
-		"",
+		"argv",
 		// expectedReplacedSource:
-		"",
+		"argv",
 		// test name
 		"<completion on argument name>"
 	);
@@ -554,7 +554,7 @@ public void test12() {
 		// completeBehind:
 		"argv",
 		// expectedCompletionNodeToString:
-		"<CompleteOnName:>",
+		"<CompleteOnArgumentName:String[] argv>",
 		// expectedUnitDisplayString:
 		"class DD {\n" +
 		"  DD() {\n" +
@@ -563,9 +563,9 @@ public void test12() {
 		"  }\n" +
 		"}\n",
 		// expectedCompletionIdentifier:
-		"",
+		"argv",
 		// expectedReplacedSource:
-		"",
+		"argv",
 		// test name
 		"<complete on argument name with class decl later on>"
 	);
@@ -758,6 +758,7 @@ public void test18() {
 		"      int hello() {\n" +
 		"      }\n" +
 		"    }\n" +
+		"    <CompleteOnName:>;\n" +
 		"  }\n" +
 		"}\n",
 		// expectedCompletionIdentifier:
@@ -1069,11 +1070,11 @@ public void test26() {
 		"  }\n" +
 		"  void main(Shell shell) {\n" +
 		"    final Label label;\n" +
-		"    new PaintListener() {\n" +
-		"      public void paintControl(PaintEvent e) {\n" +
-		"        e.gc.setLineCap(<CompleteOnName:SWT.CAP_>);\n" +
-		"      }\n" +
-		"    };\n" +
+		"    label.addPaintListener(new PaintListener() {\n" +
+		"  public void paintControl(PaintEvent e) {\n" +
+		"    e.gc.setLineCap(<CompleteOnName:SWT.CAP_>);\n" +
+		"  }\n" +
+		"});\n" +
 		"  }\n" +
 		"}\n",
 		// expectedCompletionIdentifier:
