@@ -28,6 +28,7 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 	public static Class testClass() {
 		return LambdaExpressionSyntaxTest.class;
 	}
+	@Override
 	public void initialize(CompilerTestSetup setUp) {
 		super.initialize(setUp);
 	}
@@ -56,7 +57,7 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 	}
 	// type elided, unparenthesized parameter + expression body lambda in casting context.
 	public void test0001() throws IOException {
-		String source = 
+		String source =
 				"interface I {\n" +
 				"    int square(int x);\n" +
 				"}\n" +
@@ -66,23 +67,23 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 				"    }\n" +
 				"}\n";
 
-		String expectedUnitToString = 
-				"interface I {\n" + 
-				"  int square(int x);\n" + 
-				"}\n" + 
-				"public class X {\n" + 
-				"  public X() {\n" + 
-				"    super();\n" + 
-				"  }\n" + 
-				"  public static void main(String[] args) {\n" + 
-				"    System.out.println(((I) (<no type> x) -> (x * x)).square(10));\n" + 
-				"  }\n" + 
+		String expectedUnitToString =
+				"interface I {\n" +
+				"  int square(int x);\n" +
+				"}\n" +
+				"public class X {\n" +
+				"  public X() {\n" +
+				"    super();\n" +
+				"  }\n" +
+				"  public static void main(String[] args) {\n" +
+				"    System.out.println(((I) (<no type> x) -> (x * x)).square(10));\n" +
+				"  }\n" +
 				"}\n";
 		checkParse(CHECK_PARSER | CHECK_JAVAC_PARSER , source.toCharArray(), null, "test0001", expectedUnitToString);
 	}
 	// type elided, unparenthesized parameter + expression body lambda as initializer.
 	public void test0002() throws IOException {
-		String source = 
+		String source =
 				"interface I {\n" +
 				"    int square(int x);\n" +
 				"}\n" +
@@ -93,24 +94,24 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 				"    }\n" +
 				"}\n";
 
-		String expectedUnitToString = 
-				"interface I {\n" + 
-				"  int square(int x);\n" + 
-				"}\n" + 
-				"public class X {\n" + 
-				"  public X() {\n" + 
-				"    super();\n" + 
-				"  }\n" + 
-				"  public static void main(String[] args) {\n" + 
-				"    I i = (<no type> x) -> (x * x);\n" + 
-				"    System.out.println(i.square(10));\n" + 
-				"  }\n" + 
+		String expectedUnitToString =
+				"interface I {\n" +
+				"  int square(int x);\n" +
+				"}\n" +
+				"public class X {\n" +
+				"  public X() {\n" +
+				"    super();\n" +
+				"  }\n" +
+				"  public static void main(String[] args) {\n" +
+				"    I i = (<no type> x) -> (x * x);\n" +
+				"    System.out.println(i.square(10));\n" +
+				"  }\n" +
 				"}\n";
 		checkParse(CHECK_PARSER | CHECK_JAVAC_PARSER , source.toCharArray(), null, "test0002", expectedUnitToString);
 	}
 	// type elided, unparenthesized parameter + expression body lambda as initializer, full lambda is parenthesized.
 	public void test0003() throws IOException {
-		String source = 
+		String source =
 				"interface I {\n" +
 				"    int square(int x);\n" +
 				"}\n" +
@@ -121,24 +122,24 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 				"    }\n" +
 				"}\n";
 
-		String expectedUnitToString = 
-				"interface I {\n" + 
-				"  int square(int x);\n" + 
-				"}\n" + 
-				"public class X {\n" + 
-				"  public X() {\n" + 
-				"    super();\n" + 
-				"  }\n" + 
-				"  public static void main(String[] args) {\n" + 
-				"    I i = (((((<no type> x) -> (x * x)))));\n" + 
-				"    System.out.println(i.square(10));\n" + 
-				"  }\n" + 
+		String expectedUnitToString =
+				"interface I {\n" +
+				"  int square(int x);\n" +
+				"}\n" +
+				"public class X {\n" +
+				"  public X() {\n" +
+				"    super();\n" +
+				"  }\n" +
+				"  public static void main(String[] args) {\n" +
+				"    I i = (((((<no type> x) -> (x * x)))));\n" +
+				"    System.out.println(i.square(10));\n" +
+				"  }\n" +
 				"}\n";
 		checkParse(CHECK_PARSER | CHECK_JAVAC_PARSER , source.toCharArray(), null, "test0003", expectedUnitToString);
 	}
 	// type elided, unparenthesized parameter + expression body lambda as RHS of assignment, full lambda is parenthesized.
 	public void test0004() throws IOException {
-		String source = 
+		String source =
 				"interface I {\n" +
 				"    int square(int x);\n" +
 				"}\n" +
@@ -150,25 +151,25 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 				"    }\n" +
 				"}\n";
 
-		String expectedUnitToString = 
-				"interface I {\n" + 
-				"  int square(int x);\n" + 
-				"}\n" + 
-				"public class X {\n" + 
-				"  public X() {\n" + 
-				"    super();\n" + 
-				"  }\n" + 
-				"  public static void main(String[] args) {\n" + 
-				"    I i;\n" + 
-				"    i = ((<no type> x) -> (x * x));\n" + 
-				"    System.out.println(i.square(10));\n" + 
-				"  }\n" + 
+		String expectedUnitToString =
+				"interface I {\n" +
+				"  int square(int x);\n" +
+				"}\n" +
+				"public class X {\n" +
+				"  public X() {\n" +
+				"    super();\n" +
+				"  }\n" +
+				"  public static void main(String[] args) {\n" +
+				"    I i;\n" +
+				"    i = ((<no type> x) -> (x * x));\n" +
+				"    System.out.println(i.square(10));\n" +
+				"  }\n" +
 				"}\n";
 		checkParse(CHECK_PARSER | CHECK_JAVAC_PARSER , source.toCharArray(), null, "test0004", expectedUnitToString);
 	}
 	// type elided, unparenthesized parameter + expression body lambda in return statement, full lambda is parenthesized.
 	public void test0005() throws IOException {
-		String source = 
+		String source =
 				"interface I {\n" +
 				"    int square(int x);\n" +
 				"}\n" +
@@ -182,27 +183,27 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 				"    }\n" +
 				"}\n";
 
-		String expectedUnitToString = 
-				"interface I {\n" + 
-				"  int square(int x);\n" + 
-				"}\n" + 
-				"public class X {\n" + 
-				"  public X() {\n" + 
-				"    super();\n" + 
-				"  }\n" + 
-				"  static I getI() {\n" + 
-				"    return ((<no type> x) -> (x * x));\n" + 
-				"  }\n" + 
-				"  public static void main(String[] args) {\n" + 
-				"    I i = getI();\n" + 
-				"    System.out.println(i.square(10));\n" + 
-				"  }\n" + 
+		String expectedUnitToString =
+				"interface I {\n" +
+				"  int square(int x);\n" +
+				"}\n" +
+				"public class X {\n" +
+				"  public X() {\n" +
+				"    super();\n" +
+				"  }\n" +
+				"  static I getI() {\n" +
+				"    return ((<no type> x) -> (x * x));\n" +
+				"  }\n" +
+				"  public static void main(String[] args) {\n" +
+				"    I i = getI();\n" +
+				"    System.out.println(i.square(10));\n" +
+				"  }\n" +
 				"}\n";
 		checkParse(CHECK_PARSER | CHECK_JAVAC_PARSER , source.toCharArray(), null, "test0005", expectedUnitToString);
 	}
 	// type elided, unparenthesized parameter + expression body lambda in conditional expression.
 	public void test0006() throws IOException {
-		String source = 
+		String source =
 				"interface I {\n" +
 				"    int square(int x);\n" +
 				"}\n" +
@@ -213,24 +214,24 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 				"    }\n" +
 				"}\n";
 
-		String expectedUnitToString = 
-				"interface I {\n" + 
-				"  int square(int x);\n" + 
-				"}\n" + 
-				"public class X {\n" + 
-				"  public X() {\n" + 
-				"    super();\n" + 
-				"  }\n" + 
-				"  public static void main(String[] args) {\n" + 
-				"    I i = ((args == null) ? (<no type> x) -> (x * x) : (<no type> x) -> ((x * x) * x));\n" + 
-				"    System.out.println(i.square(10));\n" + 
-				"  }\n" + 
+		String expectedUnitToString =
+				"interface I {\n" +
+				"  int square(int x);\n" +
+				"}\n" +
+				"public class X {\n" +
+				"  public X() {\n" +
+				"    super();\n" +
+				"  }\n" +
+				"  public static void main(String[] args) {\n" +
+				"    I i = ((args == null) ? (<no type> x) -> (x * x) : (<no type> x) -> ((x * x) * x));\n" +
+				"    System.out.println(i.square(10));\n" +
+				"  }\n" +
 				"}\n";
 		checkParse(CHECK_PARSER | CHECK_JAVAC_PARSER , source.toCharArray(), null, "test0006", expectedUnitToString);
 	}
 	// type elided, unparenthesized parameter + expression body lambda in message send.
 	public void test0007() throws IOException {
-		String source = 
+		String source =
 				"interface I {\n" +
 				"    int square(int x);\n" +
 				"}\n" +
@@ -244,27 +245,27 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 				"    }\n" +
 				"}\n";
 
-		String expectedUnitToString = 
-				"interface I {\n" + 
-				"  int square(int x);\n" + 
-				"}\n" + 
-				"public class X {\n" + 
-				"  public X() {\n" + 
-				"    super();\n" + 
-				"  }\n" + 
-				"  static void foo(I i1, I i2) {\n" + 
-				"    System.out.println(i1.square(10));\n" + 
-				"    System.out.println(i2.square(10));\n" + 
-				"  }\n" + 
-				"  public static void main(String[] args) {\n" + 
-				"    foo((<no type> x) -> (x * x), (<no type> x) -> ((x * x) * x));\n" + 
-				"  }\n" + 
+		String expectedUnitToString =
+				"interface I {\n" +
+				"  int square(int x);\n" +
+				"}\n" +
+				"public class X {\n" +
+				"  public X() {\n" +
+				"    super();\n" +
+				"  }\n" +
+				"  static void foo(I i1, I i2) {\n" +
+				"    System.out.println(i1.square(10));\n" +
+				"    System.out.println(i2.square(10));\n" +
+				"  }\n" +
+				"  public static void main(String[] args) {\n" +
+				"    foo((<no type> x) -> (x * x), (<no type> x) -> ((x * x) * x));\n" +
+				"  }\n" +
 				"}\n";
 		checkParse(CHECK_PARSER | CHECK_JAVAC_PARSER , source.toCharArray(), null, "test0007", expectedUnitToString);
 	}
 	// type elided, unparenthesized parameter + expression body lambda in constructor call.
 	public void test0008() throws IOException {
-		String source = 
+		String source =
 				"interface I {\n" +
 				"    int square(int x);\n" +
 				"}\n" +
@@ -278,25 +279,25 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 				"    }\n" +
 				"}\n";
 
-		String expectedUnitToString = 
-				"interface I {\n" + 
-				"  int square(int x);\n" + 
-				"}\n" + 
-				"public class X {\n" + 
-				"  X(I i1, I i2) {\n" + 
-				"    super();\n" + 
-				"    System.out.println(i1.square(10));\n" + 
-				"    System.out.println(i2.square(10));\n" + 
-				"  }\n" + 
-				"  public static void main(String[] args) {\n" + 
-				"    new X((<no type> x) -> (x * x), (<no type> x) -> ((x * x) * x));\n" + 
-				"  }\n" + 
+		String expectedUnitToString =
+				"interface I {\n" +
+				"  int square(int x);\n" +
+				"}\n" +
+				"public class X {\n" +
+				"  X(I i1, I i2) {\n" +
+				"    super();\n" +
+				"    System.out.println(i1.square(10));\n" +
+				"    System.out.println(i2.square(10));\n" +
+				"  }\n" +
+				"  public static void main(String[] args) {\n" +
+				"    new X((<no type> x) -> (x * x), (<no type> x) -> ((x * x) * x));\n" +
+				"  }\n" +
 				"}\n";
 		checkParse(CHECK_PARSER | CHECK_JAVAC_PARSER , source.toCharArray(), null, "test0008", expectedUnitToString);
 	}
 	// type elided, unparenthesized parameter + expression body lambda in lambda.
 	public void test0009() throws IOException {
-		String source = 
+		String source =
 				"interface I {\n" +
 				"    I square(int x);\n" +
 				"}\n" +
@@ -306,23 +307,23 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 				"    }\n" +
 				"}\n";
 
-		String expectedUnitToString = 
-				"interface I {\n" + 
-				"  I square(int x);\n" + 
-				"}\n" + 
-				"public class X {\n" + 
-				"  public X() {\n" + 
-				"    super();\n" + 
-				"  }\n" + 
-				"  public static void main(String[] args) {\n" + 
-				"    System.out.println(((I) (<no type> a) -> (<no type> b) -> (<no type> c) -> (<no type> d) -> (<no type> e) -> (<no type> f) -> (<no type> g) -> null).square(10));\n" + 
-				"  }\n" + 
+		String expectedUnitToString =
+				"interface I {\n" +
+				"  I square(int x);\n" +
+				"}\n" +
+				"public class X {\n" +
+				"  public X() {\n" +
+				"    super();\n" +
+				"  }\n" +
+				"  public static void main(String[] args) {\n" +
+				"    System.out.println(((I) (<no type> a) -> (<no type> b) -> (<no type> c) -> (<no type> d) -> (<no type> e) -> (<no type> f) -> (<no type> g) -> null).square(10));\n" +
+				"  }\n" +
 				"}\n";
 		checkParse(CHECK_PARSER | CHECK_JAVAC_PARSER , source.toCharArray(), null, "test0009", expectedUnitToString);
 	}
 	// type elided, unparenthesized parameter + expression body lambda in an initializer block
 	public void test00010() throws IOException {
-		String source = 
+		String source =
 				"interface I {\n" +
 				"    int square(int x);\n" +
 				"}\n" +
@@ -336,29 +337,29 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 				"    }\n" +
 				"}\n";
 
-		String expectedUnitToString = 
-				"interface I {\n" + 
-				"  int square(int x);\n" + 
-				"}\n" + 
-				"public class X {\n" + 
-				"  static I i = (<no type> x) -> (x * x);\n" + 
-				"  {\n" + 
-				"    i = (<no type> x) -> ((x * x) * x);\n" + 
-				"  }\n" + 
-				"  static {\n" + 
-				"    i = (<no type> x) -> ((x * x) * x);\n" + 
-				"  }\n" + 
-				"  <clinit>() {\n" + 
-				"  }\n" + 
-				"  public X() {\n" + 
-				"    super();\n" + 
-				"  }\n" + 
+		String expectedUnitToString =
+				"interface I {\n" +
+				"  int square(int x);\n" +
+				"}\n" +
+				"public class X {\n" +
+				"  static I i = (<no type> x) -> (x * x);\n" +
+				"  {\n" +
+				"    i = (<no type> x) -> ((x * x) * x);\n" +
+				"  }\n" +
+				"  static {\n" +
+				"    i = (<no type> x) -> ((x * x) * x);\n" +
+				"  }\n" +
+				"  <clinit>() {\n" +
+				"  }\n" +
+				"  public X() {\n" +
+				"    super();\n" +
+				"  }\n" +
 				"}\n";
 		checkParse(CHECK_PARSER | CHECK_JAVAC_PARSER , source.toCharArray(), null, "test00010", expectedUnitToString);
 	}
 	// type elided, parenthesized parameter + expression body lambda in casting context.
 	public void test0011() throws IOException {
-		String source = 
+		String source =
 				"interface I {\n" +
 				"    int square(int x);\n" +
 				"}\n" +
@@ -368,23 +369,23 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 				"    }\n" +
 				"}\n";
 
-		String expectedUnitToString = 
-				"interface I {\n" + 
-				"  int square(int x);\n" + 
-				"}\n" + 
-				"public class X {\n" + 
-				"  public X() {\n" + 
-				"    super();\n" + 
-				"  }\n" + 
-				"  public static void main(String[] args) {\n" + 
-				"    System.out.println(((I) (<no type> x) -> (x * x)).square(10));\n" + 
-				"  }\n" + 
+		String expectedUnitToString =
+				"interface I {\n" +
+				"  int square(int x);\n" +
+				"}\n" +
+				"public class X {\n" +
+				"  public X() {\n" +
+				"    super();\n" +
+				"  }\n" +
+				"  public static void main(String[] args) {\n" +
+				"    System.out.println(((I) (<no type> x) -> (x * x)).square(10));\n" +
+				"  }\n" +
 				"}\n";
 		checkParse(CHECK_PARSER | CHECK_JAVAC_PARSER , source.toCharArray(), null, "test0011", expectedUnitToString);
 	}
 	// Normal & minimal parameter list + expression body lambda in assignment context.
 	public void test0012() throws IOException {
-		String source = 
+		String source =
 				"interface I {\n" +
 				"    int square(int x);\n" +
 				"}\n" +
@@ -395,24 +396,24 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 				"    }\n" +
 				"}\n";
 
-		String expectedUnitToString = 
-				"interface I {\n" + 
-				"  int square(int x);\n" + 
-				"}\n" + 
-				"public class X {\n" + 
-				"  public X() {\n" + 
-				"    super();\n" + 
-				"  }\n" + 
-				"  public static void main(String[] args) {\n" + 
-				"    I i = (int x) -> (x * x);\n" + 
-				"    System.out.println(i.square(10));\n" + 
-				"  }\n" + 
+		String expectedUnitToString =
+				"interface I {\n" +
+				"  int square(int x);\n" +
+				"}\n" +
+				"public class X {\n" +
+				"  public X() {\n" +
+				"    super();\n" +
+				"  }\n" +
+				"  public static void main(String[] args) {\n" +
+				"    I i = (int x) -> (x * x);\n" +
+				"    System.out.println(i.square(10));\n" +
+				"  }\n" +
 				"}\n";
 		checkParse(CHECK_PARSER | CHECK_JAVAC_PARSER , source.toCharArray(), null, "test0012", expectedUnitToString);
 	}
 	// Normal parameter list, with modifiers & annotations  + expression body lambda in invocation context.
 	public void test0013() throws IOException {
-		String source = 
+		String source =
 				"interface I {\n" +
 				"    int square(int x);\n" +
 				"}\n" +
@@ -427,29 +428,29 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 				"    }\n" +
 				"}\n";
 
-		String expectedUnitToString = 
-				"interface I {\n" + 
-				"  int square(int x);\n" + 
-				"}\n" + 
-				"public class X {\n" + 
-				"  @interface Positive {\n" + 
-				"  }\n" + 
-				"  public X() {\n" + 
-				"    super();\n" + 
-				"  }\n" + 
-				"  static void foo(I i1, I i2) {\n" + 
-				"    System.out.println(i1.square(10));\n" + 
-				"    System.out.println(i2.square(10));\n" + 
-				"  }\n" + 
-				"  public static void main(String[] args) {\n" + 
-				"    foo((final int x) -> (x * x), (final @Positive int x) -> ((x * x) * x));\n" + 
-				"  }\n" + 
+		String expectedUnitToString =
+				"interface I {\n" +
+				"  int square(int x);\n" +
+				"}\n" +
+				"public class X {\n" +
+				"  @interface Positive {\n" +
+				"  }\n" +
+				"  public X() {\n" +
+				"    super();\n" +
+				"  }\n" +
+				"  static void foo(I i1, I i2) {\n" +
+				"    System.out.println(i1.square(10));\n" +
+				"    System.out.println(i2.square(10));\n" +
+				"  }\n" +
+				"  public static void main(String[] args) {\n" +
+				"    foo((final int x) -> (x * x), (final @Positive int x) -> ((x * x) * x));\n" +
+				"  }\n" +
 				"}\n";
 		checkParse(CHECK_PARSER | CHECK_JAVAC_PARSER , source.toCharArray(), null, "test0013", expectedUnitToString);
 	}
 	// Vararg parameter list, with modifiers & annotations + expression body lambda in message send context.
 	public void test0014() throws IOException {
-		String source = 
+		String source =
 				"interface I {\n" +
 				"    int square(int ... x);\n" +
 				"}\n" +
@@ -464,29 +465,29 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 				"    }\n" +
 				"}\n";
 
-		String expectedUnitToString = 
-				"interface I {\n" + 
-				"  int square(int... x);\n" + 
-				"}\n" + 
-				"public class X {\n" + 
-				"  @interface Positive {\n" + 
-				"  }\n" + 
-				"  public X() {\n" + 
-				"    super();\n" + 
-				"  }\n" + 
-				"  static void foo(I i1, I i2) {\n" + 
-				"    System.out.println(i1.square(10));\n" + 
-				"    System.out.println(i2.square(10));\n" + 
-				"  }\n" + 
-				"  public static void main(String[] args) {\n" + 
-				"    foo((final int... x) -> 10, (final @Positive int[] x) -> 20);\n" + 
-				"  }\n" + 
+		String expectedUnitToString =
+				"interface I {\n" +
+				"  int square(int... x);\n" +
+				"}\n" +
+				"public class X {\n" +
+				"  @interface Positive {\n" +
+				"  }\n" +
+				"  public X() {\n" +
+				"    super();\n" +
+				"  }\n" +
+				"  static void foo(I i1, I i2) {\n" +
+				"    System.out.println(i1.square(10));\n" +
+				"    System.out.println(i2.square(10));\n" +
+				"  }\n" +
+				"  public static void main(String[] args) {\n" +
+				"    foo((final int... x) -> 10, (final @Positive int[] x) -> 20);\n" +
+				"  }\n" +
 				"}\n";
 		checkParse(CHECK_PARSER | CHECK_JAVAC_PARSER , source.toCharArray(), null, "test0014", expectedUnitToString);
 	}
 	// multi parameter type elided list + expression body lambda in return statement.
 	public void test0015() throws IOException {
-		String source = 
+		String source =
 				"interface I {\n" +
 				"    int product(int x, int y);\n" +
 				"}\n" +
@@ -500,27 +501,27 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 				"    }\n" +
 				"};\n";
 
-		String expectedUnitToString = 
-				"interface I {\n" + 
-				"  int product(int x, int y);\n" + 
-				"}\n" + 
-				"public class X {\n" + 
-				"  public X() {\n" + 
-				"    super();\n" + 
-				"  }\n" + 
-				"  static I getI() {\n" + 
-				"    return ((<no type> x, <no type> y) -> (x * y));\n" + 
-				"  }\n" + 
-				"  public static void main(String[] args) {\n" + 
-				"    I i = getI();\n" + 
-				"    System.out.println(i.product(5, 6));\n" + 
-				"  }\n" + 
+		String expectedUnitToString =
+				"interface I {\n" +
+				"  int product(int x, int y);\n" +
+				"}\n" +
+				"public class X {\n" +
+				"  public X() {\n" +
+				"    super();\n" +
+				"  }\n" +
+				"  static I getI() {\n" +
+				"    return ((<no type> x, <no type> y) -> (x * y));\n" +
+				"  }\n" +
+				"  public static void main(String[] args) {\n" +
+				"    I i = getI();\n" +
+				"    System.out.println(i.product(5, 6));\n" +
+				"  }\n" +
 				"}\n";
 		checkParse(CHECK_PARSER | CHECK_JAVAC_PARSER , source.toCharArray(), null, "test0015", expectedUnitToString);
 	}
 	// multi parameter type specified list + block body lambda in return statement.
 	public void test0016() throws IOException {
-		String source = 
+		String source =
 				"interface I {\n" +
 				"    int product(int x, int y);\n" +
 				"}\n" +
@@ -534,29 +535,29 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 				"    }\n" +
 				"}\n";
 
-		String expectedUnitToString = 
-				"interface I {\n" + 
-				"  int product(int x, int y);\n" + 
-				"}\n" + 
-				"public class X {\n" + 
-				"  public X() {\n" + 
-				"    super();\n" + 
-				"  }\n" + 
-				"  static I getI() {\n" + 
-				"    return (int x, int y) -> {\n" + 
-				"  return (x * y);\n" + 
-				"};\n" + 
-				"  }\n" + 
-				"  public static void main(String[] args) {\n" + 
-				"    I i = getI();\n" + 
-				"    System.out.println(i.product(5, 6));\n" + 
-				"  }\n" + 
+		String expectedUnitToString =
+				"interface I {\n" +
+				"  int product(int x, int y);\n" +
+				"}\n" +
+				"public class X {\n" +
+				"  public X() {\n" +
+				"    super();\n" +
+				"  }\n" +
+				"  static I getI() {\n" +
+				"    return (int x, int y) -> {\n" +
+				"  return (x * y);\n" +
+				"};\n" +
+				"  }\n" +
+				"  public static void main(String[] args) {\n" +
+				"    I i = getI();\n" +
+				"    System.out.println(i.product(5, 6));\n" +
+				"  }\n" +
 				"}\n";
 		checkParse(CHECK_PARSER | CHECK_JAVAC_PARSER , source.toCharArray(), null, "test0016", expectedUnitToString);
 	}
-	// noarg + block body lambda 
+	// noarg + block body lambda
 	public void test0017() throws IOException {
-		String source = 
+		String source =
 				"interface I {\n" +
 				"    String noarg();\n" +
 				"}\n" +
@@ -566,25 +567,25 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 				"    }\n" +
 				"}\n";
 
-		String expectedUnitToString = 
-				"interface I {\n" + 
-				"  String noarg();\n" + 
-				"}\n" + 
-				"public class X {\n" + 
-				"  public X() {\n" + 
-				"    super();\n" + 
-				"  }\n" + 
-				"  public static void main(String[] args) {\n" + 
-				"    System.out.println(((I) () -> {\n" + 
-				"  return \"noarg\";\n" + 
-				"}).noarg());\n" + 
-				"  }\n" + 
+		String expectedUnitToString =
+				"interface I {\n" +
+				"  String noarg();\n" +
+				"}\n" +
+				"public class X {\n" +
+				"  public X() {\n" +
+				"    super();\n" +
+				"  }\n" +
+				"  public static void main(String[] args) {\n" +
+				"    System.out.println(((I) () -> {\n" +
+				"  return \"noarg\";\n" +
+				"}).noarg());\n" +
+				"  }\n" +
 				"}\n";
 		checkParse(CHECK_PARSER | CHECK_JAVAC_PARSER , source.toCharArray(), null, "test0017", expectedUnitToString);
 	}
 	// Assorted tests.
 	public void test0018() throws IOException {
-		String source = 
+		String source =
 				"interface I {\n" +
 				"    void foo();\n" +
 				"}\n" +
@@ -607,44 +608,44 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 				"    }\n" +
 				"  };\n" +
 				"}\n";
-		String expectedUnitToString = 
-				"interface I {\n" + 
-				"  void foo();\n" + 
-				"}\n" + 
-				"interface J {\n" + 
-				"  int foo();\n" + 
-				"}\n" + 
-				"public class X {\n" + 
-				"  I i1 = () ->   {\n" + 
-				"  };\n" + 
-				"  J j1 = () -> 0;\n" + 
-				"  J j2 = () ->   {\n" + 
-				"    return 0;\n" + 
-				"  };\n" + 
-				"  I i2 = () ->   {\n" + 
-				"    System.gc();\n" + 
-				"  };\n" + 
-				"  J j3 = () ->   {\n" + 
-				"    if (true)\n" + 
-				"        return 0;\n" + 
-				"    else\n" + 
-				"        {\n" + 
-				"          int r = 12;\n" + 
-				"          for (int i = 1;; (i < 8); i ++) \n" + 
-				"            r += i;\n" + 
-				"          return r;\n" + 
-				"        }\n" + 
-				"  };\n" + 
-				"  public X() {\n" + 
-				"    super();\n" + 
-				"  }\n" + 
+		String expectedUnitToString =
+				"interface I {\n" +
+				"  void foo();\n" +
+				"}\n" +
+				"interface J {\n" +
+				"  int foo();\n" +
+				"}\n" +
+				"public class X {\n" +
+				"  I i1 = () ->   {\n" +
+				"  };\n" +
+				"  J j1 = () -> 0;\n" +
+				"  J j2 = () ->   {\n" +
+				"    return 0;\n" +
+				"  };\n" +
+				"  I i2 = () ->   {\n" +
+				"    System.gc();\n" +
+				"  };\n" +
+				"  J j3 = () ->   {\n" +
+				"    if (true)\n" +
+				"        return 0;\n" +
+				"    else\n" +
+				"        {\n" +
+				"          int r = 12;\n" +
+				"          for (int i = 1;; (i < 8); i ++) \n" +
+				"            r += i;\n" +
+				"          return r;\n" +
+				"        }\n" +
+				"  };\n" +
+				"  public X() {\n" +
+				"    super();\n" +
+				"  }\n" +
 				"}\n";
 		checkParse(CHECK_PARSER | CHECK_JAVAC_PARSER , source.toCharArray(), null, "test0018", expectedUnitToString);
 	}
 
 	// like test0001() but body expression is an assignment
 	public void test0019() throws IOException {
-		String source = 
+		String source =
 				"interface I {\n" +
 						"    int square(int x);\n" +
 						"}\n" +
@@ -654,28 +655,28 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 						"        System.out.println(((I) x -> y = x * x ).square(10));\n" +
 						"    }\n" +
 						"}\n";
-		
-		String expectedUnitToString = 
-				"interface I {\n" + 
-						"  int square(int x);\n" + 
-						"}\n" + 
-						"public class X {\n" + 
+
+		String expectedUnitToString =
+				"interface I {\n" +
+						"  int square(int x);\n" +
+						"}\n" +
+						"public class X {\n" +
 						"  int y;\n" +
-						"  public X() {\n" + 
-						"    super();\n" + 
-						"  }\n" + 
-						"  public static void main(String[] args) {\n" + 
-						"    System.out.println(((I) (<no type> x) -> y = (x * x)).square(10));\n" + 
-						"  }\n" + 
+						"  public X() {\n" +
+						"    super();\n" +
+						"  }\n" +
+						"  public static void main(String[] args) {\n" +
+						"    System.out.println(((I) (<no type> x) -> y = (x * x)).square(10));\n" +
+						"  }\n" +
 						"}\n";
 		checkParse(CHECK_PARSER | CHECK_JAVAC_PARSER , source.toCharArray(), null, "test0019", expectedUnitToString);
 	}
-	
+
 	// Coverage:  exercise this condition in Parser.consumeExpression():
 	//   if (this.valueLambdaNestDepth >= 0 && this.stateStackLengthStack[this.valueLambdaNestDepth] == this.stateStackTop - 1)
 	// make sure we see a (true && false) combination
 	public void testNestedLambda01() throws IOException {
-		String source = 
+		String source =
 				"public class C {\n" +
 				"	I foo() {\n" +
 				"		return (i1, i2) -> 	(String x1, String x2) -> { \n" +
@@ -687,7 +688,7 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 				"interface I {\n" +
 				"	String doit(String s1, String s2);\n" +
 				"}\n";
-		String expectedUnitToString = 
+		String expectedUnitToString =
 				"public class C {\n" +
 				"  public C() {\n" +
 				"    super();\n" +
@@ -706,14 +707,14 @@ public class LambdaExpressionSyntaxTest extends AbstractSyntaxTreeTest {
 	// https://bugs.eclipse.org/bugs/show_bug.cgi?id=385132
 	public void test385132() throws IOException {
 		String source = "->";
-		String expectedErrorString = 
+		String expectedErrorString =
 				"----------\n" +
 				"1. ERROR in test385132 (at line 1)\n" +
 				"	->\n" +
 				"	^^\n" +
 				"Syntax error on token \"->\", delete this token\n" +
 				"----------\n";
-				
+
 		checkParse(CHECK_PARSER , source.toCharArray(), expectedErrorString, "test385132", null);
 	}
 }
