@@ -301,20 +301,20 @@ public void testAfterEmptyAnonymous() {
 		// completeBehind:
 		"fred(new Runnable() {}, ",
 		// expectedCompletionNodeToString:
-		"<CompleteOnMessageSend:this.fred(new Runnable() {\n})>",
+		"<CompleteOnName:>",
 		// expectedUnitDisplayString:
 		"class Bar {\n" +
 		"  Bar() {\n" +
 		"  }\n" +
 		"  void foo() {\n" +
-		"    <CompleteOnMessageSend:this.fred(new Runnable() {\n" +
-		"})>;\n" +
+		"    this.fred(new Runnable() {\n" +
+		"}, <CompleteOnName:>, i);\n" +
 		"  }\n" +
 		"}\n",
 		// expectedCompletionIdentifier:
 		"",
 		// expectedReplacedSource:
-		"fred(new Runnable() {}, ",
+		"",
 		// test name
 		"<completion just before second parameter, the first parameter being an empty anonymous class>"
 	);
@@ -364,19 +364,19 @@ public void testBeforeFirstParameter() {
 		// completeBehind:
 		"fred(",
 		// expectedCompletionNodeToString:
-		"<CompleteOnMessageSend:this.fred()>",
+		"<CompleteOnMessageSend:this.fred(<CompleteOnName:>, 2, i)>",
 		// expectedUnitDisplayString:
 		"class Bar {\n" +
 		"  Bar() {\n" +
 		"  }\n" +
 		"  void foo() {\n" +
-		"    <CompleteOnMessageSend:this.fred()>;\n" +
+		"    <CompleteOnMessageSend:this.fred(<CompleteOnName:>, 2, i)>;\n" +
 		"  }\n" +
 		"}\n",
 		// expectedCompletionIdentifier:
 		"",
 		// expectedReplacedSource:
-		"fred(",
+		"fred(1, 2, i)",
 		// test name
 		"<completion just before first parameter>"
 	);
@@ -426,19 +426,19 @@ public void testBeforeSecondParameter() {
 		// completeBehind:
 		"fred(1, ",
 		// expectedCompletionNodeToString:
-		"<CompleteOnMessageSend:this.fred(1)>",
+		"<CompleteOnName:>",
 		// expectedUnitDisplayString:
 		"class Bar {\n" +
 		"  Bar() {\n" +
 		"  }\n" +
 		"  void foo() {\n" +
-		"    <CompleteOnMessageSend:this.fred(1)>;\n" +
+		"    this.fred(1, <CompleteOnName:>, i);\n" +
 		"  }\n" +
 		"}\n",
 		// expectedCompletionIdentifier:
 		"",
 		// expectedReplacedSource:
-		"fred(1, ",
+		"",
 		// test name
 		"<completion just before second parameter>"
 	);
@@ -463,7 +463,7 @@ public void testEmptyInFirstParameter() {
 		"  Bar() {\n" +
 		"  }\n" +
 		"  void foo() {\n" +
-		"    (\"abc\" + <CompleteOnName:>);\n" +
+		"    this.fred((\"abc\" + <CompleteOnName:>), 2, i);\n" +
 		"  }\n" +
 		"}\n",
 		// expectedCompletionIdentifier:
@@ -494,7 +494,7 @@ public void testInFirstParameter() {
 		"  Bar() {\n" +
 		"  }\n" +
 		"  void foo() {\n" +
-		"    (\"abc\" + <CompleteOnName:bi>);\n" +
+		"    this.fred((\"abc\" + <CompleteOnName:bi>), 2, i);\n" +
 		"  }\n" +
 		"}\n",
 		// expectedCompletionIdentifier:
@@ -527,15 +527,16 @@ public void testInIfStatement() {
 		"  X() {\n" +
 		"  }\n" +
 		"  void foo() {\n" +
-		"    {\n" +
-		"      <CompleteOnMessageSend:bar.fred()>;\n" +
-		"    }\n" +
+		"    if (true)\n" +
+		"        {\n" +
+		"          <CompleteOnMessageSend:bar.fred()>;\n" +
+		"        }\n" +
 		"  }\n" +
 		"}\n",
 		// expectedCompletionIdentifier:
 		"",
 		// expectedReplacedSource:
-		"fred(",
+		"fred()",
 		// test name
 		"<completion inside a if statement>"
 	);
@@ -651,19 +652,19 @@ public void testSpaceThenFirstParameter() {
 		// completeBehind:
 		"fred( ",
 		// expectedCompletionNodeToString:
-		"<CompleteOnMessageSend:this.fred()>",
+		"<CompleteOnName:>",
 		// expectedUnitDisplayString:
 		"class Bar {\n" +
 		"  Bar() {\n" +
 		"  }\n" +
 		"  void foo() {\n" +
-		"    <CompleteOnMessageSend:this.fred()>;\n" +
+		"    this.fred(<CompleteOnName:>, 2, i);\n" +
 		"  }\n" +
 		"}\n",
 		// expectedCompletionIdentifier:
 		"",
 		// expectedReplacedSource:
-		"fred( ",
+		"",
 		// test name
 		"<completion just before first parameter with a space after open parenthesis>"
 	);
@@ -725,7 +726,7 @@ public void testWithExpressionReceiver() {
 		// expectedCompletionIdentifier:
 		"",
 		// expectedReplacedSource:
-		"fred(",
+		"fred()",
 		// test name
 		"<completion on method invocation with expression receiver>"
 	);
