@@ -41,7 +41,7 @@ public SourcePackage(
  */
 @Override
 public String toString() {
-	StringBuffer buffer = new StringBuffer();
+	StringBuilder buffer = new StringBuilder();
 	buffer
 		.append(
 			this.source,
