@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2003, 2020 IBM Corporation and others.
+ * Copyright (c) 2003, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -45,7 +45,7 @@ public ConstantTest(String name) {
 // All specified tests which does not belong to the class are skipped...
 static {
 //	TESTS_PREFIX = "testBug95521";
-//	TESTS_NAMES = new String[] { "testBug83127a" };
+//	TESTS_NAMES = new String[] { "testBug566332_01" };
 //	TESTS_NUMBERS = new int[] { 21 };
 //	TESTS_RANGE = new int[] { 23, -1 };
 }
@@ -1101,6 +1101,9 @@ public void test019() {
 // http://bugs.eclipse.org/bugs/show_bug.cgi?id=154822
 // null is not a constant - again
 public void test020() {
+	if (this.complianceLevel >= ClassFileConstants.JDK16) {
+		return;
+	}
 	this.runNegativeTest(
 		new String[] {
 			"X.java",
@@ -1604,6 +1607,25 @@ public void testBug566332_04() {
 			"case expressions must be constant expressions\n" +
 			"----------\n");
 }
+public void testBug569498() {
+	if (this.complianceLevel < ClassFileConstants.JDK11) {
+		return;
+	}
+	this.runNegativeTest(
+			new String[] {
+				"X.java",
+				"public class X {\n"
+				+ "	final String s1 = \"\";\n"
+				+ "	public void m(Object s) {\n"
+				+ "		final boolean b = false;\n"
+				+ "		final String s2 = \"\";\n"
+				+ "		m(b? s1 : s2);\n"
+				+ "	}\n"
+				+ "    public static void main(String[] args) {}\n"
+				+ "}",
+			},
+			"");
+}
 public static Class testClass() {
 	return ConstantTest.class;
 }
