@@ -7,7 +7,7 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- * 
+ *
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *     Jesper S Moller - realigned with bug 399695
@@ -37,6 +37,7 @@ public static Test suite() {
 	return buildMinimalComplianceTestSuite(testClass(), F_1_8);
 }
 
+@Override
 protected Map getCompilerOptions() {
 	Map defaultOptions = super.getCompilerOptions();
 	defaultOptions.put(CompilerOptions.OPTION_ReportUnnecessaryTypeCheck, CompilerOptions.WARNING);
@@ -59,11 +60,11 @@ public void test001() {
 				"	Object p = (I) () -> {};\n" +
 				"}\n",
 			},
-			"----------\n" + 
-			"1. ERROR in X.java (at line 6)\n" + 
-			"	Object o = () -> {};\n" + 
+			"----------\n" +
+			"1. ERROR in X.java (at line 6)\n" +
+			"	Object o = () -> {};\n" +
 			"	           ^^^^^\n" +
-			"The target type of this expression must be a functional interface\n" + 
+			"The target type of this expression must be a functional interface\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=399773, [1.8][compiler] Cast expression should allow for additional bounds to form intersection types
@@ -101,16 +102,16 @@ public void test003() {
 				"	Object p = (int & I & J) () -> {};\n" +
 				"}\n" ,
 			},
-			"----------\n" + 
-			"1. ERROR in X.java (at line 10)\n" + 
-			"	Object p = (int & I & J) () -> {};\n" + 
-			"	            ^^^\n" + 
-			"Base types are not allowed in intersection cast operator\n" + 
-			"----------\n" + 
-			"2. ERROR in X.java (at line 10)\n" + 
-			"	Object p = (int & I & J) () -> {};\n" + 
+			"----------\n" +
+			"1. ERROR in X.java (at line 10)\n" +
+			"	Object p = (int & I & J) () -> {};\n" +
+			"	            ^^^\n" +
+			"Base types are not allowed in intersection cast operator\n" +
+			"----------\n" +
+			"2. ERROR in X.java (at line 10)\n" +
+			"	Object p = (int & I & J) () -> {};\n" +
 			"	                         ^^^^^\n" +
-			"The target type of this expression must be a functional interface\n" + 
+			"The target type of this expression must be a functional interface\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=399773, [1.8][compiler] Cast expression should allow for additional bounds to form intersection types
@@ -130,16 +131,16 @@ public void test004() {
 				"	Object p = (X[] & Serializable & Cloneable) new X[0];\n" +
 				"}\n" ,
 			},
-			"----------\n" + 
-			"1. ERROR in X.java (at line 10)\n" + 
-			"	Object p = (X[] & Serializable & Cloneable) new X[0];\n" + 
-			"	            ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\n" + 
-			"Arrays are not allowed in intersection cast operator\n" + 
-			"----------\n" + 
-			"2. ERROR in X.java (at line 10)\n" + 
-			"	Object p = (X[] & Serializable & Cloneable) new X[0];\n" + 
-			"	                  ^^^^^^^^^^^^\n" + 
-			"Serializable cannot be resolved to a type\n" + 
+			"----------\n" +
+			"1. ERROR in X.java (at line 10)\n" +
+			"	Object p = (X[] & Serializable & Cloneable) new X[0];\n" +
+			"	            ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\n" +
+			"Arrays are not allowed in intersection cast operator\n" +
+			"----------\n" +
+			"2. ERROR in X.java (at line 10)\n" +
+			"	Object p = (X[] & Serializable & Cloneable) new X[0];\n" +
+			"	                  ^^^^^^^^^^^^\n" +
+			"Serializable cannot be resolved to a type\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=399773, [1.8][compiler] Cast expression should allow for additional bounds to form intersection types
@@ -159,16 +160,16 @@ public void test005() {
 				"	Object p = (I & X) () -> {};\n" +
 				"}\n" ,
 			},
-			"----------\n" + 
-			"1. ERROR in X.java (at line 10)\n" + 
-			"	Object p = (I & X) () -> {};\n" + 
-			"	                ^\n" + 
-			"The type X is not an interface; it cannot be specified as a bounded parameter\n" + 
-			"----------\n" + 
-			"2. ERROR in X.java (at line 10)\n" + 
-			"	Object p = (I & X) () -> {};\n" + 
+			"----------\n" +
+			"1. ERROR in X.java (at line 10)\n" +
+			"	Object p = (I & X) () -> {};\n" +
+			"	                ^\n" +
+			"The type X is not an interface; it cannot be specified as a bounded parameter\n" +
+			"----------\n" +
+			"2. ERROR in X.java (at line 10)\n" +
+			"	Object p = (I & X) () -> {};\n" +
 			"	                   ^^^^^\n" +
-			"The target type of this expression must be a functional interface\n" + 
+			"The target type of this expression must be a functional interface\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=399773, [1.8][compiler] Cast expression should allow for additional bounds to form intersection types
@@ -188,16 +189,16 @@ public void test006() {
 				"	Object p = (I & J & I) () -> {};\n" +
 				"}\n" ,
 			},
-			"----------\n" + 
-			"1. ERROR in X.java (at line 10)\n" + 
-			"	Object p = (I & J & I) () -> {};\n" + 
-			"	                    ^\n" + 
-			"Duplicate type in intersection cast operator\n" + 
-			"----------\n" + 
-			"2. ERROR in X.java (at line 10)\n" + 
-			"	Object p = (I & J & I) () -> {};\n" + 
+			"----------\n" +
+			"1. ERROR in X.java (at line 10)\n" +
+			"	Object p = (I & J & I) () -> {};\n" +
+			"	                    ^\n" +
+			"Duplicate type in intersection cast operator\n" +
+			"----------\n" +
+			"2. ERROR in X.java (at line 10)\n" +
+			"	Object p = (I & J & I) () -> {};\n" +
 			"	                       ^^^^^\n" +
-			"The target type of this expression must be a functional interface\n" + 
+			"The target type of this expression must be a functional interface\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=399773, [1.8][compiler] Cast expression should allow for additional bounds to form intersection types
@@ -216,11 +217,11 @@ public void test007() {
 				"	I<X> i2 = (List<String> p) -> {};\n" +
 				"}\n",
 			},
-			"----------\n" + 
-			"1. ERROR in X.java (at line 9)\n" + 
-			"	I<X> i2 = (List<String> p) -> {};\n" + 
-			"	           ^^^^\n" + 
-			"Lambda expression\'s parameter p is expected to be of type List<X>\n" + 
+			"----------\n" +
+			"1. ERROR in X.java (at line 9)\n" +
+			"	I<X> i2 = (List<String> p) -> {};\n" +
+			"	           ^^^^\n" +
+			"Lambda expression\'s parameter p is expected to be of type List<X>\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=399773, [1.8][compiler] Cast expression should allow for additional bounds to form intersection types
@@ -240,26 +241,26 @@ public void test008() {
 				"	Object p = (@Marker java.lang. @Readonly String & I & J) () -> {};\n" +
 				"}\n" ,
 			},
-			"----------\n" + 
-			"1. ERROR in X.java (at line 10)\n" + 
-			"	Object p = (@Marker java.lang. @Readonly String & I & J) () -> {};\n" + 
-			"	            ^^^^^^^\n" + 
-			"Illegally placed annotation: type annotations must directly precede the simple name of the type they are meant to affect (or the [] for arrays)\n" + 
-			"----------\n" + 
-			"2. ERROR in X.java (at line 10)\n" + 
-			"	Object p = (@Marker java.lang. @Readonly String & I & J) () -> {};\n" + 
-			"	             ^^^^^^\n" + 
-			"Marker cannot be resolved to a type\n" + 
-			"----------\n" + 
-			"3. ERROR in X.java (at line 10)\n" + 
-			"	Object p = (@Marker java.lang. @Readonly String & I & J) () -> {};\n" + 
-			"	                                ^^^^^^^^\n" + 
-			"Readonly cannot be resolved to a type\n" + 
-			"----------\n" + 
-			"4. ERROR in X.java (at line 10)\n" + 
-			"	Object p = (@Marker java.lang. @Readonly String & I & J) () -> {};\n" + 
-			"	                                                         ^^^^^\n" + 
-			"The target type of this expression must be a functional interface\n" + 
+			"----------\n" +
+			"1. ERROR in X.java (at line 10)\n" +
+			"	Object p = (@Marker java.lang. @Readonly String & I & J) () -> {};\n" +
+			"	            ^^^^^^^\n" +
+			"Illegally placed annotation: type annotations must directly precede the simple name of the type they are meant to affect (or the [] for arrays)\n" +
+			"----------\n" +
+			"2. ERROR in X.java (at line 10)\n" +
+			"	Object p = (@Marker java.lang. @Readonly String & I & J) () -> {};\n" +
+			"	             ^^^^^^\n" +
+			"Marker cannot be resolved to a type\n" +
+			"----------\n" +
+			"3. ERROR in X.java (at line 10)\n" +
+			"	Object p = (@Marker java.lang. @Readonly String & I & J) () -> {};\n" +
+			"	                                ^^^^^^^^\n" +
+			"Readonly cannot be resolved to a type\n" +
+			"----------\n" +
+			"4. ERROR in X.java (at line 10)\n" +
+			"	Object p = (@Marker java.lang. @Readonly String & I & J) () -> {};\n" +
+			"	                                                         ^^^^^\n" +
+			"The target type of this expression must be a functional interface\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=399773, [1.8][compiler] Cast expression should allow for additional bounds to form intersection types
@@ -280,11 +281,11 @@ public void test009() {
 				"	I<X> i2 = (Map<String, String> & I<X>) null;\n" +
 				"}\n",
 			},
-			"----------\n" + 
-			"1. WARNING in X.java (at line 9)\n" + 
-			"	I<X> i2 = (Map<String, String> & I<X>) null;\n" + 
-			"	          ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\n" + 
-			"Unnecessary cast from null to I<X> & Map<String,String>\n" + 
+			"----------\n" +
+			"1. WARNING in X.java (at line 9)\n" +
+			"	I<X> i2 = (Map<String, String> & I<X>) null;\n" +
+			"	          ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\n" +
+			"Unnecessary cast from null to I<X> & Map<String,String>\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=399773, [1.8][compiler] Cast expression should allow for additional bounds to form intersection types
@@ -303,16 +304,16 @@ public void test010() {
 				"	I<X> i2 = (Map<String, String>.Entry & I<X> & Serializable) null;\n" +
 				"}\n",
 			},
-			"----------\n" + 
-			"1. ERROR in X.java (at line 9)\n" + 
-			"	I<X> i2 = (Map<String, String>.Entry & I<X> & Serializable) null;\n" + 
-			"	           ^^^^^^^^^^^^^^^^^^^^^^^^^\n" + 
-			"The member type Map.Entry<K,V> cannot be qualified with a parameterized type, since it is static. Remove arguments from qualifying type Map<String,String>\n" + 
-			"----------\n" + 
-			"2. ERROR in X.java (at line 9)\n" + 
-			"	I<X> i2 = (Map<String, String>.Entry & I<X> & Serializable) null;\n" + 
-			"	                                              ^^^^^^^^^^^^\n" + 
-			"Serializable cannot be resolved to a type\n" + 
+			"----------\n" +
+			"1. ERROR in X.java (at line 9)\n" +
+			"	I<X> i2 = (Map<String, String>.Entry & I<X> & Serializable) null;\n" +
+			"	           ^^^^^^^^^^^^^^^^^^^^^^^^^\n" +
+			"The member type Map.Entry<K,V> cannot be qualified with a parameterized type, since it is static. Remove arguments from qualifying type Map<String,String>\n" +
+			"----------\n" +
+			"2. ERROR in X.java (at line 9)\n" +
+			"	I<X> i2 = (Map<String, String>.Entry & I<X> & Serializable) null;\n" +
+			"	                                              ^^^^^^^^^^^^\n" +
+			"Serializable cannot be resolved to a type\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=399773, [1.8][compiler] Cast expression should allow for additional bounds to form intersection types
@@ -332,11 +333,11 @@ public void test011() {
 				"class Y {\n" +
 				"}\n",
 			},
-			"----------\n" + 
-			"1. ERROR in X.java (at line 8)\n" + 
-			"	X X = (X & J & K) new Y();\n" + 
-			"	      ^^^^^^^^^^^^^^^^^^^\n" + 
-			"Cannot cast from Y to X & J & K\n" + 
+			"----------\n" +
+			"1. ERROR in X.java (at line 8)\n" +
+			"	X X = (X & J & K) new Y();\n" +
+			"	      ^^^^^^^^^^^^^^^^^^^\n" +
+			"Cannot cast from Y to X & J & K\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=399773, [1.8][compiler] Cast expression should allow for additional bounds to form intersection types
@@ -356,16 +357,16 @@ public void test012() {
 				"class Y extends X implements Zork {\n" +
 				"}\n",
 			},
-			"----------\n" + 
-			"1. WARNING in X.java (at line 8)\n" + 
-			"	X X = (X & J & K) new Y();\n" + 
-			"	      ^^^^^^^^^^^^^^^^^^^\n" + 
-			"Unnecessary cast from Y to X & J & K\n" + 
-			"----------\n" + 
-			"2. ERROR in X.java (at line 10)\n" + 
-			"	class Y extends X implements Zork {\n" + 
-			"	                             ^^^^\n" + 
-			"Zork cannot be resolved to a type\n" + 
+			"----------\n" +
+			"1. WARNING in X.java (at line 8)\n" +
+			"	X X = (X & J & K) new Y();\n" +
+			"	      ^^^^^^^^^^^^^^^^^^^\n" +
+			"Unnecessary cast from Y to X & J & K\n" +
+			"----------\n" +
+			"2. ERROR in X.java (at line 10)\n" +
+			"	class Y extends X implements Zork {\n" +
+			"	                             ^^^^\n" +
+			"Zork cannot be resolved to a type\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=399773, [1.8][compiler] Cast expression should allow for additional bounds to form intersection types
@@ -385,16 +386,16 @@ public void test013() {
 				"final class Y extends X {\n" +
 				"}\n",
 			},
-			"----------\n" + 
-			"1. ERROR in X.java (at line 8)\n" + 
-			"	X X = (X & J & K) new Y();\n" + 
-			"	      ^^^^^^^^^^^^^^^^^^^\n" + 
-			"Cannot cast from Y to X & J & K\n" + 
-			"----------\n" + 
-			"2. WARNING in X.java (at line 8)\n" + 
-			"	X X = (X & J & K) new Y();\n" + 
-			"	      ^^^^^^^^^^^^^^^^^^^\n" + 
-			"Unnecessary cast from Y to X & J & K\n" + 
+			"----------\n" +
+			"1. ERROR in X.java (at line 8)\n" +
+			"	X X = (X & J & K) new Y();\n" +
+			"	      ^^^^^^^^^^^^^^^^^^^\n" +
+			"Cannot cast from Y to X & J & K\n" +
+			"----------\n" +
+			"2. WARNING in X.java (at line 8)\n" +
+			"	X X = (X & J & K) new Y();\n" +
+			"	      ^^^^^^^^^^^^^^^^^^^\n" +
+			"Unnecessary cast from Y to X & J & K\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=399773, [1.8][compiler] Cast expression should allow for additional bounds to form intersection types
@@ -415,11 +416,11 @@ public void test014() {
 				"final class Y extends P {\n" +
 				"}\n",
 			},
-			"----------\n" + 
-			"1. ERROR in X.java (at line 11)\n" + 
-			"	final class Y extends P {\n" + 
-			"	                      ^\n" + 
-			"P cannot be resolved to a type\n" + 
+			"----------\n" +
+			"1. ERROR in X.java (at line 11)\n" +
+			"	final class Y extends P {\n" +
+			"	                      ^\n" +
+			"P cannot be resolved to a type\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=399773, [1.8][compiler] Cast expression should allow for additional bounds to form intersection types
@@ -439,16 +440,16 @@ public void test015() {
 				"   Zork z;\n" +
 				"}\n",
 			},
-			"----------\n" + 
-			"1. ERROR in X.java (at line 9)\n" + 
-			"	X X = (X & J & K) i;\n" + 
-			"	      ^^^^^^^^^^^^^\n" + 
-			"Cannot cast from I to X & J & K\n" + 
-			"----------\n" + 
-			"2. ERROR in X.java (at line 10)\n" + 
-			"	Zork z;\n" + 
-			"	^^^^\n" + 
-			"Zork cannot be resolved to a type\n" + 
+			"----------\n" +
+			"1. ERROR in X.java (at line 9)\n" +
+			"	X X = (X & J & K) i;\n" +
+			"	      ^^^^^^^^^^^^^\n" +
+			"Cannot cast from I to X & J & K\n" +
+			"----------\n" +
+			"2. ERROR in X.java (at line 10)\n" +
+			"	Zork z;\n" +
+			"	^^^^\n" +
+			"Zork cannot be resolved to a type\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=399773, [1.8][compiler] Cast expression should allow for additional bounds to form intersection types
@@ -468,11 +469,11 @@ public void test016() {
 				"   Zork z;\n" +
 				"}\n",
 			},
-			"----------\n" + 
-			"1. ERROR in X.java (at line 10)\n" + 
-			"	Zork z;\n" + 
-			"	^^^^\n" + 
-			"Zork cannot be resolved to a type\n" + 
+			"----------\n" +
+			"1. ERROR in X.java (at line 10)\n" +
+			"	Zork z;\n" +
+			"	^^^^\n" +
+			"Zork cannot be resolved to a type\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=399773, [1.8][compiler] Cast expression should allow for additional bounds to form intersection types
@@ -492,16 +493,16 @@ public void test017() {
 				"   Zork z;\n" +
 				"}\n",
 			},
-			"----------\n" + 
-			"1. WARNING in X.java (at line 9)\n" + 
-			"	X X = (X & J & K) (X & K & J) i;\n" + 
-			"	      ^^^^^^^^^^^^^^^^^^^^^^^^^\n" + 
-			"Unnecessary cast from X & K & J to X & J & K\n" + 
-			"----------\n" + 
-			"2. ERROR in X.java (at line 10)\n" + 
-			"	Zork z;\n" + 
-			"	^^^^\n" + 
-			"Zork cannot be resolved to a type\n" + 
+			"----------\n" +
+			"1. WARNING in X.java (at line 9)\n" +
+			"	X X = (X & J & K) (X & K & J) i;\n" +
+			"	      ^^^^^^^^^^^^^^^^^^^^^^^^^\n" +
+			"Unnecessary cast from X & K & J to X & J & K\n" +
+			"----------\n" +
+			"2. ERROR in X.java (at line 10)\n" +
+			"	Zork z;\n" +
+			"	^^^^\n" +
+			"Zork cannot be resolved to a type\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=399778, [1.8][compiler] Conditional operator expressions should propagate target types
@@ -521,11 +522,11 @@ public void test018() {
 				"	I j = () -> {};\n" +
 				"}\n",
 			},
-			"----------\n" + 
-			"1. WARNING in X.java (at line 7)\n" + 
-			"	I i = 1 == 2 ? () -> {} : () -> {};\n" + 
-			"	               ^^^^^^^^\n" + 
-			"Dead code\n" + 
+			"----------\n" +
+			"1. WARNING in X.java (at line 7)\n" +
+			"	I i = 1 == 2 ? () -> {} : () -> {};\n" +
+			"	               ^^^^^^^^\n" +
+			"Dead code\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=399778, [1.8][compiler] Conditional operator expressions should propagate target types
@@ -546,16 +547,16 @@ public void test019() {
 			    "   }\n" +
 				"}\n",
 			},
-			"----------\n" + 
-			"1. WARNING in X.java (at line 5)\n" + 
-			"	I [] k = {(()->{}), ()->{}, 1 == 2 ? () -> {} : ()->{}};\n" + 
-			"	                                     ^^^^^^^^\n" + 
-			"Dead code\n" + 
-			"----------\n" + 
-			"2. WARNING in X.java (at line 8)\n" + 
-			"	I i = () -> {};\n" + 
-			"	  ^\n" + 
-			"The local variable i is hiding a field from type X\n" + 
+			"----------\n" +
+			"1. WARNING in X.java (at line 5)\n" +
+			"	I [] k = {(()->{}), ()->{}, 1 == 2 ? () -> {} : ()->{}};\n" +
+			"	                                     ^^^^^^^^\n" +
+			"Dead code\n" +
+			"----------\n" +
+			"2. WARNING in X.java (at line 8)\n" +
+			"	I i = () -> {};\n" +
+			"	  ^\n" +
+			"The local variable i is hiding a field from type X\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=399778, [1.8][compiler] Conditional operator expressions should propagate target types
@@ -578,11 +579,11 @@ public void test020() {
 			    "   }\n" +
 				"}\n",
 			},
-			"----------\n" + 
-			"1. ERROR in X.java (at line 11)\n" + 
-			"	return x -> { return () -> () -> \"Hello\"; };\n" + 
-			"	                                 ^^^^^^^\n" + 
-			"Type mismatch: cannot convert from String to I\n" + 
+			"----------\n" +
+			"1. ERROR in X.java (at line 11)\n" +
+			"	return x -> { return () -> () -> \"Hello\"; };\n" +
+			"	                                 ^^^^^^^\n" +
+			"Type mismatch: cannot convert from String to I\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=399778, [1.8][compiler] Conditional operator expressions should propagate target types
@@ -608,26 +609,26 @@ public void test021() {
 			    "   }\n" +
 				"}\n",
 			},
-			"----------\n" + 
-			"1. ERROR in X.java (at line 6)\n" + 
-			"	return \"Hello\" + () -> {};\n" + 
+			"----------\n" +
+			"1. ERROR in X.java (at line 6)\n" +
+			"	return \"Hello\" + () -> {};\n" +
 			"	                 ^^^^^\n" +
-			"The target type of this expression must be a functional interface\n" + 
-			"----------\n" + 
-			"2. ERROR in X.java (at line 9)\n" + 
-			"	return \"Hello\" + (I)(() -> {});\n" + 
-			"	       ^^^^^^^^^^^^^^^^^^^^^^^\n" + 
-			"Type mismatch: cannot convert from String to I\n" + 
-			"----------\n" + 
-			"3. ERROR in X.java (at line 12)\n" + 
-			"	return 10 + (() -> {});\n" + 
+			"The target type of this expression must be a functional interface\n" +
+			"----------\n" +
+			"2. ERROR in X.java (at line 9)\n" +
+			"	return \"Hello\" + (I)(() -> {});\n" +
+			"	       ^^^^^^^^^^^^^^^^^^^^^^^\n" +
+			"Type mismatch: cannot convert from String to I\n" +
+			"----------\n" +
+			"3. ERROR in X.java (at line 12)\n" +
+			"	return 10 + (() -> {});\n" +
 			"	            ^^^^^^\n" +
-			"The target type of this expression must be a functional interface\n" + 
-			"----------\n" + 
-			"4. ERROR in X.java (at line 15)\n" + 
-			"	return 10 + (I) (() -> {});\n" + 
-			"	       ^^^^^^^^^^^^^^^^^^^\n" + 
-			"The operator + is undefined for the argument type(s) int, I\n" + 
+			"The target type of this expression must be a functional interface\n" +
+			"----------\n" +
+			"4. ERROR in X.java (at line 15)\n" +
+			"	return 10 + (I) (() -> {});\n" +
+			"	       ^^^^^^^^^^^^^^^^^^^\n" +
+			"The operator + is undefined for the argument type(s) int, I\n" +
 			"----------\n");
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=401222, [1.8][compiler] Conditional operator expressions results differ from 8b76
@@ -645,16 +646,16 @@ public void test022() {
 				"	}\n" +
 				"}\n",
 			},
-			"----------\n" + 
-			"1. ERROR in X.java (at line 5)\n" + 
-			"	List<String> l = x == 2 ? (List<String>)(null) : 1;\n" + 
-			"	                                                 ^\n" + 
-			"Type mismatch: cannot convert from int to List<String>\n" + 
-			"----------\n" + 
-			"2. ERROR in X.java (at line 6)\n" + 
-			"	List<String> m = x == 2 ? 1 : (List<String>)(null);\n" + 
-			"	                          ^\n" + 
-			"Type mismatch: cannot convert from int to List<String>\n" + 
+			"----------\n" +
+			"1. ERROR in X.java (at line 5)\n" +
+			"	List<String> l = x == 2 ? (List<String>)(null) : 1;\n" +
+			"	                                                 ^\n" +
+			"Type mismatch: cannot convert from int to List<String>\n" +
+			"----------\n" +
+			"2. ERROR in X.java (at line 6)\n" +
+			"	List<String> m = x == 2 ? 1 : (List<String>)(null);\n" +
+			"	                          ^\n" +
+			"Type mismatch: cannot convert from int to List<String>\n" +
 			"----------\n");
 }
 public static Class testClass() {
