@@ -72,6 +72,30 @@ static final String ORG_JUNIT_ASSERT_CONTENT = "package org.junit;\n" +
 		"    static public void assertFalse(boolean expression) {}\n" +
 		"    static public void assertFalse(String message, boolean expression) {}\n" +
 		"}\n";
+static final String ORG_JUNIT_JUPITER_API_ASSERTIONS_NAME = "org/junit/jupiter/api/Assertions.java";
+static final String ORG_JUNIT_JUPITER_API_ASSERTIONS_CONTENT = "package org.junit.jupiter.api;\n" +
+		"import java.util.function.Supplier;\n" +
+		"import java.util.function.BooleanSupplier;\n" +
+		"public class Assertions {\n" +
+		"    static public void assertNull(Object object) {}\n" +
+		"    static public void assertNull(Object object, String message) {}\n" +
+		"    static public void assertNull(Object object, Supplier<String> messageSupplier) {}\n" +
+		"    static public void assertNotNull(Object object) {}\n" +
+		"    static public void assertNotNull(Object object, String message) {}\n" +
+		"    static public void assertNotNull(Object object, Supplier<String> messageSupplier) {}\n" +
+		"    static public void assertTrue(boolean expression) {}\n" +
+		"    static public void assertTrue(boolean expression, String message) {}\n" +
+		"    static public void assertTrue(boolean expression, Supplier<String> messageSupplier) {}\n" +
+		"    static public void assertTrue(BooleanSupplier booleanSupplier) {}\n" +
+		"    static public void assertTrue(BooleanSupplier booleanSupplier, String message) {}\n" +
+		"    static public void assertTrue(BooleanSupplier booleanSupplier, Supplier<String> messageSupplier) {}\n" +
+		"    static public void assertFalse(boolean expression) {}\n" +
+		"    static public void assertFalse(boolean expression, String message) {}\n" +
+		"    static public void assertFalse(boolean expression, Supplier<String> messageSupplier) {}\n" +
+		"    static public void assertFalse(BooleanSupplier booleanSupplier) {}\n" +
+		"    static public void assertFalse(BooleanSupplier booleanSupplier, String message) {}\n" +
+		"    static public void assertFalse(BooleanSupplier booleanSupplier, Supplier<String> messageSupplier) {}\n" +
+		"}\n";
 
 static final String APACHE_VALIDATE_NAME = "org/apache/commons/lang/Validate.java";
 static final String APACHE_VALIDATE_CONTENT = "package org.apache.commons.lang;\n" +
@@ -151,7 +175,9 @@ protected Map getCompilerOptions() {
 
 //https://bugs.eclipse.org/bugs/show_bug.cgi?id=127575
 public void testBug127575a() throws IOException {
-		this.runConformTest(
+	if (RUN_JAVAC && this.complianceLevel < ClassFileConstants.JDK11)
+		return; // Assert has class file format JDK 11
+	this.runConformTest(
 			new String[] {
 				"X.java",
 				"public class X {\n" +
@@ -169,6 +195,8 @@ public void testBug127575a() throws IOException {
 
 //https://bugs.eclipse.org/bugs/show_bug.cgi?id=127575
 public void testBug127575b() {
+	if (RUN_JAVAC && this.complianceLevel < ClassFileConstants.JDK11)
+		return; // Assert has class file format JDK 11
 	Runner runner = new Runner();
 	runner.testFiles =
 			new String[] {
@@ -194,6 +222,8 @@ public void testBug127575b() {
 
 //https://bugs.eclipse.org/bugs/show_bug.cgi?id=127575
 public void testBug127575c() {
+	if (RUN_JAVAC && this.complianceLevel < ClassFileConstants.JDK11)
+		return; // Assert has class file format JDK 11
 	Runner runner = new Runner();
 	runner.testFiles =
 			new String[] {
@@ -219,6 +249,8 @@ public void testBug127575c() {
 
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=127575
 public void testBug127575d() {
+	if (RUN_JAVAC && this.complianceLevel < ClassFileConstants.JDK11)
+		return; // Assert has class file format JDK 11
 	Runner runner = new Runner();
 	runner.testFiles =
 			new String[] {
@@ -255,6 +287,8 @@ public void testBug127575d() {
 
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=127575
 public void testBug127575e() {
+	if (RUN_JAVAC && this.complianceLevel < ClassFileConstants.JDK11)
+		return; // Assert has class file format JDK 11
 	Runner runner = new Runner();
 	runner.testFiles =
 			new String[] {
@@ -279,6 +313,8 @@ public void testBug127575e() {
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=127575
 public void testBug127575e_1() {
+	if (RUN_JAVAC && this.complianceLevel < ClassFileConstants.JDK11)
+		return; // Assert has class file format JDK 11
 	Runner runner = new Runner();
 	runner.testFiles =
 			new String[] {
@@ -310,6 +346,8 @@ public void testBug127575e_1() {
 
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=127575
 public void testBug127575e_2() {
+	if (RUN_JAVAC && this.complianceLevel < ClassFileConstants.JDK11)
+		return; // Assert has class file format JDK 11
 	Runner runner = new Runner();
 	runner.testFiles =
 			new String[] {
@@ -334,6 +372,8 @@ public void testBug127575e_2() {
 }
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=127575
 public void testBug127575f() {
+	if (RUN_JAVAC && this.complianceLevel < ClassFileConstants.JDK11)
+		return; // Assert has class file format JDK 11
 	Runner runner = new Runner();
 	runner.testFiles =
 			new String[] {
@@ -365,6 +405,8 @@ public void testBug127575f() {
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=127575
 // do warn always false comparisons even inside org.eclipse.core.runtime.Assert.isLegal
 public void testBug127575g() {
+	if (RUN_JAVAC && this.complianceLevel < ClassFileConstants.JDK11)
+		return; // Assert has class file format JDK 11
 	Runner runner = new Runner();
 	runner.testFiles =
 			new String[] {
@@ -403,6 +445,8 @@ public void testBug127575g() {
 // Test to verify that asserts are exempted from redundant null check warnings,
 // but this doesn't affect the downstream info.
 public void testBug127575h() {
+	if (RUN_JAVAC && this.complianceLevel < ClassFileConstants.JDK11)
+		return; // Assert has class file format JDK 11
 	Runner runner = new Runner();
 	runner.testFiles =
 			new String[] {
@@ -475,6 +519,8 @@ public void testBug127575h() {
 // Test to verify that asserts are exempted from redundant null check warnings,
 // but this doesn't affect the downstream info.
 public void testBug127575i() {
+	if (RUN_JAVAC && this.complianceLevel < ClassFileConstants.JDK11)
+		return; // Assert has class file format JDK 11
 	Runner runner = new Runner();
 	runner.testFiles =
 			new String[] {
@@ -514,6 +560,8 @@ public void testBug127575i() {
 // Test to verify that asserts are exempted from redundant null check warnings in a looping context,
 // but this doesn't affect the downstream info.
 public void testBug127575j() {
+	if (RUN_JAVAC && this.complianceLevel < ClassFileConstants.JDK11)
+		return; // Assert has class file format JDK 11
 	Runner runner = new Runner();
 	runner.testFiles =
 			new String[] {
@@ -588,6 +636,8 @@ public void testBug127575j() {
 // Test to verify that asserts are exempted from redundant null check warnings in a finally context,
 // but this doesn't affect the downstream info.
 public void testBug127575k() {
+	if (RUN_JAVAC && this.complianceLevel < ClassFileConstants.JDK11)
+		return; // Assert has class file format JDK 11
 	Runner runner = new Runner();
 	runner.testFiles =
 			new String[] {
@@ -665,6 +715,8 @@ public void testBug127575k() {
 // The condition of org.eclipse.core.runtime.Assert.isLegal is considered always true
 // and alters the following analysis suitably.
 public void testBug127575l() {
+	if (RUN_JAVAC && this.complianceLevel < ClassFileConstants.JDK11)
+		return; // Assert has class file format JDK 11
 	Runner runner = new Runner();
 	runner.testFiles =
 			new String[] {
@@ -746,6 +798,8 @@ public void testBug127575l() {
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=127575
 // NPE warnings should be given inside org.eclipse.core.runtime.Assert.isLegal too
 public void testBug127575m() {
+	if (RUN_JAVAC && this.complianceLevel < ClassFileConstants.JDK11)
+		return; // Assert has class file format JDK 11
 	if (this.complianceLevel >= ClassFileConstants.JDK1_5) {
 		Runner runner = new Runner();
 		runner.testFiles =
@@ -786,6 +840,8 @@ public void testBug127575m() {
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=127575
 // always false comparison in Assert.isLegal in loop should be warned against
 public void testBug127575n() {
+	if (RUN_JAVAC && this.complianceLevel < ClassFileConstants.JDK11)
+		return; // Assert has class file format JDK 11
 	if (this.complianceLevel >= ClassFileConstants.JDK1_5) {
 		Runner runner = new Runner();
 		runner.testFiles =
@@ -825,6 +881,8 @@ public void testBug127575n() {
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=127575
 // "redundant null check" in Assert.isLegal in loop should not be warned against
 public void testBug127575o() {
+	if (RUN_JAVAC && this.complianceLevel < ClassFileConstants.JDK11)
+		return; // Assert has class file format JDK 11
 	if (this.complianceLevel >= ClassFileConstants.JDK1_5) {
 		Runner runner = new Runner();
 		runner.testFiles =
@@ -928,6 +986,8 @@ public void testBug382069a() throws IOException {
 // https://bugs.eclipse.org/382069 - [null] Make the null analysis consider JUnit's assertNotNull similarly to assertions
 // org.eclipse.core.runtime.Assert.isNotNull
 public void testBug382069b() {
+	if (RUN_JAVAC && this.complianceLevel < ClassFileConstants.JDK11)
+		return; // Assert has class file format JDK 11
 	if (this.complianceLevel >= ClassFileConstants.JDK1_5) {
 		this.runConformTest(
 			new String[] {
@@ -1197,4 +1257,125 @@ public void testBug472618() throws IOException {
 			"}\n"},
 		"");
 }
+// https://bugs.eclipse.org/bugs/show_bug.cgi?id=568542
+// junit 5's assertNotNull
+public void testBug568542a() throws IOException {
+	if (this.complianceLevel < ClassFileConstants.JDK1_8) return; // uses Supplier
+	this.runConformTest(
+		new String[] {
+			ORG_JUNIT_JUPITER_API_ASSERTIONS_NAME,
+			ORG_JUNIT_JUPITER_API_ASSERTIONS_CONTENT,
+			"X.java",
+			"import static org.junit.jupiter.api.Assertions.assertNotNull;\n" +
+			"public class X {\n" +
+			"    void test(Long test1, Long test2, Long test3) {\n" +
+			"        boolean b = (test1 != null | test2 != null | test3 != null);\n" +
+			"        assertNotNull(test1);\n" +
+			"        test1.longValue();\n" +
+			"        assertNotNull(test2, \"message\");\n" +
+			"        test2.longValue();\n" +
+			"        assertNotNull(test3, () -> \"message\");\n" +
+			"        test3.longValue();\n" +
+			"    }\n" +
+			"}\n"},
+		"");
+}
+// junit 5's assertNull
+public void testBug568542b() throws IOException {
+	if (this.complianceLevel < ClassFileConstants.JDK1_8) return; // uses Supplier
+	runNegativeTest(
+		new String[] {
+			ORG_JUNIT_JUPITER_API_ASSERTIONS_NAME,
+			ORG_JUNIT_JUPITER_API_ASSERTIONS_CONTENT,
+			"X.java",
+			"import static org.junit.jupiter.api.Assertions.assertNull;\n" +
+			"public class X {\n" +
+			"    void test(Long test1, Long test2, Long test3) {\n" +
+			"        boolean b = (test1 != null | test2 != null | test3 != null);\n" +
+			"        assertNull(test1);\n" +
+			"        test1.longValue();\n" +
+			"        assertNull(test2, \"message\");\n" +
+			"        test2.longValue();\n" +
+			"        assertNull(test3, () -> \"message\");\n" +
+			"        test3.longValue();\n" +
+			"    }\n" +
+			"}\n"},
+		"----------\n" +
+		"1. ERROR in X.java (at line 6)\n" +
+		"	test1.longValue();\n" +
+		"	^^^^^\n" +
+		"Null pointer access: The variable test1 can only be null at this location\n" +
+		"----------\n" +
+		"2. ERROR in X.java (at line 8)\n" +
+		"	test2.longValue();\n" +
+		"	^^^^^\n" +
+		"Null pointer access: The variable test2 can only be null at this location\n" +
+		"----------\n" +
+		"3. ERROR in X.java (at line 10)\n" +
+		"	test3.longValue();\n" +
+		"	^^^^^\n" +
+		"Null pointer access: The variable test3 can only be null at this location\n" +
+		"----------\n"
+	);
+}
+// junit 5's assertTrue
+public void testBug568542c() throws IOException {
+	if (this.complianceLevel < ClassFileConstants.JDK1_8) return; // uses Supplier
+	this.runConformTest(
+		new String[] {
+			ORG_JUNIT_JUPITER_API_ASSERTIONS_NAME,
+			ORG_JUNIT_JUPITER_API_ASSERTIONS_CONTENT,
+			"X.java",
+			"import static org.junit.jupiter.api.Assertions.assertTrue;\n" +
+			"public class X {\n" +
+			"    void test(Long test1, Long test2, Long test3) {\n" +
+			"        boolean b = (test1 != null | test2 != null | test3 != null);\n" +
+			"        assertTrue(test1 != null);\n" +
+			"        test1.longValue();\n" +
+			"        assertTrue(test2 != null, \"message\");\n" +
+			"        test2.longValue();\n" +
+			"        assertTrue(test3 != null, () -> \"message\");\n" +
+			"        test3.longValue();\n" +
+			"    }\n" +
+			"}\n"},
+		"");
+}
+// junit 5's assertFalse
+public void testBug568542d() throws IOException {
+	if (this.complianceLevel < ClassFileConstants.JDK1_8) return; // uses Supplier
+	runNegativeTest(
+		new String[] {
+			ORG_JUNIT_JUPITER_API_ASSERTIONS_NAME,
+			ORG_JUNIT_JUPITER_API_ASSERTIONS_CONTENT,
+			"X.java",
+			"import static org.junit.jupiter.api.Assertions.assertFalse;\n" +
+			"public class X {\n" +
+			"    void test(Long test1, Long test2, Long test3) {\n" +
+			"        boolean b = (test1 != null | test2 != null | test3 != null);\n" +
+			"        assertFalse(test1 != null);\n" +
+			"        test1.longValue();\n" +
+			"        assertFalse(test2 != null, \"message\");\n" +
+			"        test2.longValue();\n" +
+			"        assertFalse(test3 != null, () -> \"message\");\n" +
+			"        test3.longValue();\n" +
+			"    }\n" +
+			"}\n"},
+		"----------\n" +
+		"1. ERROR in X.java (at line 6)\n" +
+		"	test1.longValue();\n" +
+		"	^^^^^\n" +
+		"Null pointer access: The variable test1 can only be null at this location\n" +
+		"----------\n" +
+		"2. ERROR in X.java (at line 8)\n" +
+		"	test2.longValue();\n" +
+		"	^^^^^\n" +
+		"Null pointer access: The variable test2 can only be null at this location\n" +
+		"----------\n" +
+		"3. ERROR in X.java (at line 10)\n" +
+		"	test3.longValue();\n" +
+		"	^^^^^\n" +
+		"Null pointer access: The variable test3 can only be null at this location\n" +
+		"----------\n"
+	);
+}
 }
