@@ -44,8 +44,9 @@ public class ASTConverter9Test extends ConverterTestSetup {
 
 	ICompilationUnit workingCopy;
 	private static final String jcl9lib = "CONVERTER_JCL9_LIB";
-	
 
+
+	@Override
 	public void setUpSuite() throws Exception {
 		super.setUpSuite();
 		this.ast = AST.newAST(getAST9(), false);
@@ -83,6 +84,7 @@ public class ASTConverter9Test extends ConverterTestSetup {
 		return buildModelTestSuite(ASTConverter9Test.class);
 	}
 
+	@Override
 	protected void tearDown() throws Exception {
 		super.tearDown();
 		if (this.workingCopy != null) {
@@ -109,9 +111,9 @@ public class ASTConverter9Test extends ConverterTestSetup {
 		checkSourceRange(simpleName, "y1", source);
 		variableDeclarationExpression = (VariableDeclarationExpression) list.get(2);
 		checkSourceRange(variableDeclarationExpression, "final Y y2 = new Y()", source);
-		
+
 	}
-	
+
 	public void testBug497719_0002() throws JavaModelException {
 		String contents =
 				"import java.io.IOException;\n" +
@@ -219,7 +221,7 @@ public class ASTConverter9Test extends ConverterTestSetup {
 			IJavaProject project1 = createJavaProject("ConverterTests9", new String[] {"src"}, new String[] {jcl9lib}, "bin", "9");
 			project1.open(null);
 			addClasspathEntry(project1, JavaCore.newContainerEntry(new Path("org.eclipse.jdt.MODULE_PATH")));
-			String content = 
+			String content =
 				"module first {\n" +
 				"    requires second.third;\n" +
 				"    exports pack1.X11 to org.eclipse.jdt;\n" +
@@ -314,15 +316,15 @@ public class ASTConverter9Test extends ConverterTestSetup {
 				+ "}";
 		this.workingCopies[0] = getWorkingCopy(
 				"/Converter9/src/module-info.java", content);
-		
+
 		CompilationUnit unit = (CompilationUnit) runConversion(this.ast.apiLevel(), this.workingCopies[0], false/*no bindings*/);
 		ModuleDeclaration moduleDecl = unit.getModule();
-		
+
 		assertTrue(moduleDecl.isOpen());
 		checkSourceRange(moduleDecl, content, content);
 		List<ModuleDirective> stmts = moduleDecl.moduleStatements();
 		assertTrue(stmts.size() > 0);
-		
+
 		int count = 0;
 		RequiresDirective req = (RequiresDirective) stmts.get(count++);
 		checkSourceRange(req, "requires one;", content);
@@ -351,7 +353,7 @@ public class ASTConverter9Test extends ConverterTestSetup {
 			IJavaProject project1 = createJavaProject("ConverterTests9", new String[] {"src"}, new String[] {jcl9lib}, "bin", "9");
 			project1.open(null);
 			addClasspathEntry(project1, JavaCore.newContainerEntry(new Path("org.eclipse.jdt.MODULE_PATH")));
-			String content = 
+			String content =
 				"module first {\n" +
 				"    requires transitive static second.third;\n" +
 				"    exports pack1.X11 to org.eclipse.jdt;\n" +
@@ -394,10 +396,10 @@ public class ASTConverter9Test extends ConverterTestSetup {
 			IJavaProject project1 = createJavaProject("ConverterTests9", new String[] {"src"}, new String[] {jcl9lib}, "bin", "9");
 			project1.open(null);
 			addClasspathEntry(project1, JavaCore.newContainerEntry(new Path("org.eclipse.jdt.MODULE_PATH")));
-			String fileContent = 
+			String fileContent =
 				"module first {\n" +
 				"    requires second;\n" +
-				"	 uses pack22.I22;\n" + 
+				"	 uses pack22.I22;\n" +
 				"    provides pack22.I22 with pack1.X11;\n" +
 				"}";
 			createFile("/ConverterTests9/src/module-info.java",	fileContent);
@@ -409,7 +411,7 @@ public class ASTConverter9Test extends ConverterTestSetup {
 			IJavaProject project2 = createJavaProject("second", new String[] {"src"}, new String[] {jcl9lib}, "bin", "9");
 			project2.open(null);
 			addClasspathEntry(project2, JavaCore.newContainerEntry(new Path("org.eclipse.jdt.MODULE_PATH")));
-			String secondFile = 
+			String secondFile =
 					"module second {\n" +
 					"    exports pack22 to first;\n" +
 					"}";
@@ -425,7 +427,7 @@ public class ASTConverter9Test extends ConverterTestSetup {
 			IJavaProject project3 = createJavaProject("third", new String[] {"src"}, new String[] {jcl9lib}, "bin", "9");
 			project3.open(null);
 			addClasspathEntry(project3, JavaCore.newContainerEntry(new Path("org.eclipse.jdt.MODULE_PATH")));
-			String thirdFile = 
+			String thirdFile =
 					"module third {\n" +
 					"    requires first;\n" +
 					"}";
@@ -453,7 +455,7 @@ public class ASTConverter9Test extends ConverterTestSetup {
 			moduleBinding = (IModuleBinding) binding;
 
 			assertModuleFirstDetails(moduleBinding);
-			
+
 			// indirectly fetch the binary version of "first" via "third":
 			ICompilationUnit sourceUnit3 = getCompilationUnit("third" , "src", "", "module-info.java"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$
 			ASTNode unit3 = runConversion(this.ast.apiLevel(), sourceUnit3, true);
@@ -462,7 +464,7 @@ public class ASTConverter9Test extends ConverterTestSetup {
 			IModuleBinding firstModAsBinary = moduleDecl3.resolveBinding().getRequiredModules()[1]; // skip java.base
 
 			assertModuleFirstDetails(firstModAsBinary);
-		
+
 		} finally {
 			deleteProject("ConverterTests9");
 			deleteProject("second");
@@ -475,7 +477,7 @@ public class ASTConverter9Test extends ConverterTestSetup {
 		String name = moduleBinding.getName();
 		assertTrue("Module Name null", name != null);
 		assertTrue("Wrong Module Name", name.equals("first"));
-		
+
 		assertTrue("Module Binding null", moduleBinding != null);
 		name = moduleBinding.getName();
 		assertTrue("Module Name null", name != null);
@@ -516,7 +518,7 @@ public class ASTConverter9Test extends ConverterTestSetup {
 			IJavaProject project1 = createJavaProject("ConverterTests9", new String[] {"src"}, new String[] {jcl9lib}, "bin", "9");
 			project1.open(null);
 			addClasspathEntry(project1, JavaCore.newContainerEntry(new Path("org.eclipse.jdt.MODULE_PATH")));
-			String fileContent = 
+			String fileContent =
 				"module first {\n" +
 				"    requires second;\n" +
 				"    provides pack22.I22 with pack1.X11;\n" +
@@ -530,7 +532,7 @@ public class ASTConverter9Test extends ConverterTestSetup {
 			IJavaProject project2 = createJavaProject("second", new String[] {"src"}, new String[] {jcl9lib}, "bin", "9");
 			project2.open(null);
 			addClasspathEntry(project2, JavaCore.newContainerEntry(new Path("org.eclipse.jdt.MODULE_PATH")));
-			String secondFile = 
+			String secondFile =
 					"module second {\n" +
 					"    exports pack22 to first;\n" +
 					"}";
@@ -572,7 +574,7 @@ public class ASTConverter9Test extends ConverterTestSetup {
 			IJavaProject project1 = createJavaProject("ConverterTests9", new String[] {"src"}, new String[] {jcl9lib}, "bin", "9");
 			project1.open(null);
 			addClasspathEntry(project1, JavaCore.newContainerEntry(new Path("org.eclipse.jdt.MODULE_PATH")));
-			String fileContent = 
+			String fileContent =
 				"open module first {\n" +
 				"    requires second;\n" +
 				"    provides pack22.I22 with pack1.X11;\n" +
@@ -586,7 +588,7 @@ public class ASTConverter9Test extends ConverterTestSetup {
 			IJavaProject project2 = createJavaProject("second", new String[] {"src"}, new String[] {jcl9lib}, "bin", "9");
 			project2.open(null);
 			addClasspathEntry(project2, JavaCore.newContainerEntry(new Path("org.eclipse.jdt.MODULE_PATH")));
-			String secondFile = 
+			String secondFile =
 					"open module second {\n" +
 					"    exports pack22 to first;\n" +
 					"}";
@@ -607,7 +609,7 @@ public class ASTConverter9Test extends ConverterTestSetup {
 			assertEquals("Not a compilation unit", ASTNode.COMPILATION_UNIT, unit1.getNodeType());
 			ModuleDeclaration moduleDecl1 = ((CompilationUnit) unit1).getModule();
 			checkSourceRange(moduleDecl1, fileContent, fileContent);
-			
+
 			Name name = moduleDecl1.getName();
 			IModuleBinding moduleBinding = (IModuleBinding) name.resolveBinding();
 			assertTrue("Module Binding null", moduleBinding != null);
@@ -744,11 +746,11 @@ public class ASTConverter9Test extends ConverterTestSetup {
 		try {
 			project1 = createJavaProject("ConverterTests9", new String[] {"src"}, new String[] {jcl9lib}, "bin", "9");
 			project1.open(null);
-			String fileContent = 
+			String fileContent =
 				"open module first.module {\n" +
 				"}";
 			createFile("/ConverterTests9/src/module-info.java",	fileContent);
-	
+
 			IModuleDescription firstModule = project1.findModule("first.module", null);
 			IJavaElement[] elements = new IJavaElement[] {
 					firstModule,
@@ -774,17 +776,17 @@ public class ASTConverter9Test extends ConverterTestSetup {
 		try {
 			project1 = createJavaProject("ConverterTests9", new String[] {"src"}, new String[] {jcl9lib}, "bin", "9");
 			project1.open(null);
-			String fileContent = 
+			String fileContent =
 				"module first.module { }";
 			createFile("/ConverterTests9/src/module-info.java",	fileContent);
-			
+
 			project1.getProject().build(IncrementalProjectBuilder.FULL_BUILD, null);
-	
+
 			project2 = createJavaProject("second", new String[] {"src"}, new String[] {jcl9lib}, "bin", "9");
-			addClasspathEntry(project2, JavaCore.newLibraryEntry(new Path("/ConverterTests9/bin"), null, null, null, 
-					new IClasspathAttribute[] { JavaCore.newClasspathAttribute(IClasspathAttribute.MODULE, "true") }, false));		
+			addClasspathEntry(project2, JavaCore.newLibraryEntry(new Path("/ConverterTests9/bin"), null, null, null,
+					new IClasspathAttribute[] { JavaCore.newClasspathAttribute(IClasspathAttribute.MODULE, "true") }, false));
 			project2.open(null);
-	
+
 			IModuleDescription firstModule = null;
 			for (IPackageFragmentRoot root : project2.getPackageFragmentRoots()) {
 				IModuleDescription module = root.getModuleDescription();
@@ -1137,7 +1139,7 @@ public class ASTConverter9Test extends ConverterTestSetup {
 			deleteProject("second");
 		}
 	}
-	// 
+	//
 	public void testBug518794_001() throws Exception {
 		try {
 
@@ -1373,7 +1375,7 @@ public class ASTConverter9Test extends ConverterTestSetup {
 			ModuleDirective stat = (ModuleDirective) moduleDeclaration2.moduleStatements().get(0);
 			IBinding requiredModule = ((RequiresDirective) stat).getName().resolveBinding();
 			validateBinding.accept(requiredModule);
-			
+
 		} finally {
 			deleteProject("First");
 			deleteProject("Second");
@@ -1389,15 +1391,15 @@ public class ASTConverter9Test extends ConverterTestSetup {
 			project1.open(null);
 			createFolder("/Foo/src/foo");
 			createFile("/Foo/src/foo/Foo.java",
-					"package foo;\n" + 
-					"\n" + 
-					"public class Foo {\n" + 
-					"	public interface MyInterface<T> {\n" + 
-					"		public void perform(T t);\n" + 
-					"	}\n" + 
-					"	public <T> MyInterface<T> createMyInterface() {\n" + 
+					"package foo;\n" +
+					"\n" +
+					"public class Foo {\n" +
+					"	public interface MyInterface<T> {\n" +
+					"		public void perform(T t);\n" +
+					"	}\n" +
+					"	public <T> MyInterface<T> createMyInterface() {\n" +
 					"		return new My\n" + // incomplete, use case is: completion after "My"
-					"	}\n" + 
+					"	}\n" +
 					"}\n");
 			ASTParser parser = ASTParser.newParser(this.ast.apiLevel());
 			parser.setProject(project1);
@@ -1443,7 +1445,7 @@ public class ASTConverter9Test extends ConverterTestSetup {
 					"	}\n" +
 					"}\n");
 			ICompilationUnit cuD = getCompilationUnit("/Foo/src/Test.java");
-			
+
 			p.setOption(JavaCore.COMPILER_PB_DEPRECATION, JavaCore.ERROR);
 			ASTParser parser = ASTParser.newParser(AST_INTERNAL_JLS11);
 			parser.setProject(p);
@@ -1454,20 +1456,20 @@ public class ASTConverter9Test extends ConverterTestSetup {
 			org.eclipse.jdt.core.dom.CompilationUnit cuAST = (org.eclipse.jdt.core.dom.CompilationUnit) parser.createAST(null);
 			IProblem[] problems = cuAST.getProblems();
 			assertProblems("Unexpected problems",
-					"1. ERROR in /Foo/src/Test.java (at line 1)\n" + 
-					"	public class Test implements test.Screen.Component {}\n" + 
-					"	             ^^^^\n" + 
-					"The hierarchy of the type Test is inconsistent\n" + 
-					"----------\n" + 
-					"2. ERROR in /Foo/src/Test.java (at line 1)\n" + 
-					"	public class Test implements test.Screen.Component {}\n" + 
-					"	                                  ^^^^^^\n" + 
-					"The type Screen is deprecated\n" + 
-					"----------\n" + 
-					"3. ERROR in /Foo/src/Test.java (at line 1)\n" + 
-					"	public class Test implements test.Screen.Component {}\n" + 
-					"	                                         ^^^^^^^^^\n" + 
-					"The type Screen.Component is deprecated\n" + 
+					"1. ERROR in /Foo/src/Test.java (at line 1)\n" +
+					"	public class Test implements test.Screen.Component {}\n" +
+					"	             ^^^^\n" +
+					"The hierarchy of the type Test is inconsistent\n" +
+					"----------\n" +
+					"2. ERROR in /Foo/src/Test.java (at line 1)\n" +
+					"	public class Test implements test.Screen.Component {}\n" +
+					"	                                  ^^^^^^\n" +
+					"The type Screen is deprecated\n" +
+					"----------\n" +
+					"3. ERROR in /Foo/src/Test.java (at line 1)\n" +
+					"	public class Test implements test.Screen.Component {}\n" +
+					"	                                         ^^^^^^^^^\n" +
+					"The type Screen.Component is deprecated\n" +
 					"----------\n",
 					problems, source.toCharArray());
 		} finally {
