@@ -18,8 +18,8 @@ package org.eclipse.jdt.core.tests.model;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 
+import org.eclipse.jdt.core.tests.compiler.map.CharArrayMapperTest;
 import org.eclipse.jdt.core.tests.junit.extension.TestCase;
-import org.eclipse.jdt.core.tests.nd.RunIndexTests;
 
 import junit.framework.Test;
 import junit.framework.TestSuite;
@@ -66,8 +66,11 @@ private static Class[] getAllTestClasses() {
 		// Java search tests
 		RunJavaSearchTests.class,
 
-		// Testss for the new index
-		RunIndexTests.class,
+		IndexManagerTests.class,
+
+		// Tests for the new index - disabled because the index is not used anymore
+		// See bug 572976 and bug 544898
+		// RunIndexTests.class,
 
 		// Working copy tests
 		WorkingCopyTests.class,
@@ -224,6 +227,8 @@ private static Class[] getAllTestClasses() {
 		NullAnnotationModelTests9.class,
 
 		JavaModelManagerTests.class,
+
+		CharArrayMapperTest.class,
 	};
 
 	Class[] deprecatedClasses = getDeprecatedJDOMTestClasses();
