@@ -722,7 +722,8 @@ public class EncodingTests extends ModifyingResourceTests {
 						return result;
 					}
 				};
-				char[] result = org.eclipse.jdt.internal.compiler.util.Util.getInputStreamAsCharArray(in, (int) file.getLocation().toFile().length(), "UTF-8");
+				char[] result = org.eclipse.jdt.internal.compiler.util.Util.getInputStreamAsCharArray(in,
+						org.eclipse.jdt.internal.compiler.util.Util.UTF_8);
 				assertSourceEquals(
 					"Unexpected source",
 					"abcdefghijklmn",
