@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2020 IBM Corporation and others.
+ * Copyright (c) 2020, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -7,21 +7,42 @@
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- *
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
 package org.eclipse.jdt.core.tests.rewrite.describing;
 import java.util.List;
 
-import junit.framework.Test;
-
 import org.eclipse.jdt.core.ICompilationUnit;
 import org.eclipse.jdt.core.IPackageFragment;
-import org.eclipse.jdt.core.JavaCore;
-import org.eclipse.jdt.core.dom.*;
+import org.eclipse.jdt.core.dom.AST;
+import org.eclipse.jdt.core.dom.ASTNode;
+import org.eclipse.jdt.core.dom.Assignment;
+import org.eclipse.jdt.core.dom.CastExpression;
+import org.eclipse.jdt.core.dom.ClassInstanceCreation;
+import org.eclipse.jdt.core.dom.CompilationUnit;
+import org.eclipse.jdt.core.dom.ExpressionStatement;
+import org.eclipse.jdt.core.dom.InstanceofExpression;
+import org.eclipse.jdt.core.dom.MarkerAnnotation;
+import org.eclipse.jdt.core.dom.MethodDeclaration;
+import org.eclipse.jdt.core.dom.MethodInvocation;
+import org.eclipse.jdt.core.dom.NameQualifiedType;
+import org.eclipse.jdt.core.dom.ParameterizedType;
+import org.eclipse.jdt.core.dom.QualifiedName;
+import org.eclipse.jdt.core.dom.RecordDeclaration;
+import org.eclipse.jdt.core.dom.SimpleName;
+import org.eclipse.jdt.core.dom.SimpleType;
+import org.eclipse.jdt.core.dom.SingleVariableDeclaration;
+import org.eclipse.jdt.core.dom.TryStatement;
+import org.eclipse.jdt.core.dom.TypeDeclaration;
+import org.eclipse.jdt.core.dom.TypeParameter;
+import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
+import org.eclipse.jdt.core.dom.VariableDeclarationStatement;
+import org.eclipse.jdt.core.dom.WildcardType;
 import org.eclipse.jdt.core.dom.rewrite.ASTRewrite;
 
+import junit.framework.Test;
+
 @SuppressWarnings("rawtypes")
 public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 
@@ -33,28 +54,23 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 	}
 
 	public static Test suite() {
-		return createSuite(ASTRewritingRecordAnnotationsTest.class, getAST15());
+		return createSuite(ASTRewritingRecordAnnotationsTest.class, getAST16());
 	}
 
-	protected static int getAST15() {
-		return AST.JLS15;
+	protected static int getAST16() {
+		return AST.JLS16;
 	}
 
 	@Override
 	protected void setUp() throws Exception {
 		super.setUp();
-		if (this.apiLevel == AST.JLS15 ) {
-			this.project1.setOption(JavaCore.COMPILER_COMPLIANCE, JavaCore.VERSION_15);
-			this.project1.setOption(JavaCore.COMPILER_SOURCE, JavaCore.VERSION_15);
-			this.project1.setOption(JavaCore.COMPILER_CODEGEN_TARGET_PLATFORM, JavaCore.VERSION_15);
-			this.project1.setOption(JavaCore.COMPILER_PB_ENABLE_PREVIEW_FEATURES, JavaCore.ENABLED);
-		}
+		setUpProjectAbove16();
 	}
 
 	@SuppressWarnings("deprecation")
 	private boolean checkAPILevel() {
-		if (this.apiLevel != 15) {
-			System.err.println("Test "+getName()+" requires a JRE 15");
+		if (this.apiLevel < 16) {
+			System.err.println("Test "+getName()+" requires a JRE 16");
 			return true;
 		}
 		return false;
@@ -65,7 +81,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			return;
 		}
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("public record X() {\n");
@@ -111,7 +127,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			rewrite.replace((ASTNode)annotations.get(0), markerAnnotation, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("public record X() {\n");
@@ -133,7 +149,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			return;
 		}
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("public record X() {\n");
@@ -206,7 +222,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			rewrite.replace((MarkerAnnotation) wildcardType2.annotations().get(0), markerAnnotation2, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("public record X() {\n");
@@ -235,7 +251,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			return;
 		}
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 
 		buf.append("public record X() {\n");
 		buf.append("	public record Helper<T>() {\n");
@@ -279,7 +295,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			rewrite.replace((MarkerAnnotation) simpleType.annotations().get(0), markerAnnotation, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("public record X() {\n");
 		buf.append("	public record Helper<T>() {\n");
 		buf.append("	}\n");
@@ -298,7 +314,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			return;
 		}
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
@@ -342,7 +358,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			rewrite.replace((MarkerAnnotation) simpleType.annotations().get(0), markerAnnotation, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
 		buf.append("public record X() {\n");
@@ -367,7 +383,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			return;
 		}
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
@@ -412,7 +428,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			rewrite.remove((ASTNode) simpleType.annotations().get(0), null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
 		buf.append("public record X() {\n");
@@ -436,7 +452,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			return;
 		}
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
@@ -487,7 +503,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			rewrite.replace((MarkerAnnotation)simpleType.annotations().get(0), markerAnnotation, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
 		buf.append("public record X() {\n");
@@ -519,7 +535,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			return;
 		}
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
@@ -563,7 +579,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			rewrite.replace((MarkerAnnotation) simpleType.annotations().get(0), markerAnnotation, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
 		buf.append("public record X() {\n");
@@ -588,7 +604,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			return;
 		}
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
@@ -638,7 +654,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			rewrite.replace((MarkerAnnotation) simpleType.annotations().get(0), markerAnnotation, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
 		buf.append("public record X() {\n");
@@ -666,7 +682,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			return;
 		}
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append(" \n");
 		buf.append("public record X() {\n");
@@ -713,7 +729,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			rewrite.replace((MarkerAnnotation) simpleType.annotations().get(0), markerAnnotation, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append(" \n");
 		buf.append("public record X() {\n");
@@ -738,7 +754,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			return;
 		}
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
 		buf.append("public record X() {\n");
@@ -775,7 +791,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			rewrite.replace((MarkerAnnotation) methodDeclaration.modifiers().get(0), markerAnnotation, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
 		buf.append("public record X() {\n");
@@ -799,7 +815,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			return;
 		}
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
@@ -849,7 +865,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			rewrite.getListRewrite(simpleType, SimpleType.ANNOTATIONS_PROPERTY).insertBefore(markerAnnotation, (MarkerAnnotation) simpleType.annotations().get(1), null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf = new StringBuffer();
+		buf = new StringBuilder();
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("\n");
 		buf.append("public record X() {\n");
@@ -873,7 +889,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			return;
 		}
 		IPackageFragment pack1= this.sourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public record X() {\n");
 		buf.append("	static String myObject = \"Foo\";\n");
@@ -899,7 +915,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 			rewrite.getListRewrite(simpleType, SimpleType.ANNOTATIONS_PROPERTY).insertLast(markerAnnotation, null);
 		}
 		String preview= evaluateRewrite(cu, rewrite);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public record X() {\n");
 		buf.append("	static String myObject = \"Foo\";\n");
@@ -950,7 +966,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 				"class FileNotFoundException extends Exception{private static final long serialVersionUID=10002L;}\n" +
 				"class EOFException extends Exception{private static final long serialVersionUID=10003L;}\n" +
 				"class IOError extends Exception{private static final long serialVersionUID=10004L;}\n";
-		StringBuffer buf = new StringBuffer(contents);
+		StringBuilder buf = new StringBuilder(contents);
 		ICompilationUnit cu= pack1.createCompilationUnit("X.java", buf.toString(), false, null);
 		CompilationUnit astRoot= createAST(cu, /* resolve */ true, false);
 		ASTRewrite rewrite= ASTRewrite.create(astRoot.getAST());
@@ -1058,7 +1074,7 @@ public class ASTRewritingRecordAnnotationsTest extends ASTRewritingTest {
 				 "@Target (java.lang.annotation.ElementType.TYPE_USE)\n" +
 				 "@interface Marker2 {}\n";
 
-		StringBuffer buf = new StringBuffer(contents);
+		StringBuilder buf = new StringBuilder(contents);
 		ICompilationUnit cu= pack1.createCompilationUnit("X.java", buf.toString(), false, null);
 		CompilationUnit astRoot= createAST(cu, /* resolve */ true, false);
 		ASTRewrite rewrite= ASTRewrite.create(astRoot.getAST());
