@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,7 +10,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
- *     Jesper Steen Møller <jesper@selskabet.org> - contributions for:	
+ *     Jesper Steen Møller <jesper@selskabet.org> - contributions for:
  *         Bug 531046: [10] ICodeAssist#codeSelect support for 'var'
  *******************************************************************************/
 package org.eclipse.jdt.internal.codeassist;
@@ -48,6 +48,8 @@ import org.eclipse.jdt.internal.codeassist.select.SelectionJavadocParser;
 import org.eclipse.jdt.internal.codeassist.select.SelectionNodeFound;
 import org.eclipse.jdt.internal.codeassist.select.SelectionOnPackageVisibilityReference;
 import org.eclipse.jdt.internal.codeassist.select.SelectionOnImportReference;
+import org.eclipse.jdt.internal.codeassist.select.SelectionOnLocalName;
+import org.eclipse.jdt.internal.codeassist.select.SelectionOnMessageSend;
 import org.eclipse.jdt.internal.codeassist.select.SelectionOnPackageReference;
 import org.eclipse.jdt.internal.codeassist.select.SelectionOnQualifiedTypeReference;
 import org.eclipse.jdt.internal.codeassist.select.SelectionOnSingleTypeReference;
@@ -63,6 +65,7 @@ import org.eclipse.jdt.internal.compiler.ast.ConstructorDeclaration;
 import org.eclipse.jdt.internal.compiler.ast.FieldDeclaration;
 import org.eclipse.jdt.internal.compiler.ast.ImportReference;
 import org.eclipse.jdt.internal.compiler.ast.LocalDeclaration;
+import org.eclipse.jdt.internal.compiler.ast.MessageSend;
 import org.eclipse.jdt.internal.compiler.ast.MethodDeclaration;
 import org.eclipse.jdt.internal.compiler.ast.ModuleDeclaration;
 import org.eclipse.jdt.internal.compiler.ast.PackageVisibilityStatement;
@@ -75,6 +78,7 @@ import org.eclipse.jdt.internal.compiler.classfmt.ClassFormatException;
 import org.eclipse.jdt.internal.compiler.env.AccessRestriction;
 import org.eclipse.jdt.internal.compiler.env.IBinaryType;
 import org.eclipse.jdt.internal.compiler.env.ICompilationUnit;
+import org.eclipse.jdt.internal.compiler.env.ISourceType;
 import org.eclipse.jdt.internal.compiler.lookup.ArrayBinding;
 import org.eclipse.jdt.internal.compiler.lookup.BaseTypeBinding;
 import org.eclipse.jdt.internal.compiler.lookup.Binding;
@@ -137,16 +141,16 @@ import org.eclipse.jdt.internal.core.util.HashSetOfCharArrayArray;
  */
 @SuppressWarnings({"rawtypes", "unchecked"})
 public final class SelectionEngine extends Engine implements ISearchRequestor {
-	
+
 	private static class SelectionTypeNameMatchRequestorWrapper extends TypeNameMatchRequestorWrapper {
-		
-		class AcceptedType {
+
+		static class AcceptedType {
 			public int modifiers;
 			public char[] packageName;
 			public char[] simpleTypeName;
 			public String path;
 			public AccessRestriction access;
-			
+
 			public AcceptedType(int modifiers, char[] packageName, char[] simpleTypeName, String path, AccessRestriction access) {
 				this.modifiers = modifiers;
 				this.packageName = packageName;
@@ -155,63 +159,63 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 				this.access = access;
 			}
 		}
-		
+
 		private ImportReference[] importReferences;
-		
+
 		private boolean importCachesNodeInitialized = false;
 		private ImportReference[] onDemandImportsNodeCache;
 		private int onDemandImportsNodeCacheCount;
 		private char[][][] importsNodeCache;
 		private int importsNodeCacheCount;
-		
+
 		private HashtableOfObject onDemandFound = new HashtableOfObject();
 		private ObjectVector notImportedFound = new ObjectVector();
-		
+
 		public SelectionTypeNameMatchRequestorWrapper(TypeNameMatchRequestor requestor, IJavaSearchScope scope, ImportReference[] importReferences) {
 			super(requestor, scope);
 			this.importReferences = importReferences;
 		}
-		
+
 		@Override
 		public void acceptType(int modifiers, char[] packageName, char[] simpleTypeName, char[][] enclosingTypeNames, String path, AccessRestriction access) {
 			if (enclosingTypeNames != null && enclosingTypeNames.length > 0) return;
-			
+
 			if (!this.importCachesNodeInitialized) initializeImportNodeCaches();
-			
+
 			char[] fullyQualifiedTypeName = CharOperation.concat(packageName, simpleTypeName, '.');
-			
+
 			for (int i = 0; i < this.importsNodeCacheCount; i++) {
 				char[][] importName = this.importsNodeCache[i];
 				if (CharOperation.equals(importName[0], simpleTypeName)) {
-					
+
 					if(CharOperation.equals(importName[1], fullyQualifiedTypeName)) {
 						super.acceptType(modifiers, packageName, simpleTypeName, enclosingTypeNames, path, access);
 					}
 					return;
 				}
 			}
-			
+
 			for (int i = 0; i < this.onDemandImportsNodeCacheCount; i++) {
 				char[][] importName = this.onDemandImportsNodeCache[i].tokens;
 				char[] importFlatName = CharOperation.concatWith(importName, '.');
-				
+
 				if (CharOperation.equals(importFlatName, packageName)) {
-					
+
 					this.onDemandFound.put(simpleTypeName, simpleTypeName);
 					super.acceptType(modifiers, packageName, simpleTypeName, enclosingTypeNames, path, access);
 					return;
 				}
 			}
-			
-			
+
+
 			this.notImportedFound.add(new AcceptedType(modifiers, packageName, simpleTypeName, path, access));
 		}
-		
+
 		public void acceptNotImported() {
 			int size = this.notImportedFound.size();
 			for (int i = 0; i < size; i++) {
 				AcceptedType acceptedType = (AcceptedType)this.notImportedFound.elementAt(i);
-				
+
 				if (this.onDemandFound.get(acceptedType.simpleTypeName) == null) {
 					super.acceptType(
 							acceptedType.modifiers,
@@ -223,10 +227,10 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 				}
 			}
 		}
-		
+
 		public void initializeImportNodeCaches() {
 			int length = this.importReferences == null ? 0 : this.importReferences.length;
-			
+
 			for (int i = 0; i < length; i++) {
 				ImportReference importReference = this.importReferences[i];
 				if((importReference.bits & ASTNode.OnDemand) != 0) {
@@ -239,15 +243,15 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 					if(this.importsNodeCache == null) {
 						this.importsNodeCache = new char[length - i][][];
 					}
-					
-					
+
+
 					this.importsNodeCache[this.importsNodeCacheCount++] = new char[][]{
 							importReference.tokens[importReference.tokens.length - 1],
 							CharOperation.concatWith(importReference.tokens, '.')
 						};
 				}
 			}
-			
+
 			this.importCachesNodeInitialized = true;
 		}
 	}
@@ -348,7 +352,7 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 		this.parser = new SelectionParser(problemReporter);
 		this.owner = owner;
 	}
-	
+
 	@Override
 	public void acceptConstructor(
 			int modifiers,
@@ -364,6 +368,12 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 			AccessRestriction access) {
 		// constructors aren't searched
 	}
+	@Override
+	public void accept(ISourceType[] sourceTypes, PackageBinding packageBinding, AccessRestriction accessRestriction) {
+		CompilationUnitDeclaration unit = this.lookupEnvironment.unitBeingCompleted;
+		super.accept(sourceTypes, packageBinding, accessRestriction);
+		this.lookupEnvironment.unitBeingCompleted = unit;
+	}
 
 	@Override
 	public void acceptType(char[] packageName, char[] simpleTypeName, char[][] enclosingTypeNames, int modifiers, AccessRestriction accessRestriction) {
@@ -566,9 +576,10 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 				this.compilerOptions.complianceLevel,
 				null/*taskTag*/,
 				null/*taskPriorities*/,
-				true /*taskCaseSensitive*/);
+				true /*taskCaseSensitive*/,
+				this.compilerOptions.enablePreviewFeatures);
 		scanner.setSource(source);
-		
+
 		int lastIdentifierStart = -1;
 		int lastIdentifierEnd = -1;
 		char[] lastIdentifier = null;
@@ -684,7 +695,7 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 			if (selectionStart == selectionEnd) { // Widen the selection to scan -> || :: if needed. No unicode handling for now.
 				if (selectionStart > 0 && selectionEnd < source.length - 1) {
 					if ((source[selectionStart] == '>' && source[selectionStart - 1] == '-') ||
-							source[selectionStart] == ':' && source[selectionStart - 1] == ':') { 
+							source[selectionStart] == ':' && source[selectionStart - 1] == ':') {
 						selectionStart--;
 					} else {
 						if ((source[selectionStart] == '-' && source[selectionEnd + 1] == '>') ||
@@ -692,7 +703,7 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 							selectionEnd++;
 						}
 					}
-				}  
+				}
 			} // there could be some innocuous widening, shouldn't matter.
 			scanner.resetTo(selectionStart, selectionEnd, isModuleInfo);
 
@@ -719,12 +730,12 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 						}
 						expectingIdentifier = false;
 						break;
-					case TerminalTokens.TokenNameCOLON_COLON:	
+					case TerminalTokens.TokenNameCOLON_COLON:
 						if (selectionStart >= scanner.startPosition && selectionEnd < scanner.currentPosition) {
 							this.actualSelectionStart = selectionStart;
 							this.actualSelectionEnd = selectionEnd;
 							this.selectedIdentifier = CharOperation.NO_CHAR;
-							return true;		
+							return true;
 						}
 						//$FALL-THROUGH$
 					case TerminalTokens.TokenNameDOT :
@@ -749,7 +760,7 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 							this.actualSelectionStart = selectionStart;
 							this.actualSelectionEnd = selectionEnd;
 							this.selectedIdentifier = CharOperation.NO_CHAR;
-							return true;		
+							return true;
 						}
 						return false;
 					default :
@@ -768,7 +779,7 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 	private boolean checkTypeArgument(Scanner scanner) {
 		int depth = 1;
 		int token;
-		StringBuffer buffer = new StringBuffer();
+		StringBuilder buffer = new StringBuilder();
 		do {
 			try {
 				token = scanner.getNextToken();
@@ -805,7 +816,7 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 						buffer.getChars(0, length, typeRef, 0);
 						try {
 							Signature.createTypeSignature(typeRef, true);
-							buffer = new StringBuffer();
+							buffer = new StringBuilder();
 						} catch(IllegalArgumentException e) {
 							return false;
 						}
@@ -835,7 +846,7 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 
 		return false;
 	}
-	
+
 	/*
 	 * find all types outside the project scope
 	 */
@@ -876,7 +887,7 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 					// implements interface method
 				}
 			};
-			
+
 			TypeNameMatchRequestor typeNameMatchRequestor = new TypeNameMatchRequestor() {
 				@Override
 				public void acceptTypeNameMatch(TypeNameMatch match) {
@@ -886,17 +897,17 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 					}
 				}
 			};
-			
+
 			IJavaSearchScope scope = BasicSearchEngine.createWorkspaceScope();
-			
+
 			SelectionTypeNameMatchRequestorWrapper requestorWrapper =
 				new SelectionTypeNameMatchRequestorWrapper(
-						typeNameMatchRequestor, 
+						typeNameMatchRequestor,
 						scope,
 						this.unitScope == null ? null : this.unitScope.referenceContext.imports);
-			
+
 			org.eclipse.jdt.core.ICompilationUnit[] workingCopies = this.owner == null ? null : JavaModelManager.getJavaModelManager().getWorkingCopies(this.owner, true/*add primary WCs*/);
-			
+
 			try {
 				new BasicSearchEngine(workingCopies).searchAllTypeNames(
 					null,
@@ -1096,7 +1107,7 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 				// accept qualified types only if no unqualified type was accepted
 				if(!this.acceptedAnswer) {
 					acceptQualifiedTypes();
-					
+
 					// accept types from all the workspace only if no type was found in the project scope
 					if (this.noProposal) {
 						findAllTypes(this.selectedIdentifier);
@@ -1106,12 +1117,7 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 			if(this.noProposal && this.problem != null) {
 				this.requestor.acceptError(this.problem);
 			}
-		} catch (IndexOutOfBoundsException e) { // work-around internal failure - 1GEMF6D
-			if(DEBUG) {
-				System.out.println("Exception caught by SelectionEngine:"); //$NON-NLS-1$
-				e.printStackTrace(System.out);
-			}
-		} catch (AbortCompilation e) { // ignore this exception for now since it typically means we cannot find java.lang.Object
+		} catch (IndexOutOfBoundsException | AbortCompilation e) { // ignore this exception for now since it typically means we cannot find java.lang.Object
 			if(DEBUG) {
 				System.out.println("Exception caught by SelectionEngine:"); //$NON-NLS-1$
 				e.printStackTrace(System.out);
@@ -1421,6 +1427,12 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 		// for traversing the parse tree, the parser assist identifier is necessary for identitiy checks
 		final char[] assistIdentifier = getParser().assistIdentifier();
 		if (assistIdentifier == null) return;
+		final BlockScope nodeScope;
+		if (node instanceof AbstractMethodDeclaration) {
+			nodeScope = ((AbstractMethodDeclaration)node).scope;
+		} else {
+			nodeScope = null;
+		}
 
 		class Visitor extends ASTVisitor {
 			@Override
@@ -1439,6 +1451,9 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 			@Override
 			public boolean visit(
 		    		LocalDeclaration localDeclaration, BlockScope scope) {
+				if(localDeclaration instanceof SelectionOnLocalName) {
+					localDeclaration.resolve(scope);
+				}
 				if (localDeclaration.type instanceof SingleTypeReference && ((SingleTypeReference)localDeclaration.type).token == assistIdentifier) {
 					if(localDeclaration.binding != null) {
 						throw new SelectionNodeFound(localDeclaration.binding.type);
@@ -1483,6 +1498,19 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 				return true;
 			}
 			@Override
+			public boolean visit(MessageSend messageSend, BlockScope scope) {
+				if (messageSend.selector == assistIdentifier && messageSend instanceof SelectionOnMessageSend) {
+					if (scope == null) {
+						scope = nodeScope;
+					}
+					if (scope != null) {
+						messageSend.resolve(scope);
+						throw new SelectionNodeFound(messageSend.binding);
+					}
+				}
+				return true;
+			}
+			@Override
 			public boolean visit(
 		    		Argument argument, BlockScope scope) {
 				if (argument.type instanceof SingleTypeReference && ((SingleTypeReference)argument.type).token == assistIdentifier)
@@ -1568,7 +1596,7 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 					}
 					// find the type declaration that corresponds to the original source type
 					while (context.isLambda() && context.getParent() != null) {
-						// It is easier to find the first enclosing proper type than the corresponding 
+						// It is easier to find the first enclosing proper type than the corresponding
 						// lambda expression ast to add the selection node to.
 						context = (IType) context.getParent().getAncestor(IJavaElement.TYPE);
 					}
@@ -1600,7 +1628,7 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 					CompilationResult result = new CompilationResult(reader.getFileName(), 1, 1, this.compilerOptions.maxProblemsPerUnit);
 					parsedUnit = new CompilationUnitDeclaration(this.parser.problemReporter(), result, 0);
 					HashSetOfCharArrayArray typeNames = new HashSetOfCharArrayArray();
-					
+
 					BinaryTypeConverter converter = new BinaryTypeConverter(this.parser.problemReporter(), result, typeNames);
 					typeDeclaration = converter.buildTypeDeclaration(context, parsedUnit);
 					parsedUnit.imports = converter.buildImports(reader);
@@ -1826,7 +1854,7 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 
 		return false;
 	}
-	
+
 	/*
 	 * Returns the correct method binding according to whether the selection is on the method declaration
 	 * or on the inheritDoc tag in its javadoc.
@@ -1846,7 +1874,7 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 		}
 		return binding;
 	}
-	
+
 	protected MethodBinding findOverriddenMethodInType(ReferenceBinding overriddenType, MethodBinding overriding) throws JavaModelException {
 		if (overriddenType == null)
 			return null;
@@ -1861,7 +1889,7 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 		}
 		return null;
 	}
-	
+
 	private Object findMethodWithAttachedDocInHierarchy(final MethodBinding method) throws JavaModelException {
 		ReferenceBinding type= method.declaringClass;
 		final SelectionRequestor requestor1 = (SelectionRequestor) this.requestor;
@@ -1879,7 +1907,7 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 				IMember member = (IMember) requestor1.findMethodFromBinding(overridden, names, overridden.declaringClass);
 				if (member == null)
 					return InheritDocVisitor.CONTINUE;
-				if (member.getAttachedJavadoc(null) != null ) {  
+				if (member.getAttachedJavadoc(null) != null ) {
 					// for binary methods with attached javadoc and no source attached
 					return overridden;
 				}
@@ -1903,7 +1931,7 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 			}
 		}.visitInheritDoc(type);
 	}
-	
+
 	/**
 	 * Implements the "Algorithm for Inheriting Method Comments" as specified for
 	 * <a href="http://download.oracle.com/javase/6/docs/technotes/tools/windows/javadoc.html#inheritingcomments">1.6</a>.
@@ -1983,7 +2011,7 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 
 		/**
 		 * Visits the super interfaces of the given type in the given hierarchy, thereby skipping already visited types.
-		 * 
+		 *
 		 * @param visited set of visited types
 		 * @param currentType type whose super interfaces should be visited
 		 * @return the result, or {@link #CONTINUE} if no result has been found
@@ -2019,6 +2047,6 @@ public final class SelectionEngine extends Engine implements ISearchRequestor {
 	@Override
 	public void acceptModule(char[] moduleName) {
 		// TODO Auto-generated method stub
-		
+
 	}
 }
