@@ -107,6 +107,9 @@ public abstract class CategorizedProblem implements IProblem {
 	 * @since 3.18
 	 */
 	public static final int CAT_COMPLIANCE = 170;
+	/** Category for problems related to preview features
+	 * @since 3.20*/
+	public static final int CAT_PREVIEW_RELATED = 180;
 
 /**
  * Returns an integer identifying the category of this problem. Categories, like problem IDs are
