@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -2125,6 +2125,8 @@ void setSourceStart(int sourceStart);
 	int PreviewFeaturesNotAllowed = PreviewRelated + 1106;
 	/** @since 3.24*/
 	int FeatureNotSupported = Compliance + 1107;
+	/** @since 3.26*/
+	int PreviewAPIUsed = Compliance + 1108;
 
 	/** @since 3.13 */
 	int UnlikelyCollectionMethodArgumentType = 1200;
@@ -2259,107 +2261,112 @@ void setSourceStart(int sourceStart);
 	/* Java 15 errors begin */
 	/* records - begin */
 
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordIllegalModifierForInnerRecord = PreviewRelated + 1730;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordIllegalModifierForRecord = PreviewRelated + 1731;
-	/** @since 3.22
+	/** @since 3.26 */
+	int RecordIllegalModifierForInnerRecord = TypeRelated + 1730;
+	/** @since 3.26 */
+	int RecordIllegalModifierForRecord = TypeRelated + 1731;
+	/** @since 3.26
 	 * JLS 14 Sec 8.10.1
 	 * it is always a compile-time error for a record header to declare a record component with the name
 	 * finalize, getClass, hashCode, notify, notifyAll, or toString. */
-	int RecordIllegalComponentNameInRecord = PreviewRelated + 1732;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordNonStaticFieldDeclarationInRecord = PreviewRelated + 1733;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordAccessorMethodHasThrowsClause = PreviewRelated + 1734;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordCanonicalConstructorHasThrowsClause = PreviewRelated + 1735;
-	/** @since 3.24
-	 * @noreference preview feature error */
-	int RecordCanonicalConstructorVisibilityReduced = PreviewRelated + 1736;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordMultipleCanonicalConstructors = PreviewRelated + 1737;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordCompactConstructorHasReturnStatement = PreviewRelated + 1738;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordDuplicateComponent = PreviewRelated + 1739;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordIllegalNativeModifierInRecord = PreviewRelated + 1740;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordInstanceInitializerBlockInRecord = PreviewRelated + 1741;
-	/** @since 3.24
-	 * @noreference preview feature error */
-	int RestrictedTypeName = PreviewRelated + 1742;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordIllegalAccessorReturnType = PreviewRelated + 1743;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordAccessorMethodShouldNotBeGeneric = PreviewRelated + 1744;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordAccessorMethodShouldBePublic = PreviewRelated + 1745;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordCanonicalConstructorShouldNotBeGeneric = PreviewRelated + 1746;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordCanonicalConstructorHasReturnStatement = PreviewRelated + 1747;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordCanonicalConstructorHasExplicitConstructorCall = PreviewRelated + 1748;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordCompactConstructorHasExplicitConstructorCall = PreviewRelated + 1749;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordNestedRecordInherentlyStatic = PreviewRelated + 1750;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordAccessorMethodShouldNotBeStatic= PreviewRelated + 1751;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordCannotExtendRecord= PreviewRelated + 1752;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordComponentCannotBeVoid= PreviewRelated + 1753;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordIllegalVararg= PreviewRelated + 1754;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordStaticReferenceToOuterLocalVariable= PreviewRelated + 1755;
-	/** @since 3.22
-	 * @noreference preview feature error */
-	int RecordCannotDefineRecordInLocalType= PreviewRelated + 1756;
-	/** @since 3.24
-	 * @noreference preview feature error */
-	int RecordComponentsCannotHaveModifiers= PreviewRelated + 1757;
-	/** @since 3.24
-	 * @noreference preview feature error */
-	int RecordIllegalParameterNameInCanonicalConstructor = PreviewRelated + 1758;
-	/** @since 3.24
-	 * @noreference preview feature error */
-	int RecordIllegalExplicitFinalFieldAssignInCompactConstructor = PreviewRelated + 1759;
-	/** @since 3.23
-	 * @noreference preview feature error */
-	int RecordMissingExplicitConstructorCallInNonCanonicalConstructor= PreviewRelated + 1760;
-	/** @since 3.24
-	 * @noreference preview feature error */
-	int RecordIllegalStaticModifierForLocalClassOrInterface = PreviewRelated + 1761;
-	/** @since 3.24
-	 * @noreference preview feature error */
-	int RecordIllegalModifierForLocalRecord = PreviewRelated + 1762;
+	int RecordIllegalComponentNameInRecord = TypeRelated + 1732;
+	/** @since 3.26
+	 */
+	int RecordNonStaticFieldDeclarationInRecord = TypeRelated + 1733;
+	/** @since 3.26
+	 */
+	int RecordAccessorMethodHasThrowsClause = TypeRelated + 1734;
+	/** @since 3.26
+	 */
+	int RecordCanonicalConstructorHasThrowsClause = TypeRelated + 1735;
+	/** @since 3.26
+	 */
+	int RecordCanonicalConstructorVisibilityReduced = TypeRelated + 1736;
+	/** @since 3.26
+	 */
+	int RecordMultipleCanonicalConstructors = TypeRelated + 1737;
+	/** @since 3.26
+	 */
+	int RecordCompactConstructorHasReturnStatement = TypeRelated + 1738;
+	/** @since 3.26
+	 */
+	int RecordDuplicateComponent = TypeRelated + 1739;
+	/** @since 3.26
+	 */
+	int RecordIllegalNativeModifierInRecord = TypeRelated + 1740;
+	/** @since 3.26
+	 */
+	int RecordInstanceInitializerBlockInRecord = TypeRelated + 1741;
+	/** @since 3.26
+	 */
+	int RestrictedTypeName = TypeRelated + 1742;
+	/** @since 3.26
+	 */
+	int RecordIllegalAccessorReturnType = TypeRelated + 1743;
+	/** @since 3.26
+	 */
+	int RecordAccessorMethodShouldNotBeGeneric = TypeRelated + 1744;
+	/** @since 3.26
+	 */
+	int RecordAccessorMethodShouldBePublic = TypeRelated + 1745;
+	/** @since 3.26
+	 */
+	int RecordCanonicalConstructorShouldNotBeGeneric = TypeRelated + 1746;
+	/** @since 3.26
+	 */
+	int RecordCanonicalConstructorHasReturnStatement = TypeRelated + 1747;
+	/** @since 3.26
+	 */
+	int RecordCanonicalConstructorHasExplicitConstructorCall = TypeRelated + 1748;
+	/** @since 3.26
+	 */
+	int RecordCompactConstructorHasExplicitConstructorCall = TypeRelated + 1749;
+	/** @since 3.26
+	 */
+	int RecordNestedRecordInherentlyStatic = TypeRelated + 1750;
+	/** @since 3.26
+	 */
+	int RecordAccessorMethodShouldNotBeStatic= TypeRelated + 1751;
+	/** @since 3.26
+	 */
+	int RecordCannotExtendRecord= TypeRelated + 1752;
+	/** @since 3.26
+	 */
+	int RecordComponentCannotBeVoid= TypeRelated + 1753;
+	/** @since 3.26
+	 */
+	int RecordIllegalVararg= TypeRelated + 1754;
+	/** @since 3.26
+	 */
+	int RecordStaticReferenceToOuterLocalVariable= TypeRelated + 1755;
+	/** @since 3.26
+	 */
+	int RecordCannotDefineRecordInLocalType= TypeRelated + 1756;
+	/** @since 3.26
+	 */
+	int RecordComponentsCannotHaveModifiers= TypeRelated + 1757;
+	/** @since 3.26
+	 */
+	int RecordIllegalParameterNameInCanonicalConstructor = TypeRelated + 1758;
+	/** @since 3.26
+	 */
+	int RecordIllegalExplicitFinalFieldAssignInCompactConstructor = TypeRelated + 1759;
+	/** @since 3.26
+	 */
+	int RecordMissingExplicitConstructorCallInNonCanonicalConstructor= TypeRelated + 1760;
+	/** @since 3.26
+	 */
+	int RecordIllegalStaticModifierForLocalClassOrInterface = TypeRelated + 1761;
+	/** @since 3.26
+	 */
+	int RecordIllegalModifierForLocalRecord = TypeRelated + 1762;
+	/** @since 3.26
+	 */
+	int RecordIllegalExtendedDimensionsForRecordComponent = Syntax + Internal + 1763;
+	/** @since 3.26
+	 */
+	int SafeVarargsOnSyntheticRecordAccessor = TypeRelated + 1764;
+
 
 	/* records - end */
 	/* Local and Nested Static Declarations - Begin */
@@ -2376,7 +2383,22 @@ void setSourceStart(int sourceStart);
 	/** @since 3.22
 	 * @deprecated problem no longer generated */
 	int PatternVariableNotInScope = PreviewRelated + 1780;
+	/** @since 3.26
+	 */
+	int PatternVariableRedefined = Internal + 1781;
+	/** @since 3.26
+	 */
+	int PatternSubtypeOfExpression = Internal + 1782;
+	/** @since 3.26
+	 */
+	int IllegalModifierForPatternVariable = Internal + 1783;
+	/** @since 3.26
+	 */
+	int PatternVariableRedeclared = Internal + 1784;
 
+	/** @since 3.26
+	 * @noreference */
+	int DiscouragedValueBasedTypeSynchronization = Internal + 1820;
 
 	/** @since 3.24
 	 * @noreference preview feature error */
@@ -2426,6 +2448,12 @@ void setSourceStart(int sourceStart);
 	/** @since 3.24
 	 * @noreference preview feature error */
 	int SealedAnonymousClassCannotExtendSealedType = PreviewRelated + 1865;
+	/** @since 3.27
+	 * @noreference preview feature error */
+	int SealedSuperTypeInDifferentPackage = PreviewRelated + 1866;
+	/** @since 3.27
+	 * @noreference preview feature error */
+	int SealedSuperTypeDisallowed = PreviewRelated + 1867;
 	/* Java15 errors - end */
 
 	}
