@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -106,6 +106,9 @@ public abstract class ASTVisitor {
 	public void endVisit(Clinit clinit, ClassScope scope) {
 		// do nothing by default
 	}
+	public void endVisit(CompactConstructorDeclaration ccd, ClassScope scope) {
+		// do nothing by default
+	}
 	public void endVisit(
 		CompilationUnitDeclaration compilationUnitDeclaration,
 		CompilationUnitScope scope) {
@@ -241,6 +244,12 @@ public abstract class ASTVisitor {
 	public void endVisit(JavadocQualifiedTypeReference typeRef, ClassScope scope) {
 		// do nothing by default
 	}
+	public void endVisit(JavadocModuleReference moduleRef, BlockScope scope) {
+		// do nothing by default
+	}
+	public void endVisit(JavadocModuleReference moduleRef, ClassScope scope) {
+		// do nothing by default
+	}
 	public void endVisit(JavadocReturnStatement statement, BlockScope scope) {
 		// do nothing by default
 	}
@@ -487,6 +496,9 @@ public abstract class ASTVisitor {
 			ClassScope scope) {
 		// do nothing by default
 	}
+	public void endVisit(YieldStatement yieldStatement, BlockScope scope) {
+		// do nothing by default
+	}
 	public void endVisit(WhileStatement whileStatement, BlockScope scope) {
 		// do nothing by default
 	}
@@ -500,7 +512,7 @@ public abstract class ASTVisitor {
 		// do nothing by default
 	}
 	public void endVisit(ReferenceExpression referenceExpression, BlockScope blockScope) {
-		// do nothing by default	
+		// do nothing by default
 	}
 	public void endVisit(IntersectionCastTypeReference intersectionCastTypeReference, ClassScope scope) {
 		// do nothing by default
@@ -511,6 +523,9 @@ public abstract class ASTVisitor {
 	public void endVisit(SwitchExpression switchExpression,	BlockScope scope) {
 		// do nothing by default
 	}
+	public void endVisit(RecordComponent recordComponent, BlockScope scope) {
+		// do nothing by default, keep traversing
+	}
 	public boolean visit(
     		AllocationExpression allocationExpression,
     		BlockScope scope) {
@@ -593,6 +608,9 @@ public abstract class ASTVisitor {
 	public boolean visit(ModuleDeclaration module, CompilationUnitScope scope) {
 		return true;
 	}
+	public boolean visit(CompactConstructorDeclaration ccd, ClassScope scope) {
+		return true; // do nothing by default, keep traversing
+	}
 	public boolean visit(
 		CompilationUnitDeclaration compilationUnitDeclaration,
 		CompilationUnitScope scope) {
@@ -728,6 +746,12 @@ public abstract class ASTVisitor {
 	public boolean visit(JavadocQualifiedTypeReference typeRef, ClassScope scope) {
 		return true; // do nothing by default, keep traversing
 	}
+	public boolean visit(JavadocModuleReference moduleRef, BlockScope scope) {
+		return true; // do nothing by default, keep traversing
+	}
+	public boolean visit(JavadocModuleReference moduleRef, ClassScope scope) {
+		return true; // do nothing by default, keep traversing
+	}
 	public boolean visit(JavadocReturnStatement statement, BlockScope scope) {
 		return true; // do nothing by default, keep traversing
 	}
@@ -981,6 +1005,9 @@ public abstract class ASTVisitor {
 			ClassScope scope) {
 		return true; // do nothing by default, keep traversing
 	}
+	public boolean visit(YieldStatement yieldStatement, BlockScope scope) {
+		return true; // do nothing by default, keep traversing
+	}
 	public boolean visit(WhileStatement whileStatement, BlockScope scope) {
 		return true; // do nothing by default, keep traversing
 	}
@@ -1005,4 +1032,7 @@ public abstract class ASTVisitor {
 	public boolean visit(SwitchExpression switchExpression, BlockScope blockScope) {
 		return true; // do nothing by default, keep traversing
 	}
+	public  boolean visit(RecordComponent recordComponent, BlockScope scope) {
+		return true; // do nothing by default, keep traversing
+	}
 }
