@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -32,7 +32,6 @@ import org.eclipse.jdt.internal.compiler.codegen.*;
 import org.eclipse.jdt.internal.compiler.flow.*;
 import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 import org.eclipse.jdt.internal.compiler.impl.Constant;
-import org.eclipse.jdt.internal.compiler.impl.IrritantSet;
 import org.eclipse.jdt.internal.compiler.lookup.*;
 
 public class InstanceOfExpression extends OperatorExpression {
@@ -75,7 +74,7 @@ public FlowInfo analyseCode(BlockScope currentScope, FlowContext flowContext, Fl
 		flowContext.recordUsingNullReference(currentScope, local,
 				this.expression, FlowContext.CAN_ONLY_NULL | FlowContext.IN_INSTANCEOF, flowInfo);
 		// no impact upon enclosing try context
-		flowInfo =  FlowInfo.conditional(initsWhenTrue, flowInfo.copy());
+		flowInfo =  FlowInfo.conditional(initsWhenTrue.copy(), flowInfo.copy());
 	} else if (this.expression instanceof Reference) {
 		if (currentScope.compilerOptions().enableSyntacticNullAnalysisForFields) {
 			FieldBinding field = ((Reference)this.expression).lastFieldBinding();
@@ -106,6 +105,9 @@ public FlowInfo analyseCode(BlockScope currentScope, FlowContext flowContext, Fl
 */
 @Override
 public void generateCode(BlockScope currentScope, CodeStream codeStream, boolean valueRequired) {
+	if (this.elementVariable != null && this.elementVariable.binding != null) {
+		this.elementVariable.binding.modifiers &= ~ExtraCompilerModifiers.AccPatternVariable;
+	}
 	addPatternVariables(currentScope, codeStream);
 
 	int pc = codeStream.position;
@@ -251,6 +253,7 @@ public void addPatternVariables(BlockScope currentScope, CodeStream codeStream)
 public boolean resolvePatternVariable(BlockScope scope) {
 	if (this.elementVariable == null) return false;
 	if (this.elementVariable.binding == null) {
+		this.elementVariable.modifiers |= ExtraCompilerModifiers.AccPatternVariable;
 		this.elementVariable.resolve(scope, true);
 		// Kludge - to remove the AccBlankFinal added by the LocalDeclaration#resolve() due to the
 		// missing initializer
@@ -264,7 +267,7 @@ public boolean resolvePatternVariable(BlockScope scope) {
 }
 @Override
 public void collectPatternVariablesToScope(LocalVariableBinding[] variables, BlockScope scope) {
-	this.expression.collectPatternVariablesToScope(this.patternVarsWhenTrue, scope);
+	this.expression.collectPatternVariablesToScope(variables, scope);
 	if (this.elementVariable != null) {
 		if (this.elementVariable.binding == null) {
 			resolvePatternVariable(scope);
@@ -286,24 +289,13 @@ public void collectPatternVariablesToScope(LocalVariableBinding[] variables, Blo
 
 }
 @Override
-public void addPatternVariablesWhenTrue(LocalVariableBinding[] vars) {
-	if (this.patternVarsWhenTrue == null) {
-		this.getPatternVariablesWhenTrue();
-	}
-	if (vars == null || vars.length == 0) return;
-	if (this.patternVarsWhenTrue == null) {
-		this.patternVarsWhenTrue = vars;
-	} else {
-		int oldSize = this.patternVarsWhenTrue.length;
-		int newLength = oldSize + vars.length;
-		System.arraycopy(this.patternVarsWhenTrue, 0, (this.patternVarsWhenTrue = new LocalVariableBinding[newLength]), 0, oldSize);
-		System.arraycopy(vars, 0, this.patternVarsWhenTrue, oldSize, vars.length);
-	}
-}
-@Override
 public boolean containsPatternVariable() {
 	return this.elementVariable != null;
 }
+@Override
+protected LocalDeclaration getPatternVariableIntroduced() {
+	return this.elementVariable;
+}
 private void addSecretInstanceOfPatternExpressionValue(BlockScope scope1) {
 	LocalVariableBinding local =
 			new LocalVariableBinding(
@@ -322,7 +314,7 @@ private void addSecretInstanceOfPatternExpressionValue(BlockScope scope1) {
 public TypeBinding resolveType(BlockScope scope) {
 	this.constant = Constant.NotAConstant;
 	if (this.elementVariable != null)
-	addSecretInstanceOfPatternExpressionValue(scope);
+		addSecretInstanceOfPatternExpressionValue(scope);
 	resolvePatternVariable(scope);
 	TypeBinding checkedType = this.type.resolveType(scope, true /* check bounds*/);
 	if (this.expression instanceof CastExpression) {
@@ -340,15 +332,12 @@ public TypeBinding resolveType(BlockScope scope) {
 	if (this.secretInstanceOfPatternExpressionValue != null && expressionType != TypeBinding.NULL)
 		this.secretInstanceOfPatternExpressionValue.type = expressionType;
 
-		if (!checkedType.isReifiable()) {
+	if (!checkedType.isReifiable()) {
 		CompilerOptions options = scope.compilerOptions();
-		// If preview is disabled, report same as before, even at Java 14
-		if (options.complianceLevel < ClassFileConstants.JDK14 || !options.enablePreviewFeatures) {
+		// Report same as before for older compliances
+		if (options.complianceLevel < ClassFileConstants.JDK16) {
 			scope.problemReporter().illegalInstanceOfGenericType(checkedType, this);
 		} else {
-			if (options.isAnyEnabled(IrritantSet.PREVIEW)) {
-				scope.problemReporter().previewFeatureUsed(this.type.sourceStart, this.type.sourceEnd);
-			}
 			if (expressionType != TypeBinding.NULL) {
 				boolean isLegal = checkCastTypesCompatibility(scope, checkedType, expressionType, this.expression, true);
 				if (!isLegal || (this.bits & ASTNode.UnsafeCast) != 0) {
@@ -364,6 +353,11 @@ public TypeBinding resolveType(BlockScope scope) {
 			scope.problemReporter().notCompatibleTypesError(this, expressionType, checkedType);
 		}
 	}
+	// finally, the subtype check
+	if (this.secretInstanceOfPatternExpressionValue != null &&
+			expressionType.isSubtypeOf(checkedType, false)) {
+		scope.problemReporter().patternCannotBeSubtypeOfExpression(this.elementVariable.binding, this);
+	}
 	return this.resolvedType = TypeBinding.BOOLEAN;
 }
 @Override
