@@ -437,7 +437,7 @@ public void generateCompoundAssignment(BlockScope currentScope, CodeStream codeS
 	boolean isFirst = lastFieldBinding == this.binding
 		&& (this.indexOfFirstFieldBinding == 1 || TypeBinding.equalsEquals(lastFieldBinding.declaringClass, currentScope.enclosingReceiverType()))
 		&& this.otherBindings == null; // could be dup: next.next.next
-	TypeBinding constantPoolDeclaringClass = CodeStream.getConstantPoolDeclaringClass(currentScope, lastFieldBinding, getFinalReceiverType(), isFirst);			
+	TypeBinding constantPoolDeclaringClass = CodeStream.getConstantPoolDeclaringClass(currentScope, lastFieldBinding, getFinalReceiverType(), isFirst);
 	SyntheticMethodBinding accessor = this.syntheticReadAccessors == null ? null : this.syntheticReadAccessors[this.syntheticReadAccessors.length - 1];
 	if (lastFieldBinding.isStatic()) {
 		if (accessor == null) {
@@ -491,7 +491,7 @@ public void generatePostIncrement(BlockScope currentScope, CodeStream codeStream
 	boolean isFirst = lastFieldBinding == this.binding
 		&& (this.indexOfFirstFieldBinding == 1 || TypeBinding.equalsEquals(lastFieldBinding.declaringClass, currentScope.enclosingReceiverType()))
 		&& this.otherBindings == null; // could be dup: next.next.next
-	TypeBinding constantPoolDeclaringClass = CodeStream.getConstantPoolDeclaringClass(currentScope, lastFieldBinding, getFinalReceiverType(), isFirst);			
+	TypeBinding constantPoolDeclaringClass = CodeStream.getConstantPoolDeclaringClass(currentScope, lastFieldBinding, getFinalReceiverType(), isFirst);
 	SyntheticMethodBinding accessor = this.syntheticReadAccessors == null
 			? null
 			: this.syntheticReadAccessors[this.syntheticReadAccessors.length - 1];
@@ -516,7 +516,7 @@ public void generatePostIncrement(BlockScope currentScope, CodeStream codeStream
 		operandType = requiredGenericCast;
 	} else {
 		operandType = lastFieldBinding.type;
-	}		
+	}
 	// duplicate the old field value
 	if (valueRequired) {
 		if (lastFieldBinding.isStatic()) {
@@ -528,7 +528,7 @@ public void generatePostIncrement(BlockScope currentScope, CodeStream codeStream
 				default:
 					codeStream.dup();
 					break;
-			}			
+			}
 		} else { // Stack:  [owner][old field value]  ---> [old field value][owner][old field value]
 			switch (operandType.id) {
 				case TypeIds.T_long :
@@ -538,10 +538,10 @@ public void generatePostIncrement(BlockScope currentScope, CodeStream codeStream
 				default:
 					codeStream.dup_x1();
 					break;
-			}			
+			}
 		}
 	}
-	codeStream.generateImplicitConversion(this.implicitConversion);		
+	codeStream.generateImplicitConversion(this.implicitConversion);
 	codeStream.generateConstant(
 		postIncrement.expression.constant,
 		this.implicitConversion);
@@ -720,7 +720,7 @@ protected TypeBinding getFinalReceiverType() {
 		default:
 			TypeBinding previousGenericCast = this.otherGenericCasts == null ? null : this.otherGenericCasts[otherBindingsCount-2];
 			return previousGenericCast != null ? previousGenericCast : this.otherBindings[otherBindingsCount-2].type;
-	}	
+	}
 }
 
 // get the matching generic cast
@@ -775,7 +775,7 @@ public TypeBinding getOtherFieldBindings(BlockScope scope) {
 				FieldBinding originalBinding = previousField.original();
 				if (TypeBinding.notEquals(fieldReceiverType, oldReceiverType) || originalBinding.type.leafComponentType().isTypeVariable()) { // record need for explicit cast at codegen
 			    	setGenericCast(index-1,originalBinding.type.genericCast(fieldReceiverType)); // type cannot be base-type even in boxing case
-				}				
+				}
 		    }
 			// only last field is actually a write access if any
 			if (isFieldUseDeprecated(field, scope, index+1 == length ? this.bits : 0)) {
@@ -787,7 +787,7 @@ public TypeBinding getOtherFieldBindings(BlockScope scope) {
 			}
 
 			if (field.isStatic()) {
-				if ((field.modifiers & ClassFileConstants.AccEnum) != 0 && !scope.isModuleScope()) {
+				if ((field.modifiers & ClassFileConstants.AccEnum) != 0 && scope.kind != Scope.MODULE_SCOPE) {
 					// enum constants are checked even when qualified -- modules don't contain field declarations
 					ReferenceBinding declaringClass = field.original().declaringClass;
 					MethodScope methodScope = scope.methodScope();
@@ -798,7 +798,7 @@ public TypeBinding getOtherFieldBindings(BlockScope scope) {
 							&& field.id >= methodScope.lastVisibleFieldID
 							&& (!field.isStatic() || methodScope.isStatic)) {
 						scope.problemReporter().forwardReference(this, index, field);
-					}					
+					}
 					// check if accessing enum static field in initializer
 					if ((TypeBinding.equalsEquals(sourceType, declaringClass) || TypeBinding.equalsEquals(sourceType.superclass, declaringClass)) // enum constant body
 							&& field.constant(scope) == Constant.NotAConstant
@@ -864,7 +864,7 @@ public boolean isFieldAccess() {
 @Override
 public FieldBinding lastFieldBinding() {
 	if (this.otherBindings != null) {
-		return this.otherBindings[this.otherBindings.length - 1];		
+		return this.otherBindings[this.otherBindings.length - 1];
 	} else if (this.binding != null && (this.bits & RestrictiveFlagMASK) == Binding.FIELD) {
 		return (FieldBinding) this.binding;
 	}
@@ -928,17 +928,19 @@ public void manageSyntheticAccessIfNecessary(BlockScope currentScope, FieldBindi
 
 @Override
 public Constant optimizedBooleanConstant() {
-	switch (this.resolvedType.id) {
-		case T_boolean :
-		case T_JavaLangBoolean :
-			if (this.constant != Constant.NotAConstant) return this.constant;
-			switch (this.bits & ASTNode.RestrictiveFlagMASK) {
-				case Binding.FIELD : // reading a field
-					if (this.otherBindings == null)
-						return ((FieldBinding)this.binding).constant();
-					//$FALL-THROUGH$
-				case Binding.LOCAL : // reading a local variable
-					return this.otherBindings[this.otherBindings.length-1].constant();
+	if (this.binding.isValidBinding() && this.resolvedType != null) {
+		switch (this.resolvedType.id) {
+			case T_boolean :
+			case T_JavaLangBoolean :
+				if (this.constant != Constant.NotAConstant) return this.constant;
+				switch (this.bits & ASTNode.RestrictiveFlagMASK) {
+					case Binding.FIELD : // reading a field
+						if (this.otherBindings == null)
+							return ((FieldBinding)this.binding).constant();
+						//$FALL-THROUGH$
+					case Binding.LOCAL : // reading a local variable
+						return this.otherBindings[this.otherBindings.length-1].constant();
+			}
 		}
 	}
 	return Constant.NotAConstant;
@@ -1000,7 +1002,12 @@ public StringBuffer printExpression(int indent, StringBuffer output) {
  * Normal field binding did not work, try to bind to a field of the delegate receiver.
  */
 public TypeBinding reportError(BlockScope scope) {
-	if (this.binding instanceof ProblemFieldBinding) {
+	Binding inaccessible = scope.environment().getInaccessibleBinding(this.tokens, scope.module());
+	if (inaccessible instanceof TypeBinding) {
+		this.indexOfFirstFieldBinding = -1;
+		this.binding = inaccessible;
+		scope.problemReporter().invalidType(this, (TypeBinding) this.binding);
+	} else if (this.binding instanceof ProblemFieldBinding) {
 		scope.problemReporter().invalidField(this, (FieldBinding) this.binding);
 	} else if (this.binding instanceof ProblemReferenceBinding || this.binding instanceof MissingTypeBinding) {
 		scope.problemReporter().invalidType(this, (TypeBinding) this.binding);
@@ -1025,7 +1032,7 @@ public TypeBinding resolveType(BlockScope scope) {
 					this.bits &= ~ASTNode.RestrictiveFlagMASK; // clear bits
 					this.bits |= Binding.LOCAL;
 					LocalVariableBinding local = (LocalVariableBinding) this.binding;
-					if (!local.isFinal() && (this.bits & ASTNode.IsCapturedOuterLocal) != 0) { 
+					if (!local.isFinal() && (this.bits & ASTNode.IsCapturedOuterLocal) != 0) {
 						if (scope.compilerOptions().sourceLevel < ClassFileConstants.JDK1_8) // for 8, defer till effective finality could be ascertained.
 							scope.problemReporter().cannotReferToNonFinalOuterLocal((LocalVariableBinding) this.binding, this);
 					}
@@ -1045,11 +1052,15 @@ public TypeBinding resolveType(BlockScope scope) {
 					this.bits &= ~ASTNode.RestrictiveFlagMASK; // clear bits
 					this.bits |= Binding.FIELD;
 					FieldBinding fieldBinding = (FieldBinding) this.binding;
-					MethodScope methodScope = scope.methodScope();
 					ReferenceBinding declaringClass = fieldBinding.original().declaringClass;
-					SourceTypeBinding sourceType = methodScope.enclosingSourceType();
+					MethodScope methodScope = null;
+					SourceTypeBinding sourceType = null;
+					if (scope.kind != Scope.MODULE_SCOPE) {
+						methodScope = scope.methodScope();
+						sourceType = methodScope.enclosingSourceType();
+					}
 					// check for forward references
-					if (!scope.isModuleScope()) {
+					if (scope.kind != Scope.MODULE_SCOPE) {
 						if ((this.indexOfFirstFieldBinding == 1 || (fieldBinding.modifiers & ClassFileConstants.AccEnum) != 0 || (!fieldBinding.isFinal() && declaringClass.isEnum())) // enum constants are checked even when qualified
 								&& TypeBinding.equalsEquals(sourceType, declaringClass)
 								&& methodScope.lastVisibleFieldID >= 0
@@ -1063,12 +1074,12 @@ public TypeBinding resolveType(BlockScope scope) {
 						}
 					}
 					if (isFieldUseDeprecated(fieldBinding, scope, this.indexOfFirstFieldBinding == this.tokens.length ? this.bits : 0)) {
-						scope.problemReporter().deprecatedField(fieldBinding, this);	
+						scope.problemReporter().deprecatedField(fieldBinding, this);
 					}
 					if (fieldBinding.isStatic()) {
 						// only last field is actually a write access if any
 						// check if accessing enum static field in initializer
-						if (declaringClass.isEnum() && !scope.isModuleScope()) {
+						if (declaringClass.isEnum() && scope.kind != Scope.MODULE_SCOPE) {
 							if ((TypeBinding.equalsEquals(sourceType, declaringClass) || TypeBinding.equalsEquals(sourceType.superclass, declaringClass)) // enum constant body
 									&& fieldBinding.constant(scope) == Constant.NotAConstant
 									&& !methodScope.isStatic
@@ -1080,7 +1091,7 @@ public TypeBinding resolveType(BlockScope scope) {
 								&& TypeBinding.notEquals(fieldBinding.declaringClass, this.actualReceiverType)
 								&& fieldBinding.declaringClass.canBeSeenBy(scope)) {
 							scope.problemReporter().indirectAccessToStaticField(this, fieldBinding);
-						}						
+						}
 					} else {
 						boolean inStaticContext = scope.methodScope().isStatic;
 						if (this.indexOfFirstFieldBinding == 1) {
@@ -1098,7 +1109,7 @@ public TypeBinding resolveType(BlockScope scope) {
 							return null;
 						 }
 					}
-					
+
 					this.resolvedType = getOtherFieldBindings(scope);
 					if (this.resolvedType != null
 							&& (this.resolvedType.tagBits & TagBits.HasMissingType) != 0) {
