@@ -360,19 +360,6 @@ public Annotation[][] annotations = null;
 public void aboutToResolve(Scope scope) {
 	// default implementation: do nothing
 }
-private void checkYieldUsage(Scope currentScope) {
-	char [][] qName = getTypeName();
-	String name = qName != null && qName[0] != null ? new String(qName[0]) : null;
-	long sourceLevel = currentScope.compilerOptions().sourceLevel;
-	if (sourceLevel < ClassFileConstants.JDK14 || name == null ||
-			!("yield".equals(new String(name)))) //$NON-NLS-1$
-		return;
-	if (sourceLevel >= ClassFileConstants.JDK14) {
-		currentScope.problemReporter().switchExpressionsYieldTypeDeclarationError(this);
-	} else {
-		currentScope.problemReporter().switchExpressionsYieldTypeDeclarationWarning(this);
-	}
-}
 @Override
 public FlowInfo analyseCode(BlockScope currentScope, FlowContext flowContext, FlowInfo flowInfo) {
 	return flowInfo;
@@ -515,7 +502,6 @@ public abstract char [][] getTypeName() ;
 protected TypeBinding internalResolveType(Scope scope, int location) {
 	// handle the error here
 	this.constant = Constant.NotAConstant;
-	checkYieldUsage(scope);
 	if (this.resolvedType != null) { // is a shared type reference which was already resolved
 		if (this.resolvedType.isValidBinding()) {
 			return this.resolvedType;
