@@ -56,9 +56,9 @@ public class CompilationUnitScope extends Scope {
 
 	HashtableOfType constantPoolNameUsage;
 	private int captureID = 1;
-	
+
 	private ImportBinding[] tempImports;	// to keep a record of resolved imports while traversing all in faultInImports()
-	
+
 	/**
 	 * Skips import caching if unresolved imports were
 	 * found last time.
@@ -365,6 +365,10 @@ public char[] computeConstantPoolName(LocalTypeBinding localType) {
 void connectTypeHierarchy() {
 	for (int i = 0, length = this.topLevelTypes.length; i < length; i++)
 		this.topLevelTypes[i].scope.connectTypeHierarchy();
+	// Wait for all hierarchy information to be built before
+	// checking on permitted types
+	for (int i = 0, length = this.topLevelTypes.length; i < length; i++)
+		this.topLevelTypes[i].scope.connectImplicitPermittedTypes();
 }
 void faultInImports() {
 	if (this.tempImports != null)
@@ -413,13 +417,13 @@ void faultInImports() {
 	// single imports change from being just types to types or fields
 	nextImport : for (int i = 0; i < numberOfStatements; i++) {
 		ImportReference importReference = this.referenceContext.imports[i];
-		char[][] compoundName = importReference.tokens;
+		char[][] compoundName = importReference.getImportName();
 
 		// skip duplicates or imports of the current package
 		for (int j = 0; j < this.importPtr; j++) {
 			ImportBinding resolved = this.tempImports[j];
 			if (resolved.onDemand == ((importReference.bits & ASTNode.OnDemand) != 0) && resolved.isStatic() == importReference.isStatic()) {
-				if (CharOperation.equals(compoundName, resolved.compoundName)) {
+				if (CharOperation.equals(compoundName, resolved.compoundName) && CharOperation.equals(importReference.getSimpleName(), resolved.getSimpleName())) {
 					problemReporter().unusedImport(importReference); // since skipped, must be reported now
 					continue nextImport;
 				}
@@ -485,7 +489,7 @@ void faultInImports() {
 					}
 				}
 			}
-			// all the code here which checks for valid bindings have been moved to the method 
+			// all the code here which checks for valid bindings have been moved to the method
 			// checkAndRecordImportBinding() since bug 361327
 			if(checkAndRecordImportBinding(importBinding, typesBySimpleNames, importReference, compoundName) == -1)
 				continue nextImport;
@@ -495,7 +499,7 @@ void faultInImports() {
 				// So if a type is found, no fields and methods are available anyway
 				// similarly when method is found, type may be available but no field available for sure
 				if (importBinding.kind() == Binding.FIELD) {
-					checkMoreStaticBindings(compoundName, typesBySimpleNames, Binding.TYPE | Binding.METHOD, importReference);		
+					checkMoreStaticBindings(compoundName, typesBySimpleNames, Binding.TYPE | Binding.METHOD, importReference);
 				} else if (importBinding.kind() == Binding.METHOD) {
 					checkMoreStaticBindings(compoundName, typesBySimpleNames, Binding.TYPE, importReference);
 				}
@@ -513,7 +517,7 @@ void faultInImports() {
 	for (int i = 0; i < length; i++) {
 		ImportBinding binding = this.imports[i];
 		if (!binding.onDemand && binding.resolvedImport instanceof ReferenceBinding || binding instanceof ImportConflictBinding)
-			this.typeOrPackageCache.put(binding.compoundName[binding.compoundName.length - 1], binding);
+			this.typeOrPackageCache.put(binding.getSimpleName(), binding);
 	}
 	this.skipCachingImports = this.environment.suppressImportErrors && unresolvedFound;
 }
@@ -939,7 +943,7 @@ private void recordImportBinding(ImportBinding bindingToAdd) {
 	this.tempImports[this.importPtr++] = bindingToAdd;
 }
 /**
- * Checks additional bindings (methods or types) imported from a single static import. 
+ * Checks additional bindings (methods or types) imported from a single static import.
  * Method is tried first, followed by type. If found, records them.
  * If in the process, import is flagged as duplicate, -1 is returned.
  * @param compoundName
@@ -948,8 +952,8 @@ private void recordImportBinding(ImportBinding bindingToAdd) {
  * @param importReference
  */
 private void checkMoreStaticBindings(
-		char[][] compoundName, 
-		HashtableOfType typesBySimpleNames, 
+		char[][] compoundName,
+		HashtableOfType typesBySimpleNames,
 		int mask,
 		ImportReference importReference) {
 	Binding importBinding = findSingleStaticImport(compoundName, mask);
@@ -982,8 +986,8 @@ private void checkMoreStaticBindings(
  * @return -1 when this import is flagged as duplicate, importPtr otherwise.
  */
 private int checkAndRecordImportBinding(
-		Binding importBinding, 
-		HashtableOfType typesBySimpleNames, 
+		Binding importBinding,
+		HashtableOfType typesBySimpleNames,
 		ImportReference importReference,
 		char[][] compoundName) {
 	ReferenceBinding conflictingType = null;
@@ -993,7 +997,7 @@ private int checkAndRecordImportBinding(
 			conflictingType = null;
 	}
 	// collisions between an imported static field & a type should be checked according to spec... but currently not by javac
-	final char[] name = compoundName[compoundName.length - 1];
+	final char[] name = importReference.getSimpleName();
 	if (importBinding instanceof ReferenceBinding || conflictingType != null) {
 		ReferenceBinding referenceBinding = conflictingType == null ? (ReferenceBinding) importBinding : conflictingType;
 		ReferenceBinding typeToCheck = referenceBinding.problemId() == ProblemReasons.Ambiguous
@@ -1039,7 +1043,7 @@ private int checkAndRecordImportBinding(
 				for (int j = 0; j < this.importPtr; j++) {
 					ImportBinding resolved = this.tempImports[j];
 					if (resolved.isStatic() && resolved.resolvedImport instanceof ReferenceBinding && importBinding != resolved.resolvedImport) {
-						if (CharOperation.equals(name, resolved.compoundName[resolved.compoundName.length - 1])) {
+						if (CharOperation.equals(compoundName[compoundName.length - 1], resolved.compoundName[resolved.compoundName.length - 1])) {
 							ReferenceBinding type = (ReferenceBinding) resolved.resolvedImport;
 							resolved.resolvedImport = new ProblemReferenceBinding(new char[][] { name }, type, ProblemReasons.Ambiguous);
 							return -1;
