@@ -344,7 +344,7 @@ public class ParameterizedTypeBinding extends ReferenceBinding implements Substi
 
 	@Override
 	public char[] computeUniqueKey(boolean isLeaf) {
-	    StringBuffer sig = new StringBuffer(10);
+	    StringBuilder sig = new StringBuilder(10);
 	    ReferenceBinding enclosing;
 		if (isMemberType() && ((enclosing = enclosingType()).isParameterizedType() || enclosing.isRawType())) {
 		    char[] typeSig = enclosing.computeUniqueKey(false/*not a leaf*/);
@@ -411,7 +411,7 @@ public class ParameterizedTypeBinding extends ReferenceBinding implements Substi
 	public String debugName() {
 	    if (this.hasTypeAnnotations())
 	    	return annotatedDebugName();
-		StringBuffer nameBuffer = new StringBuffer(10);
+		StringBuilder nameBuffer = new StringBuilder(10);
 	    if (this.type instanceof UnresolvedReferenceBinding) {
 	    	nameBuffer.append(this.type);
 	    } else {
@@ -430,7 +430,7 @@ public class ParameterizedTypeBinding extends ReferenceBinding implements Substi
 
 	@Override
 	public String annotatedDebugName() {
-		StringBuffer nameBuffer = new StringBuffer(super.annotatedDebugName());
+		StringBuilder nameBuffer = new StringBuilder(super.annotatedDebugName());
 		if (this.arguments != null && this.arguments.length > 0) {
 			nameBuffer.append('<');
 			for (int i = 0, length = this.arguments.length; i < length; i++) {
@@ -630,7 +630,7 @@ public class ParameterizedTypeBinding extends ReferenceBinding implements Substi
 			if ((this.modifiers & ExtraCompilerModifiers.AccGenericSignature) == 0) {
 		    	this.genericTypeSignature = this.type.signature();
 			} else {
-			    StringBuffer sig = new StringBuffer(10);
+			    StringBuilder sig = new StringBuilder(10);
 			    if (isMemberType() && !isStatic()) {
 			    	ReferenceBinding enclosing = enclosingType();
 					char[] typeSig = enclosing.genericTypeSignature();
@@ -875,6 +875,11 @@ public class ParameterizedTypeBinding extends ReferenceBinding implements Substi
 		return this.type.hasMethodWithNumArgs(selector, numArgs);
 	}
 
+	@Override
+	public boolean hasValueBasedTypeAnnotation() {
+		return this.type.hasValueBasedTypeAnnotation();
+	}
+
 	/**
 	 * @see org.eclipse.jdt.internal.compiler.lookup.ReferenceBinding#implementsMethod(MethodBinding)
 	 */
@@ -1189,7 +1194,7 @@ public class ParameterizedTypeBinding extends ReferenceBinding implements Substi
 	}
 	@Override
 	public char[] readableName(boolean showGenerics) {
-	    StringBuffer nameBuffer = new StringBuffer(10);
+	    StringBuilder nameBuffer = new StringBuilder(10);
 		if (isMemberType()) {
 			nameBuffer.append(CharOperation.concat(enclosingType().readableName(showGenerics && !isStatic()), this.sourceName, '.'));
 		} else {
@@ -1272,7 +1277,7 @@ public class ParameterizedTypeBinding extends ReferenceBinding implements Substi
 	}
 	@Override
 	public char[] shortReadableName(boolean showGenerics) {
-	    StringBuffer nameBuffer = new StringBuffer(10);
+	    StringBuilder nameBuffer = new StringBuilder(10);
 		if (isMemberType()) {
 			nameBuffer.append(CharOperation.concat(enclosingType().shortReadableName(showGenerics && !isStatic()), this.sourceName, '.'));
 		} else {
@@ -1509,7 +1514,7 @@ public class ParameterizedTypeBinding extends ReferenceBinding implements Substi
 		if (this.hasTypeAnnotations()) {
 			return annotatedDebugName();
 		}
-		StringBuffer buffer = new StringBuffer(30);
+		StringBuilder buffer = new StringBuilder(30);
 		if (this.type instanceof UnresolvedReferenceBinding) {
 	    	buffer.append(debugName());
 	    } else {
