@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2004, 2019 IBM Corporation and others.
+ * Copyright (c) 2004, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -27,8 +27,8 @@ import org.eclipse.core.runtime.SubMonitor;
 import org.eclipse.jdt.core.IClassFile;
 import org.eclipse.jdt.core.ICompilationUnit;
 import org.eclipse.jdt.core.IJavaElement;
-import org.eclipse.jdt.core.ITypeRoot;
 import org.eclipse.jdt.core.IJavaProject;
+import org.eclipse.jdt.core.ITypeRoot;
 import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.core.JavaModelException;
 import org.eclipse.jdt.core.WorkingCopyOwner;
@@ -37,14 +37,19 @@ import org.eclipse.jdt.core.compiler.CharOperation;
 import org.eclipse.jdt.internal.compiler.ast.CompilationUnitDeclaration;
 import org.eclipse.jdt.internal.compiler.ast.ConstructorDeclaration;
 import org.eclipse.jdt.internal.compiler.ast.ExplicitConstructorCall;
-import org.eclipse.jdt.internal.compiler.batch.Main;
 import org.eclipse.jdt.internal.compiler.batch.FileSystem.Classpath;
+import org.eclipse.jdt.internal.compiler.batch.Main;
 import org.eclipse.jdt.internal.compiler.env.IBinaryType;
 import org.eclipse.jdt.internal.compiler.parser.RecoveryScanner;
 import org.eclipse.jdt.internal.compiler.parser.RecoveryScannerData;
 import org.eclipse.jdt.internal.compiler.parser.Scanner;
 import org.eclipse.jdt.internal.compiler.util.SuffixConstants;
-import org.eclipse.jdt.internal.core.*;
+import org.eclipse.jdt.internal.core.BasicCompilationUnit;
+import org.eclipse.jdt.internal.core.BinaryType;
+import org.eclipse.jdt.internal.core.ClassFileWorkingCopy;
+import org.eclipse.jdt.internal.core.DefaultWorkingCopyOwner;
+import org.eclipse.jdt.internal.core.PackageFragment;
+import org.eclipse.jdt.internal.core.dom.util.DOMASTUtil;
 import org.eclipse.jdt.internal.core.util.CodeSnippetParsingUtil;
 import org.eclipse.jdt.internal.core.util.RecordedParsingInformation;
 import org.eclipse.jdt.internal.core.util.Util;
@@ -148,7 +153,7 @@ public class ASTParser {
 	 * Compiler options. Defaults to JavaCore.getOptions().
 	 */
 	private Map<String, String> compilerOptions;
-	
+
     /**
 	 * The focal point for a partial AST request.
      * Only used when <code>partial</code> is <code>true</code>.
@@ -195,7 +200,7 @@ public class ASTParser {
 	 * <code>null</code> if none. Defaults to none.
      */
 	private String unitName = null;
-	
+
 	/**
 	 * Classpath entries to use to resolve bindings when no java project are available.
 	 */
@@ -205,12 +210,12 @@ public class ASTParser {
 	 * Sourcepath entries to use to resolve bindings when no java project are available.
 	 */
 	private String[] sourcepaths;
-	
+
 	/**
 	 * Encoding of the given sourcepaths entries.
 	 */
 	private String[] sourcepathsEncodings;
-	
+
 	/**
 	 * Bits used to set the different values from CompilationUnitResolver values.
 	 */
@@ -226,19 +231,7 @@ public class ASTParser {
 	 * declared on {@link AST}
 	 */
 	ASTParser(int level) {
-		switch(level) {
-			case AST.JLS2_INTERNAL:
-			case AST.JLS3_INTERNAL:
-			case AST.JLS4_INTERNAL:
-			case AST.JLS8_INTERNAL:
-			case AST.JLS9_INTERNAL:
-			case AST.JLS10_INTERNAL:
-			case AST.JLS11_INTERNAL:
-			case AST.JLS12_INTERNAL:
-				break;
-			default:
-				throw new IllegalArgumentException();
-		}
+		DOMASTUtil.checkASTLevel(level);
 		this.apiLevel = level;
 		initializeDefaults();
 	}
@@ -317,19 +310,19 @@ public class ASTParser {
 			this.bits &= ~CompilationUnitResolver.BINDING_RECOVERY;
 		}
 	}
-	
+
 	/**
 	 * Sets the environment to be used when no {@link IJavaProject} is available.
-	 * 
-	 * <p>The user has to make sure that all the required types are included either in the classpath or source paths. 
-	 * All the paths containing binary types must be included in the <code>classpathEntries</code> whereas all paths containing  
+	 *
+	 * <p>The user has to make sure that all the required types are included either in the classpath or source paths.
+	 * All the paths containing binary types must be included in the <code>classpathEntries</code> whereas all paths containing
 	 * source types must be included in the <code>sourcepathEntries</code>.</p>
 	 * <p>All paths in the <code>classpathEntries</code> and <code>sourcepathEntries</code> are absolute paths.</p>
 	 * <p>If the source paths contain units using a specific encoding (other than the platform encoding), then the
 	 * given <code>encodings</code> must be set. When the <code>encodings</code> is set to non <code>null</code>, its length must
 	 * match the length of <code>sourcepathEntries</code> or an IllegalArgumentException will be thrown.</p>
 	 * <p>If <code>encodings</code> is not <code>null</code>, the given <code>sourcepathEntries</code> must not be <code>null</code>.</p>
-	 * 
+	 *
 	 * @param classpathEntries the given classpath entries to be used to resolve bindings
 	 * @param sourcepathEntries the given sourcepath entries to be used to resolve bindings
 	 * @param encodings the encodings of the corresponding sourcepath entries or <code>null</code> if the platform encoding
@@ -346,7 +339,7 @@ public class ASTParser {
 		this.sourcepathsEncodings = encodings;
 		if (encodings != null) {
 			if (sourcepathEntries == null || sourcepathEntries.length != encodings.length) {
-				throw new IllegalArgumentException(); 
+				throw new IllegalArgumentException();
 			}
 		}
 		if (includeRunningVMBootclasspath) {
@@ -431,7 +424,7 @@ public class ASTParser {
 	 * or {@link #setSource(IClassFile) setSource(IClassFile)}.
 	 * When source is supplied by {@link #setSource(char[]) setSource(char[])},
 	 * the location must be established explicitly by setting an environment using
-	 * {@link #setProject(IJavaProject)} or {@link #setEnvironment(String[], String[], String[], boolean)} 
+	 * {@link #setProject(IJavaProject)} or {@link #setEnvironment(String[], String[], String[], boolean)}
 	 * and a unit name {@link #setUnitName(String)}.
 	 * Note that the compiler options that affect doc comment checking may also
 	 * affect whether any bindings are resolved for nodes within doc comments.
@@ -452,7 +445,7 @@ public class ASTParser {
 	 * Requests an abridged abstract syntax tree.
 	 * By default, complete ASTs are returned.
 	 * <p>
-	 * When the given <code>position</code> is a valid position within the source code of 
+	 * When the given <code>position</code> is a valid position within the source code of
 	 * the compilation unit, the resulting AST does not have nodes for
 	 * the entire compilation unit. Rather, the AST is only fleshed out
 	 * for the node that include the given source position. This kind of limited
@@ -483,9 +476,9 @@ public class ASTParser {
 	 * compilation unit.
 	 * </p>
 	 *
-	 * <p>This focal position is not used when the AST is built using 
+	 * <p>This focal position is not used when the AST is built using
 	 * {@link #createASTs(ICompilationUnit[], String[], ASTRequestor, IProgressMonitor)}.</p>
-	 * 
+	 *
 	 * @param position a position into the corresponding body declaration
 	 */
 	public void setFocalPosition(int position) {
@@ -561,10 +554,10 @@ public class ASTParser {
 	 * Binding information is only computed when <code>kind</code> is
 	 * {@link #K_COMPILATION_UNIT}.
 	 * </p>
-	 * 
+	 *
 	 * <p>This kind is not used when the AST is built using
 	 * {@link #createASTs(ICompilationUnit[], String[], ASTRequestor, IProgressMonitor)}.</p>
-	 * 
+	 *
 	 * @param kind the kind of construct to parse: one of
 	 * {@link #K_COMPILATION_UNIT},
 	 * {@link #K_CLASS_BODY_DECLARATIONS},
@@ -584,7 +577,7 @@ public class ASTParser {
 	/**
 	 * Sets the source code to be parsed.
 	 *
-	 * <p>This source is not used when the AST is built using 
+	 * <p>This source is not used when the AST is built using
 	 * {@link #createASTs(ICompilationUnit[], String[], ASTRequestor, IProgressMonitor)}.</p>
 	 *
 	 * <p>If this method is used, the user needs to specify compiler options explicitly using
@@ -605,14 +598,14 @@ public class ASTParser {
 
 	/**
 	 * Sets the source code to be parsed.
-	 * 
+	 *
 	 * <p>This method automatically sets the project (and compiler
 	 * options) based on the given compilation unit, in a manner
 	 * equivalent to {@link #setProject(IJavaProject) setProject(source.getJavaProject())}.</p>
 	 *
-	 * <p>This source is not used when the AST is built using 
+	 * <p>This source is not used when the AST is built using
 	 * {@link #createASTs(ICompilationUnit[], String[], ASTRequestor, IProgressMonitor)}.</p>
-	 * 
+	 *
 	 * @param source the Java model compilation unit whose source code
 	 * is to be parsed, or <code>null</code> if none
 	 */
@@ -629,9 +622,9 @@ public class ASTParser {
 	 * <p>If the given class file has  no source attachment, the creation of the
 	 * ast will fail with an {@link IllegalStateException}.</p>
 	 *
-	 * <p>This source is not used when the AST is built using 
+	 * <p>This source is not used when the AST is built using
 	 * {@link #createASTs(ICompilationUnit[], String[], ASTRequestor, IProgressMonitor)}.</p>
-	 * 
+	 *
 	 * @param source the Java model class file whose corresponding source code
 	 * is to be parsed, or <code>null</code> if none
 	 */
@@ -648,7 +641,7 @@ public class ASTParser {
 	 * <p>If the source is a class file without source attachment, the creation of the
 	 * ast will fail with an {@link IllegalStateException}.</p>
 	 *
-	 * <p>This source is not used when the AST is built using 
+	 * <p>This source is not used when the AST is built using
 	 * {@link #createASTs(ICompilationUnit[], String[], ASTRequestor, IProgressMonitor)}.</p>
 	 *
 	 * @param source the Java model compilation unit or class file whose corresponding source code
@@ -667,12 +660,56 @@ public class ASTParser {
 		}
 	}
 
+
+	/**
+	 * Sets the source code to be parsed.
+	 *
+	 *
+	 * <p>This method automatically sets the project (and compiler
+	 * options) based on the given compilation unit of class file, in a manner
+	 * equivalent to {@link #setProject(IJavaProject) setProject(source.getJavaProject())}.</p>
+	 * <p>If the source is a class file without source attachment, the creation of the
+	 * ast will fail with an {@link IllegalStateException}.</p>
+	 *
+	 * <p>If this method is used, the user need not specify compiler options explicitly.
+	 * The @param astLevel will be used for setting the corresponding values for the compiler
+	 * options: {@link JavaCore#COMPILER_SOURCE}, {@link JavaCore#COMPILER_CODEGEN_TARGET_PLATFORM}
+	 * and {@link JavaCore#COMPILER_COMPLIANCE}.</p>
+	 *
+	 * <p>This source is not used when the AST is built using
+	 * {@link #createASTs(ICompilationUnit[], String[], ASTRequestor, IProgressMonitor)}.</p>
+	 *
+	 * <p>This astLevel will be used as the
+	 * {@link #createASTs(ICompilationUnit[], String[], ASTRequestor, IProgressMonitor)}.</p>
+	 *
+	 * @param source the Java model compilation unit or class file whose corresponding source code
+	 * is to be parsed, or <code>null</code> if none
+	 * @param astLevel the API level; one of the <code>JLS*</code> level constants
+	 * declared on {@link AST}
+	 * @since 3.27
+	 */
+	public void setSource(ITypeRoot source, int astLevel) {
+		this.typeRoot = source;
+		// clear the raw source
+		this.rawSource = null;
+		if (source != null) {
+			this.project = source.getJavaProject();
+			Map<String, String> options = this.project.getOptions(true);
+			options.remove(JavaCore.COMPILER_TASK_TAGS); // no need to parse task tags
+			this.compilerOptions = options;
+			String compliance = DOMASTUtil.getCompliance(astLevel);
+			this.compilerOptions.put(JavaCore.COMPILER_COMPLIANCE, compliance);
+			this.compilerOptions.put(JavaCore.COMPILER_SOURCE, compliance);
+			this.compilerOptions.put(JavaCore.COMPILER_CODEGEN_TARGET_PLATFORM, compliance);
+		}
+	}
+
 	/**
      * Sets the subrange of the source code to be parsed.
      * By default, the entire source string will be parsed
      * (<code>offset</code> 0 and <code>length</code> -1).
      *
-	 * <p>This range is not used when the AST is built using 
+	 * <p>This range is not used when the AST is built using
 	 * {@link #createASTs(ICompilationUnit[], String[], ASTRequestor, IProgressMonitor)}.</p>
      *
      * @param offset the index of the first character to parse
@@ -707,14 +744,14 @@ public class ASTParser {
 			this.bits &= ~CompilationUnitResolver.STATEMENT_RECOVERY;
 		}
 	}
-	
+
 	/**
-	 * Requests an abstract syntax tree without method bodies. 
-	 * 
+	 * Requests an abstract syntax tree without method bodies.
+	 *
 	 * <p>When ignore method bodies is enabled, all method bodies are discarded.
 	 * This has no impact on the binding resolution.</p>
 	 *
-	 * <p>This setting is not used when the kind used in {@link #setKind(int)} is either 
+	 * <p>This setting is not used when the kind used in {@link #setKind(int)} is either
 	 * {@link #K_EXPRESSION} or {@link #K_STATEMENTS}.</p>
 	 * @since 3.5.2
 	 */
@@ -744,7 +781,7 @@ public class ASTParser {
 	/**
 	 * Sets the name of the compilation unit that would hypothetically contains the
 	 * source string.
-	 * 
+	 *
 	 *  <p>This is used in conjunction with {@link #setSource(char[])}
 	 * and {@link #setProject(IJavaProject)} to locate the compilation unit relative to a Java project.
 	 * Defaults to none (<code>null</code>).</p>
@@ -764,7 +801,7 @@ public class ASTParser {
 	 * If the source declares a public class name "Bar" in a package "p1.p2" in a project "P" in a source folder "src",
 	 * the name of the compilation unit must be "/P/src/p1/p2/Bar.java".</p>
 	 *
-	 * <p>This unit name is not used when the AST is built using 
+	 * <p>This unit name is not used when the AST is built using
 	 * {@link #createASTs(ICompilationUnit[], String[], ASTRequestor, IProgressMonitor)}.</p>
 	 *
 	 * @param unitName the name of the compilation unit that would contain the source
@@ -776,7 +813,7 @@ public class ASTParser {
 
 	/**
 	 * Sets the Java project used when resolving bindings.
-	 * 
+	 *
 	 * <p>This method automatically sets the compiler
 	 * options based on the given project:</p>
 	 * <pre>
@@ -809,8 +846,8 @@ public class ASTParser {
 	 * A successful call to this method returns all settings to their
 	 * default values so the object is ready to be reused.
 	 * </p>
-	 * <p>For identifying a module-info.java file as a special file instead of an ordinary 
-	 * Java file (Since Java 9), a call to this should be preceded by a call to 
+	 * <p>For identifying a module-info.java file as a special file instead of an ordinary
+	 * Java file (Since Java 9), a call to this should be preceded by a call to
 	 * {@link #setUnitName(String)} that sets the unit name as module-info.java</p>
 	 *
 	 * @param monitor the progress monitor used to report progress and request cancellation,
@@ -1020,7 +1057,7 @@ public class ASTParser {
 	}
 	/**
 	 * Creates bindings for a batch of Java elements.
-	 * 
+	 *
 	 * <p>These elements are either
 	 * enclosed in {@link ICompilationUnit ICompilationUnits} or in {@link IClassFile IClassFiles}.</p>
 	 * <p>
@@ -1184,7 +1221,7 @@ public class ASTParser {
 							throw new IllegalStateException(String.valueOf(stringWriter.getBuffer()));
 						}
 					} else if (this.rawSource != null) {
-						needToResolveBindings = 
+						needToResolveBindings =
 							((this.bits & CompilationUnitResolver.RESOLVE_BINDING) != 0)
 							&& this.unitName != null
 							&& (this.project != null
@@ -1339,12 +1376,13 @@ public class ASTParser {
 		converter.compilationUnitSourceLength = this.rawSource.length;
 		converter.scanner.setSource(this.rawSource);
 
-		AST ast = AST.newAST(this.apiLevel);
+		AST ast = AST.newAST(this.apiLevel, JavaCore.ENABLED.equals(this.compilerOptions.get(JavaCore.COMPILER_PB_ENABLE_PREVIEW_FEATURES)));
 		ast.setDefaultNodeFlag(ASTNode.ORIGINAL);
 		ast.setBindingResolver(new BindingResolver());
 		if ((this.bits & CompilationUnitResolver.STATEMENT_RECOVERY) != 0) {
 			ast.setFlag(ICompilationUnit.ENABLE_STATEMENTS_RECOVERY);
 		}
+		ast.scanner.previewEnabled = JavaCore.ENABLED.equals(this.compilerOptions.get(JavaCore.COMPILER_PB_ENABLE_PREVIEW_FEATURES));
 		converter.setAST(ast);
 		CodeSnippetParsingUtil codeSnippetParsingUtil = new CodeSnippetParsingUtil((this.bits & CompilationUnitResolver.IGNORE_METHOD_BODIES) != 0);
 		CompilationUnit compilationUnit = ast.newCompilationUnit();
@@ -1366,7 +1404,7 @@ public class ASTParser {
 					converter.scanner = new RecoveryScanner(scanner, data.removeUnused());
 					converter.docParser.scanner = converter.scanner;
 					converter.scanner.setSource(scanner.source);
-					
+
 					compilationUnit.setStatementsRecoveryData(data);
 				}
 				RecordedParsingInformation recordedParsingInformation = codeSnippetParsingUtil.recordedParsingInformation;
