@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -641,6 +641,9 @@ class DefaultBindingResolver extends BindingResolver {
 	@Override
 	Object resolveConstantExpressionValue(Expression expression) {
 		org.eclipse.jdt.internal.compiler.ast.ASTNode node = (org.eclipse.jdt.internal.compiler.ast.ASTNode) this.newAstToOldAst.get(expression);
+		if(node instanceof org.eclipse.jdt.internal.compiler.ast.FieldDeclaration) {
+				node = ((org.eclipse.jdt.internal.compiler.ast.FieldDeclaration) node).initialization;
+		}
 		if (node instanceof org.eclipse.jdt.internal.compiler.ast.Expression &&
 				((org.eclipse.jdt.internal.compiler.ast.Expression) node).isTrulyExpression()) {
 			org.eclipse.jdt.internal.compiler.ast.Expression compilerExpression = (org.eclipse.jdt.internal.compiler.ast.Expression) node;
@@ -651,8 +654,8 @@ class DefaultBindingResolver extends BindingResolver {
 					case TypeIds.T_byte : return Byte.valueOf(constant.byteValue());
 					case TypeIds.T_short : return Short.valueOf(constant.shortValue());
 					case TypeIds.T_char : return Character.valueOf(constant.charValue());
-					case TypeIds.T_float : return new Float(constant.floatValue());
-					case TypeIds.T_double : return new Double(constant.doubleValue());
+					case TypeIds.T_float : return Float.valueOf(constant.floatValue());
+					case TypeIds.T_double : return Double.valueOf(constant.doubleValue());
 					case TypeIds.T_boolean : return constant.booleanValue() ? Boolean.TRUE : Boolean.FALSE;
 					case TypeIds.T_long : return Long.valueOf(constant.longValue());
 					case TypeIds.T_JavaLangString : return constant.stringValue();
