@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2014, 2019 Mateusz Matela and others.
+ * Copyright (c) 2014, 2020 Mateusz Matela and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -33,7 +33,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
-
+import java.util.stream.Collectors;
 import org.eclipse.jdt.core.dom.ASTNode;
 import org.eclipse.jdt.core.dom.ASTVisitor;
 import org.eclipse.jdt.core.dom.BlockComment;
@@ -109,7 +109,7 @@ public class CommentsPreparator extends ASTVisitor {
 	private int noFormatTagOpenStart = -1;
 	private int formatCodeTagOpenEnd = -1;
 	private int lastFormatCodeClosingTagIndex = -1;
-	private Token firstTagToken;
+	private ArrayList<Integer> commonAttributeAnnotations = new ArrayList<Integer>();
 	private DefaultCodeFormatter commentCodeFormatter;
 
 	public CommentsPreparator(TokenManager tm, DefaultCodeFormatterOptions options, String sourceLevel) {
@@ -193,6 +193,8 @@ public class CommentsPreparator extends ASTVisitor {
 			// merge previous and current line comment
 			Token previous = this.lastLineComment;
 			Token merged = new Token(previous, previous.originalStart, commentToken.originalEnd, previous.tokenType);
+			merged.putLineBreaksAfter(commentToken.getLineBreaksAfter());
+			merged.setPreserveLineBreaksAfter(commentToken.isPreserveLineBreaksAfter());
 			this.tm.remove(commentIndex - 1);
 			this.tm.insert(commentIndex - 1, merged);
 			this.tm.remove(commentIndex);
@@ -382,7 +384,14 @@ public class CommentsPreparator extends ASTVisitor {
 		boolean isHeader = this.tm.isInHeader(commentIndex);
 		boolean formattingEnabled = (this.options.comment_format_block_comment && !isHeader)
 				|| (this.options.comment_format_header && isHeader);
-		formattingEnabled = formattingEnabled && this.tm.charAt(commentToken.originalStart + 2) != '-';
+		if (this.tm.charAt(commentToken.originalStart + 2) == '-') {
+			if (commentToken.getLineBreaksBefore() > 0 || commentIndex == 0
+					|| this.tm.get(commentIndex - 1).getLineBreaksAfter() > 0) {
+				formattingEnabled = false;
+			} else {
+				return;
+			}
+		}
 		if (formattingEnabled && tokenizeMultilineComment(commentToken)) {
 			this.commentStructure = commentToken.getInternalStructure();
 			this.ctm = new TokenManager(this.commentStructure, this.tm);
@@ -441,12 +450,20 @@ public class CommentsPreparator extends ASTVisitor {
 			}
 
 			if (existingBreaksBefore < existingBreaksAfter && previous != null) {
-				commentToken.putLineBreaksAfter(previous.getLineBreaksAfter());
-				previous.clearLineBreaksAfter();
-			} else if (existingBreaksAfter <= existingBreaksBefore && next != null
+				if (previous.isPreserveLineBreaksAfter() || previous.getLineBreaksAfter() >= 2 || existingBreaksAfter < 2) {
+					commentToken.putLineBreaksAfter(previous.getLineBreaksAfter());
+					commentToken.setPreserveLineBreaksAfter(previous.isPreserveLineBreaksAfter());
+					previous.clearLineBreaksAfter();
+					previous.setPreserveLineBreaksAfter(true);
+				}
+			} else if (existingBreaksAfter < 2 && existingBreaksAfter <= existingBreaksBefore && next != null
 					&& next.tokenType != TokenNamepackage /* doesn't apply to a comment before the package declaration */) {
-				commentToken.putLineBreaksBefore(next.getLineBreaksBefore());
-				next.clearLineBreaksBefore();
+				if (next.isPreserveLineBreaksBefore() || next.getLineBreaksBefore() >= 2 || existingBreaksBefore < 2) {
+					commentToken.putLineBreaksBefore(next.getLineBreaksBefore());
+					commentToken.setPreserveLineBreaksBefore(next.isPreserveLineBreaksBefore());
+					next.clearLineBreaksBefore();
+					next.setPreserveLineBreaksBefore(true);
+				}
 			}
 		}
 
@@ -526,7 +543,7 @@ public class CommentsPreparator extends ASTVisitor {
 		this.noFormatTagOpenStart = -1;
 		this.formatCodeTagOpenEnd = -1;
 		this.lastFormatCodeClosingTagIndex = -1;
-		this.firstTagToken = null;
+		this.commonAttributeAnnotations.clear();
 		this.ctm = null;
 
 		int commentIndex = this.tm.firstIndexIn(node, TokenNameCOMMENT_JAVADOC);
@@ -554,6 +571,7 @@ public class CommentsPreparator extends ASTVisitor {
 		this.ctm = new TokenManager(commentToken.getInternalStructure(), this.tm);
 
 		handleJavadocTagAlignment(node);
+		handleJavadocBlankLines(node);
 
 		return true;
 	}
@@ -562,10 +580,6 @@ public class CommentsPreparator extends ASTVisitor {
 	public void endVisit(Javadoc node) {
 		if (this.ctm == null)
 			return;
-		if (this.options.comment_insert_empty_line_before_root_tags && this.firstTagToken != null
-				&& this.ctm.indexOf(this.firstTagToken) > 1) {
-			this.firstTagToken.putLineBreaksBefore(2);
-		}
 		addSubstituteWraps();
 	}
 
@@ -589,10 +603,6 @@ public class CommentsPreparator extends ASTVisitor {
 			Token startTokeen = this.ctm.get(startIndex);
 			if (startIndex > 1)
 				startTokeen.breakBefore();
-			int firstTagIndex;
-			if (this.firstTagToken == null || (firstTagIndex = this.ctm.indexOf(this.firstTagToken)) < 0
-					|| startIndex < firstTagIndex)
-				this.firstTagToken = startTokeen;
 
 			handleHtml(node);
 		}
@@ -638,7 +648,7 @@ public class CommentsPreparator extends ASTVisitor {
 			}
 			javadocRootTags.add(tagTokens);
 		}
-		
+
 		if (this.options.comment_align_tags_names_descriptions) {
 			int maxTagNameLength = 0;
 			int maxParamNameLength = 0;
@@ -688,6 +698,35 @@ public class CommentsPreparator extends ASTVisitor {
 		}
 	}
 
+	private void handleJavadocBlankLines(Javadoc node) {
+		List<TagElement> tagElements = node.tags();
+		List<Integer> tagIndexes = tagElements.stream()
+				.filter(t -> !t.isNested() && t.getTagName() != null && t.getTagName().length() > 1)
+				.map(t -> tokenStartingAt(t.getStartPosition()))
+				.collect(Collectors.toList());
+		tagIndexes.addAll(this.commonAttributeAnnotations);
+		Collections.sort(tagIndexes);
+
+		String previousName = null;
+		if (!tagIndexes.isEmpty()) {
+			int firstIndex = tagIndexes.get(0);
+			previousName = this.ctm.toString(firstIndex);
+			if (this.options.comment_insert_empty_line_before_root_tags && firstIndex > 1)
+				this.ctm.get(firstIndex).putLineBreaksBefore(2);
+		}
+		if (this.options.comment_insert_empty_line_between_different_tags) {
+			for (int i = 1; i < tagIndexes.size(); i++) {
+				Token tagToken = this.ctm.get(tagIndexes.get(i));
+				String thisName = this.tm.toString(tagToken);
+				boolean sameType = previousName.equals(thisName)
+						|| (isCommonsAttributeAnnotation(previousName) && isCommonsAttributeAnnotation(thisName));
+				if (!sameType)
+					tagToken.putLineBreaksBefore(2);
+				previousName = thisName;
+			}
+		}
+	}
+
 	private void alignJavadocTag(List<Token> tagTokens, int paramNameAlign, int descriptionAlign) {
 		Token paramName = tagTokens.get(1);
 		if (paramName != null) {
@@ -1056,11 +1095,12 @@ public class CommentsPreparator extends ASTVisitor {
 						if (this.tm.charAt(tokenStart) == '@') {
 							outputToken.setWrapPolicy(WrapPolicy.DISABLE_WRAP);
 							if (commentToken.tokenType == TokenNameCOMMENT_BLOCK && lineBreaks == 1
-									&& structure.size() > 1)
+									&& structure.size() > 1) {
 								outputToken.putLineBreaksBefore(cleanBlankLines ? 1 : 2);
-							if (this.tm.charAt(tokenStart + 1) == '@' && lineBreaks > 0 && this.firstTagToken == null) {
-								// Commons Attributes annotation, see bug 237051
-								this.firstTagToken = outputToken;
+							}
+							if (lineBreaks > 0 && isCommonsAttributeAnnotation(this.tm.toString(outputToken))) {
+								outputToken.breakBefore();
+								this.commonAttributeAnnotations.add(structure.size());
 							}
 						}
 						structure.add(outputToken);
@@ -1093,6 +1133,10 @@ public class CommentsPreparator extends ASTVisitor {
 		return true;
 	}
 
+	private boolean isCommonsAttributeAnnotation(String tokenContent) {
+		return tokenContent.startsWith("@@"); //$NON-NLS-1$
+	}
+
 	private void noSubstituteWrapping(int from, int to) {
 		int commentStart = this.ctm.get(0).originalStart;
 		assert commentStart <= from && from <= to && to <= this.ctm.get(this.ctm.size() - 1).originalEnd;
@@ -1147,7 +1191,7 @@ public class CommentsPreparator extends ASTVisitor {
 		for (Token token : formattedTokens)
 			token.setAlign(token.getAlign() + openingToken.getAlign() + openingToken.getIndent());
 		fixJavadocTagAlign(openingToken, closingTagFirstIndex);
-		
+
 		// there are too few linebreaks at the start and end
 		Token start = formattedTokens.get(0);
 		start.putLineBreaksBefore(start.getLineBreaksBefore() + 1);
