@@ -41,6 +41,7 @@ import org.eclipse.core.resources.IWorkspaceRoot;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.Path;
+import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.core.compiler.CharOperation;
 import org.eclipse.jdt.internal.compiler.env.AccessRule;
 import org.eclipse.jdt.internal.compiler.env.AccessRuleSet;
@@ -76,7 +77,7 @@ private long previousStructuralBuildTime;
 private StringSet structurallyChangedTypes;
 public static int MaxStructurallyChangedTypes = 100; // keep track of ? structurally changed types, otherwise consider all to be changed
 
-public static final byte VERSION = 0x0023;
+public static final byte VERSION = 0x0024;
 
 static final byte SOURCE_FOLDER = 1;
 static final byte BINARY_FOLDER = 2;
@@ -256,11 +257,16 @@ static State read(IProject project, DataInputStream in) throws IOException, Core
 	newState.buildNumber = in.readInt();
 	newState.lastStructuralBuildTime = in.readLong();
 
-	newState.sourceLocations = readSourceLocations(project, in);
-	newState.binaryLocations = readBinaryLocations(project, in, newState.sourceLocations);
+	ArrayList<ClasspathLocation> allLocationsForEEA = null;
+	if (JavaCore.ENABLED.equals(JavaCore.create(project).getOption(JavaCore.CORE_JAVA_BUILD_EXTERNAL_ANNOTATIONS_FROM_ALL_LOCATIONS, true))) {
+		allLocationsForEEA = new ArrayList<>(); // signals that we are collecting locations
+	}
 
-	newState.testSourceLocations = readSourceLocations(project, in);
-	newState.testBinaryLocations = readBinaryLocations(project, in, newState.testSourceLocations);
+	newState.sourceLocations = readSourceLocations(project, in, allLocationsForEEA);
+	newState.binaryLocations = readBinaryLocations(project, in, newState.sourceLocations, allLocationsForEEA);
+
+	newState.testSourceLocations = readSourceLocations(project, in, allLocationsForEEA);
+	newState.testBinaryLocations = readBinaryLocations(project, in, newState.testSourceLocations, allLocationsForEEA);
 
 	int length;
 	newState.structuralBuildTimes = new SimpleLookupTable(length = in.readInt());
@@ -329,7 +335,7 @@ static State read(IProject project, DataInputStream in) throws IOException, Core
 	return newState;
 }
 
-private static ClasspathMultiDirectory[] readSourceLocations(IProject project, DataInputStream in) throws IOException {
+private static ClasspathMultiDirectory[] readSourceLocations(IProject project, DataInputStream in, List<ClasspathLocation> allLocationsForEEA) throws IOException {
 	int length = in.readInt();
 	ClasspathMultiDirectory[] sourceLocations = new ClasspathMultiDirectory[length];
 	for (int i = 0; i < length; i++) {
@@ -338,20 +344,23 @@ private static ClasspathMultiDirectory[] readSourceLocations(IProject project, D
 		if ((folderName = in.readUTF()).length() > 0) sourceFolder = project.getFolder(folderName);
 		if ((folderName = in.readUTF()).length() > 0) outputFolder = project.getFolder(folderName);
 		ClasspathMultiDirectory md =
-			(ClasspathMultiDirectory) ClasspathLocation.forSourceFolder(sourceFolder, outputFolder, readNames(in), readNames(in), in.readBoolean());
+			(ClasspathMultiDirectory) ClasspathLocation.forSourceFolder(sourceFolder, outputFolder, readNames(in), readNames(in), in.readBoolean(), readNullablePath(in), allLocationsForEEA);
 		if (in.readBoolean())
 			md.hasIndependentOutputFolder = true;
 		sourceLocations[i] = md;
+		if (allLocationsForEEA != null)
+			allLocationsForEEA.add(md);
 	}
 	return sourceLocations;
 }
 
-private static ClasspathLocation[] readBinaryLocations(IProject project, DataInputStream in, ClasspathMultiDirectory[] sourceLocations) throws IOException, CoreException {
+private static ClasspathLocation[] readBinaryLocations(IProject project, DataInputStream in, ClasspathMultiDirectory[] sourceLocations, ArrayList<ClasspathLocation> allLocationsForEEA) throws IOException, CoreException {
 	int length = in.readInt();
 	ClasspathLocation[] locations = new ClasspathLocation[length];
 	IWorkspaceRoot root = project.getWorkspace().getRoot();
 	for (int i = 0; i < length; i++) {
-		switch (in.readByte()) {
+		byte kind = in.readByte();
+		switch (kind) {
 			case SOURCE_FOLDER :
 				locations[i] = sourceLocations[in.readInt()];
 				break;
@@ -360,13 +369,13 @@ private static ClasspathLocation[] readBinaryLocations(IProject project, DataInp
 				IContainer outputFolder = path.segmentCount() == 1
 					? (IContainer) root.getProject(path.toString())
 					: (IContainer) root.getFolder(path);
-					locations[i] = ClasspathLocation.forBinaryFolder(outputFolder, in.readBoolean(),
-							readRestriction(in), new Path(in.readUTF()), in.readBoolean());
+				locations[i] = ClasspathLocation.forBinaryFolder(outputFolder, in.readBoolean(),
+							readRestriction(in), new Path(in.readUTF()), allLocationsForEEA, in.readBoolean());
 				break;
 			case EXTERNAL_JAR :
 				String jarPath = in.readUTF();
 				if (Util.isJrt(jarPath)) {
-					locations[i] = ClasspathLocation.forJrtSystem(jarPath, readRestriction(in), new Path(in.readUTF()), in.readUTF());
+					locations[i] = ClasspathLocation.forJrtSystem(jarPath, readRestriction(in), new Path(in.readUTF()), allLocationsForEEA, in.readUTF());
 				} else {
 					locations[i] = ClasspathLocation.forLibrary(jarPath, in.readLong(),
 							readRestriction(in), new Path(in.readUTF()), in.readBoolean(), in.readUTF());
@@ -374,10 +383,12 @@ private static ClasspathLocation[] readBinaryLocations(IProject project, DataInp
 				break;
 			case INTERNAL_JAR :
 					locations[i] = ClasspathLocation.forLibrary(root.getFile(new Path(in.readUTF())),
-							readRestriction(in), new Path(in.readUTF()), in.readBoolean(), in.readUTF());
+							readRestriction(in), new Path(in.readUTF()), allLocationsForEEA, in.readBoolean(), in.readUTF());
 					break;
 		}
 		ClasspathLocation loc = locations[i];
+		if (allLocationsForEEA != null && kind != SOURCE_FOLDER && !allLocationsForEEA.contains(loc))
+			allLocationsForEEA.add(loc);
 		char[] patchName = readName(in);
 		loc.patchModuleName = patchName.length > 0 ? new String(patchName) : null;
 		int limitSize = in.readInt();
@@ -429,6 +440,13 @@ private static char[][] readNames(DataInputStream in) throws IOException {
 	return names;
 }
 
+private static IPath readNullablePath(DataInputStream in) throws IOException {
+	String path = in.readUTF();
+	if (!path.isEmpty())
+		return new Path(path);
+	return null;
+}
+
 private static AccessRuleSet readRestriction(DataInputStream in) throws IOException {
 	int length = in.readInt();
 	if (length == 0) return null; // no restriction specified
@@ -711,6 +729,7 @@ private void writeSourceLocations(DataOutputStream out, ClasspathMultiDirectory[
 		writeNames(md.inclusionPatterns, out);
 		writeNames(md.exclusionPatterns, out);
 		out.writeBoolean(md.ignoreOptionalProblems);
+		writeNullablePath(md.externalAnnotationPath, out);
 		out.writeBoolean(md.hasIndependentOutputFolder);
 	}
 }
@@ -741,7 +760,7 @@ private void writeBinaryLocations(DataOutputStream out, ClasspathLocation[] loca
 			out.writeUTF(cd.binaryFolder.getFullPath().toString());
 			out.writeBoolean(cd.isOutputFolder);
 			writeRestriction(cd.accessRuleSet, out);
-			out.writeUTF(cd.externalAnnotationPath != null ? cd.externalAnnotationPath : ""); //$NON-NLS-1$
+			writeNullablePath(cd.externalAnnotationPath, out);
 			out.writeBoolean(cd.isOnModulePath);
 		} else if (c instanceof ClasspathJar) {
 			ClasspathJar jar = (ClasspathJar) c;
@@ -754,7 +773,7 @@ private void writeBinaryLocations(DataOutputStream out, ClasspathLocation[] loca
 				out.writeUTF(jar.resource.getFullPath().toString());
 			}
 			writeRestriction(jar.accessRuleSet, out);
-			out.writeUTF(jar.externalAnnotationPath != null ? jar.externalAnnotationPath : ""); //$NON-NLS-1$
+			writeNullablePath(jar.externalAnnotationPath, out);
 			out.writeBoolean(jar.isOnModulePath);
 			out.writeUTF(jar.compliance == null ? "" : jar.compliance); //$NON-NLS-1$
 
@@ -763,7 +782,7 @@ private void writeBinaryLocations(DataOutputStream out, ClasspathLocation[] loca
 			out.writeByte(EXTERNAL_JAR);
 			out.writeUTF(jrt.zipFilename);
 			writeRestriction(jrt.accessRuleSet, out);
-			out.writeUTF(jrt.externalAnnotationPath != null ? jrt.externalAnnotationPath : ""); //$NON-NLS-1$
+			writeNullablePath(jrt.externalAnnotationPath, out);
 			if (jrt instanceof ClasspathJrtWithReleaseOption)
 				out.writeUTF(((ClasspathJrtWithReleaseOption) jrt).release);
 			else
@@ -782,19 +801,17 @@ private void writeBinaryLocations(DataOutputStream out, ClasspathLocation[] loca
 		if (c.updates != null) {
 			List<Consumer<IUpdatableModule>> pu = c.updates.getList(UpdateKind.PACKAGE, false);
 			if (pu != null) {
-				Map<String, List<Consumer<IUpdatableModule>>> map = pu.stream().
-						collect(Collectors.groupingBy(
-								update -> CharOperation.charToString(((IUpdatableModule.AddExports)update).getName())));
+				Map<String, List<AddExports>> map = pu.stream().filter(AddExports.class::isInstance)
+						.map(AddExports.class::cast)
+						.collect(Collectors.groupingBy(addExport -> CharOperation.charToString(addExport.getName())));
 				out.writeInt(map.size());
 				map.entrySet().stream().forEach(entry -> {
 					String pkgName = entry.getKey();
 					try {
 						writeName(pkgName.toCharArray(), out);
 						char[][] targetModules = entry.getValue().stream()
-								.map(consumer -> ((IUpdatableModule.AddExports) consumer).getTargetModules())
-								.filter(targets -> targets != null)
-								.reduce((f,s) -> CharOperation.arrayConcat(f,s))
-								.orElse(null);
+								.map(addExport -> addExport.getTargetModules()).filter(targets -> targets != null)
+								.reduce((f, s) -> CharOperation.arrayConcat(f, s)).orElse(null);
 						writeNames(targetModules, out);
 					} catch (IOException e) {
 						// ignore
@@ -806,9 +823,10 @@ private void writeBinaryLocations(DataOutputStream out, ClasspathLocation[] loca
 			}
 			List<Consumer<IUpdatableModule>> mu = c.updates.getList(UpdateKind.MODULE, false);
 			if (mu != null) {
-				out.writeInt(mu.size());
-				for (Consumer<IUpdatableModule> cons : mu) {
-					AddReads m = (AddReads) cons;
+				// TODO, here we cannot handle MODULE_MAIN_CLASS nor MODULE_PACKAGES (ModuleUpdater stores a lambda), should we?
+				List<AddReads> allReads = mu.stream().filter(AddReads.class::isInstance).map(AddReads.class::cast).collect(Collectors.toList());
+				out.writeInt(allReads.size());
+				for (AddReads m : allReads) {
 					writeName(m.getTarget(), out);
 				}
 			} else {
@@ -835,6 +853,10 @@ private void writeNames(char[][] names, DataOutputStream out) throws IOException
 		writeName(names[i], out);
 }
 
+private void writeNullablePath(String path, DataOutputStream out) throws IOException {
+	out.writeUTF(path != null ? path : ""); //$NON-NLS-1$
+}
+
 private void writeRestriction(AccessRuleSet accessRuleSet, DataOutputStream out) throws IOException {
 	if (accessRuleSet == null) {
 		out.writeInt(0);
