@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -492,6 +492,18 @@ public interface IJavaSearchConstants {
 	 */
 	int METHOD_REFERENCE_EXPRESSION = 0x10000000;
 
+	/**
+	 * Return only type references used as a permit type (Java 15)
+	 * <p>
+	 * When this flag is set, only {@link TypeReferenceMatch} matches will be
+	 * returned.
+	 *</p>
+	 * @since 3.24
+	 * @noreference permit type reference
+	 * @category limitTo
+	 */
+	int PERMITTYPE_TYPE_REFERENCE = 0x20000000;
+
 	/* Syntactic match modes */
 
 	/**
