@@ -12,7 +12,7 @@ public boolean equals (Object obj) {
 }
 protected void finalize () throws Throwable {
 }
-public final Class getClass() {
+public final Class<? extends Object> getClass() {
 	return null;
 }
 public int hashCode() {
